Class: Dodopayments::Models::BrandArchiveParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Dodopayments::Models::BrandArchiveParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/dodopayments/models/brand_archive_params.rb,
sig/dodopayments/models/brand_archive_params.rbs
Overview
Constant Summary
Constants included from Internal::Type::RequestParameters
Internal::Type::RequestParameters::Dodopayments
Instance Attribute Summary collapse
- #id ⇒ String
-
#move_products_to ⇒ String?
Brand that takes over the products and the live subscriptions of the brand you archive.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(id:, move_products_to: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see BrandArchiveParams for more details.
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, move_products_to: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Dodopayments::Models::BrandArchiveParams for more details.
|
|
# File 'lib/dodopayments/models/brand_archive_params.rb', line 24
|
Instance Attribute Details
#id ⇒ String
13 |
# File 'lib/dodopayments/models/brand_archive_params.rb', line 13 required :id, String |
#move_products_to ⇒ String?
Brand that takes over the products and the live subscriptions of the brand you archive. It must be a brand of the same business, and it must not be archived. The primary brand (its brand id is the business id) is a valid target. Omit this field only when the brand holds no products and no live subscriptions.
22 |
# File 'lib/dodopayments/models/brand_archive_params.rb', line 22 optional :move_products_to, String, nil?: true |
Instance Method Details
#to_hash ⇒ {
21 |
# File 'sig/dodopayments/models/brand_archive_params.rbs', line 21
def to_hash: -> {
|