Module: Dodopayments::Models::Customers::EmailLogStatus

Extended by:
Internal::Type::Enum
Defined in:
lib/dodopayments/models/customers/email_log_status.rb,
sig/dodopayments/models/customers/email_log_status.rbs

Overview

The delivery status of one email.

sent also covers an email that is still on its way. A status only becomes delivered, failed or complained when the mail server answers.

Constant Summary collapse

SENT =

Returns:

  • (:sent)
:sent
DELIVERED =

Returns:

  • (:delivered)
:delivered
FAILED =

Returns:

  • (:failed)
:failed
COMPLAINED =

Returns:

  • (:complained)
:complained
BLOCKED =

Returns:

  • (:blocked)
:blocked

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/dodopayments/models/customers/email_log_status.rb', line 19

Instance Method Details

#self?.values::Array[Dodopayments::Models::Customers::email_log_status]

Returns:

  • (::Array[Dodopayments::Models::Customers::email_log_status])


16
# File 'sig/dodopayments/models/customers/email_log_status.rbs', line 16

def self?.values: -> ::Array[Dodopayments::Models::Customers::email_log_status]