Class: Dodopayments::Models::Dispute
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Dodopayments::Models::Dispute
- Defined in:
- lib/dodopayments/models/dispute.rb
Instance Attribute Summary collapse
-
#amount ⇒ String
The amount involved in the dispute, represented as a string to accommodate precision.
-
#business_id ⇒ String
The unique identifier of the business involved in the dispute.
-
#created_at ⇒ Time
The timestamp of when the dispute was created, in UTC.
-
#currency ⇒ String
The currency of the disputed amount, represented as an ISO 4217 currency code.
-
#dispute_id ⇒ String
The unique identifier of the dispute.
-
#dispute_stage ⇒ Symbol, Dodopayments::Models::DisputeStage
The current stage of the dispute process.
-
#dispute_status ⇒ Symbol, Dodopayments::Models::DisputeStatus
The current status of the dispute.
-
#is_resolved_by_rdr ⇒ Boolean?
Whether the dispute was resolved by Rapid Dispute Resolution.
-
#payment_id ⇒ String
The unique identifier of the payment associated with the dispute.
-
#remarks ⇒ String?
Remarks.
Instance Method Summary collapse
-
#initialize(amount:, business_id:, created_at:, currency:, dispute_id:, dispute_stage:, dispute_status:, payment_id:, is_resolved_by_rdr: nil, remarks: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Dispute for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(amount:, business_id:, created_at:, currency:, dispute_id:, dispute_stage:, dispute_status:, payment_id:, is_resolved_by_rdr: nil, remarks: nil) ⇒ Object
Some parameter documentations has been truncated, see Dodopayments::Models::Dispute for more details.
|
|
# File 'lib/dodopayments/models/dispute.rb', line 67
|
Instance Attribute Details
#amount ⇒ String
The amount involved in the dispute, represented as a string to accommodate precision.
11 |
# File 'lib/dodopayments/models/dispute.rb', line 11 required :amount, String |
#business_id ⇒ String
The unique identifier of the business involved in the dispute.
17 |
# File 'lib/dodopayments/models/dispute.rb', line 17 required :business_id, String |
#created_at ⇒ Time
The timestamp of when the dispute was created, in UTC.
23 |
# File 'lib/dodopayments/models/dispute.rb', line 23 required :created_at, Time |
#currency ⇒ String
The currency of the disputed amount, represented as an ISO 4217 currency code.
29 |
# File 'lib/dodopayments/models/dispute.rb', line 29 required :currency, String |
#dispute_id ⇒ String
The unique identifier of the dispute.
35 |
# File 'lib/dodopayments/models/dispute.rb', line 35 required :dispute_id, String |
#dispute_stage ⇒ Symbol, Dodopayments::Models::DisputeStage
The current stage of the dispute process.
41 |
# File 'lib/dodopayments/models/dispute.rb', line 41 required :dispute_stage, enum: -> { Dodopayments::DisputeStage } |
#dispute_status ⇒ Symbol, Dodopayments::Models::DisputeStatus
The current status of the dispute.
47 |
# File 'lib/dodopayments/models/dispute.rb', line 47 required :dispute_status, enum: -> { Dodopayments::DisputeStatus } |
#is_resolved_by_rdr ⇒ Boolean?
Whether the dispute was resolved by Rapid Dispute Resolution
59 |
# File 'lib/dodopayments/models/dispute.rb', line 59 optional :is_resolved_by_rdr, Dodopayments::Internal::Type::Boolean, nil?: true |
#payment_id ⇒ String
The unique identifier of the payment associated with the dispute.
53 |
# File 'lib/dodopayments/models/dispute.rb', line 53 required :payment_id, String |
#remarks ⇒ String?
Remarks
65 |
# File 'lib/dodopayments/models/dispute.rb', line 65 optional :remarks, String, nil?: true |