Class: Dodopayments::Models::EntitlementUpdateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/dodopayments/models/entitlement_update_params.rb,
sig/dodopayments/models/entitlement_update_params.rbs

Overview

See Also:

  • Dodopayments::Resources::Entitlements#update

Constant Summary

Constants included from Internal::Type::RequestParameters

Internal::Type::RequestParameters::Dodopayments

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, description: nil, integration_config: nil, metadata: nil, name: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Dodopayments::Models::EntitlementUpdateParams for more details.

Parameters:



# File 'lib/dodopayments/models/entitlement_update_params.rb', line 44

Instance Attribute Details

#descriptionString?

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


18
# File 'lib/dodopayments/models/entitlement_update_params.rb', line 18

optional :description, String, nil?: true

#idString

Parameters:

  • value (String)

Returns:

  • (String)


13
# File 'lib/dodopayments/models/entitlement_update_params.rb', line 13

required :id, String

#integration_configDodopayments::Models::IntegrationConfig::FeatureFlagConfig, ...

Integration-specific configuration supplied when creating or updating an entitlement. The shape required matches the entitlement's integration_type.

Untagged enum: variants are matched in order. FeatureFlag must precede LicenseKey, whose fields are all optional and would otherwise match a feature_flag config.



29
# File 'lib/dodopayments/models/entitlement_update_params.rb', line 29

optional :integration_config, union: -> { Dodopayments::IntegrationConfig }, nil?: true

#metadataHash{Symbol=>String, Float, Boolean}?

Arbitrary key-value metadata. Values can be string, integer, number, or boolean.

Parameters:

  • value (Dodopayments::Models::metadata, nil)

Returns:

  • (Hash{Symbol=>String, Float, Boolean}, nil)


35
36
37
# File 'lib/dodopayments/models/entitlement_update_params.rb', line 35

optional :metadata,
-> { Dodopayments::Internal::Type::HashOf[union: Dodopayments::MetadataItem] },
nil?: true

#nameString?

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


42
# File 'lib/dodopayments/models/entitlement_update_params.rb', line 42

optional :name, String, nil?: true

Instance Method Details

#to_hash{

Returns:

  • ({)


36
# File 'sig/dodopayments/models/entitlement_update_params.rbs', line 36

def to_hash: -> {