Class: Dodopayments::Models::Entitlements::GrantFulfillLicenseKeyParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/dodopayments/models/entitlements/grant_fulfill_license_key_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(grant_id:, key:, activations_limit: nil, expires_at: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Dodopayments::Models::Entitlements::GrantFulfillLicenseKeyParams for more details.

Parameters:

  • grant_id (String)
  • key (String)

    The license key value to deliver to the customer.

  • activations_limit (Integer, nil) (defaults to: nil)

    Per-key activation limit. Defaults to the entitlement’s license-key configuratio

  • expires_at (Time, nil) (defaults to: nil)

    When the key expires. Defaults to the duration in the entitlement’s license-key

  • request_options (Dodopayments::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/dodopayments/models/entitlements/grant_fulfill_license_key_params.rb', line 36

Instance Attribute Details

#activations_limitInteger?

Per-key activation limit. Defaults to the entitlement’s license-key configuration.

Returns:

  • (Integer, nil)


27
# File 'lib/dodopayments/models/entitlements/grant_fulfill_license_key_params.rb', line 27

optional :activations_limit, Integer, nil?: true

#expires_atTime?

When the key expires. Defaults to the duration in the entitlement’s license-key configuration.

Returns:

  • (Time, nil)


34
# File 'lib/dodopayments/models/entitlements/grant_fulfill_license_key_params.rb', line 34

optional :expires_at, Time, nil?: true

#grant_idString

Returns:

  • (String)


14
# File 'lib/dodopayments/models/entitlements/grant_fulfill_license_key_params.rb', line 14

required :grant_id, String

#keyString

The license key value to deliver to the customer.

Returns:

  • (String)


20
# File 'lib/dodopayments/models/entitlements/grant_fulfill_license_key_params.rb', line 20

required :key, String