Class: Dodopayments::Models::GetDispute

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/dodopayments/models/get_dispute.rb,
sig/dodopayments/models/get_dispute.rbs

Overview

See Also:

  • Dodopayments::Resources::Disputes#retrieve

Direct Known Subclasses

WebhookPayload::Data::Dispute

Defined Under Namespace

Modules: PaymentProvider

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(amount:, brand_id:, business_id:, created_at:, currency:, customer:, dispute_id:, dispute_stage:, dispute_status:, payment_id:, payment_provider:, is_resolved_by_rdr: nil, reason: nil, remarks: nil) ⇒ Object

Some parameter documentations has been truncated, see Dodopayments::Models::GetDispute for more details.

Parameters:

  • amount (String)

    The amount involved in the dispute, represented as a string to accommodate preci

  • brand_id (String)

    Brand id this dispute belongs to

  • business_id (String)

    The unique identifier of the business involved in the dispute.

  • created_at (Time)

    The timestamp of when the dispute was created, in UTC.

  • currency (String)

    The currency of the disputed amount, represented as an ISO 4217 currency code.

  • customer (Dodopayments::Models::CustomerLimitedDetails)

    The customer who filed the dispute

  • dispute_id (String)

    The unique identifier of the dispute.

  • dispute_stage (Symbol, Dodopayments::Models::DisputeStage)

    The current stage of the dispute process.

  • dispute_status (Symbol, Dodopayments::Models::DisputeStatus)

    The current status of the dispute.

  • payment_id (String)

    The unique identifier of the payment associated with the dispute.

  • payment_provider (Symbol, Dodopayments::Models::GetDispute::PaymentProvider)

    Which processor handled the underlying payment. stripe / adyen for

  • is_resolved_by_rdr (Boolean, nil) (defaults to: nil)

    Whether the dispute was resolved by Rapid Dispute Resolution

  • reason (String, nil) (defaults to: nil)

    Reason for the dispute

  • remarks (String, nil) (defaults to: nil)

    Remarks



# File 'lib/dodopayments/models/get_dispute.rb', line 94

Instance Attribute Details

#amountString

The amount involved in the dispute, represented as a string to accommodate precision.

Parameters:

  • value (String)

Returns:

  • (String)


12
# File 'lib/dodopayments/models/get_dispute.rb', line 12

required :amount, String

#brand_idString

Brand id this dispute belongs to

Parameters:

  • value (String)

Returns:

  • (String)


18
# File 'lib/dodopayments/models/get_dispute.rb', line 18

required :brand_id, String

#business_idString

The unique identifier of the business involved in the dispute.

Parameters:

  • value (String)

Returns:

  • (String)


24
# File 'lib/dodopayments/models/get_dispute.rb', line 24

required :business_id, String

#created_atTime

The timestamp of when the dispute was created, in UTC.

Parameters:

  • value (Time)

Returns:

  • (Time)


30
# File 'lib/dodopayments/models/get_dispute.rb', line 30

required :created_at, Time

#currencyString

The currency of the disputed amount, represented as an ISO 4217 currency code.

Parameters:

  • value (String)

Returns:

  • (String)


36
# File 'lib/dodopayments/models/get_dispute.rb', line 36

required :currency, String

#customerDodopayments::Models::CustomerLimitedDetails

The customer who filed the dispute



42
# File 'lib/dodopayments/models/get_dispute.rb', line 42

required :customer, -> { Dodopayments::CustomerLimitedDetails }

#dispute_idString

The unique identifier of the dispute.

Parameters:

  • value (String)

Returns:

  • (String)


48
# File 'lib/dodopayments/models/get_dispute.rb', line 48

required :dispute_id, String

#dispute_stageSymbol, Dodopayments::Models::DisputeStage

The current stage of the dispute process.

Parameters:

  • value (Dodopayments::Models::dispute_stage)

Returns:



54
# File 'lib/dodopayments/models/get_dispute.rb', line 54

required :dispute_stage, enum: -> { Dodopayments::DisputeStage }

#dispute_statusSymbol, Dodopayments::Models::DisputeStatus

The current status of the dispute.

Parameters:

  • value (Dodopayments::Models::dispute_status)

Returns:



60
# File 'lib/dodopayments/models/get_dispute.rb', line 60

required :dispute_status, enum: -> { Dodopayments::DisputeStatus }

#is_resolved_by_rdrBoolean?

Whether the dispute was resolved by Rapid Dispute Resolution

Parameters:

  • value (Boolean, nil)

Returns:

  • (Boolean, nil)


80
# File 'lib/dodopayments/models/get_dispute.rb', line 80

optional :is_resolved_by_rdr, Dodopayments::Internal::Type::Boolean, nil?: true

#payment_idString

The unique identifier of the payment associated with the dispute.

Parameters:

  • value (String)

Returns:

  • (String)


66
# File 'lib/dodopayments/models/get_dispute.rb', line 66

required :payment_id, String

#payment_providerSymbol, Dodopayments::Models::GetDispute::PaymentProvider

Which processor handled the underlying payment. stripe / adyen for BYOP routes (the merchant's own payment connector); dodo for everything Dodo processed itself.

Parameters:

  • value (Dodopayments::Models::GetDispute::payment_provider)

Returns:



74
# File 'lib/dodopayments/models/get_dispute.rb', line 74

required :payment_provider, enum: -> { Dodopayments::GetDispute::PaymentProvider }

#reasonString?

Reason for the dispute

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


86
# File 'lib/dodopayments/models/get_dispute.rb', line 86

optional :reason, String, nil?: true

#remarksString?

Remarks

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


92
# File 'lib/dodopayments/models/get_dispute.rb', line 92

optional :remarks, String, nil?: true

Instance Method Details

#to_hash{

Returns:

  • ({)


67
# File 'sig/dodopayments/models/get_dispute.rbs', line 67

def to_hash: -> {