Class: Dodopayments::Models::IntegrationConfig::DigitalFilesConfig

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/dodopayments/models/integration_config.rb,
sig/dodopayments/models/integration_config.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeObject



127
# File 'sig/dodopayments/models/integration_config.rbs', line 127

def initialize: (

Instance Attribute Details

#digital_file_idsArray<String>

Files attached to this entitlement. Add files via POST /entitlements/{id}/files and remove them via DELETE /entitlements/{id}/files/{file_id}.

Parameters:

  • value (::Array[String])

Returns:

  • (Array<String>)


144
# File 'lib/dodopayments/models/integration_config.rb', line 144

required :digital_file_ids, Dodopayments::Internal::Type::ArrayOf[String]

#external_urlString?

Optional external URL shown to the customer alongside the files.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


150
# File 'lib/dodopayments/models/integration_config.rb', line 150

optional :external_url, String, nil?: true

#instructionsString?

Optional human-readable delivery instructions shown to the customer alongside the files.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


157
# File 'lib/dodopayments/models/integration_config.rb', line 157

optional :instructions, String, nil?: true

#legacy_file_idsArray<String>?

Three-way patchable list of legacy file identifiers:

  • omitted → preserve the current value
  • null → clear
  • [...] → replace

On create, an omitted field, an explicit null, or an empty array all result in no legacy files attached.

Parameters:

  • value (::Array[String], nil)

Returns:

  • (Array<String>, nil)


170
# File 'lib/dodopayments/models/integration_config.rb', line 170

optional :legacy_file_ids, Dodopayments::Internal::Type::ArrayOf[String], nil?: true

Instance Method Details

#to_hash{

Returns:

  • ({)


134
# File 'sig/dodopayments/models/integration_config.rbs', line 134

def to_hash: -> {