Class: Dodopayments::Models::IntegrationConfig::LicenseKeyConfig

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/dodopayments/models/integration_config.rb,
sig/dodopayments/models/integration_config.rbs

Defined Under Namespace

Modules: FulfillmentMode

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(activation_message: nil, activations_limit: nil, duration_count: nil, duration_interval: nil, fulfillment_mode: nil) ⇒ Object

Some parameter documentations has been truncated, see Dodopayments::Models::IntegrationConfig::LicenseKeyConfig for more details.

Parameters:

  • activation_message (String, nil) (defaults to: nil)

    Optional message displayed when a customer activates the license

  • activations_limit (Integer, nil) (defaults to: nil)

    Maximum activations allowed per issued license key. Omit for unlimited.

  • duration_count (Integer, nil) (defaults to: nil)

    Validity duration of issued license keys. Provide both

  • duration_interval (Symbol, Dodopayments::Models::TimeInterval, nil) (defaults to: nil)

    Unit of duration_count.

  • fulfillment_mode (Symbol, Dodopayments::Models::IntegrationConfig::LicenseKeyConfig::FulfillmentMode, nil) (defaults to: nil)

    How license keys are fulfilled. auto (default) generates and delivers



# File 'lib/dodopayments/models/integration_config.rb', line 223

Instance Attribute Details

#activation_messageString?

Optional message displayed when a customer activates the license key (≤ 2500 characters).

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


191
# File 'lib/dodopayments/models/integration_config.rb', line 191

optional :activation_message, String, nil?: true

#activations_limitInteger?

Maximum activations allowed per issued license key. Omit for unlimited.

Parameters:

  • value (Integer, nil)

Returns:

  • (Integer, nil)


197
# File 'lib/dodopayments/models/integration_config.rb', line 197

optional :activations_limit, Integer, nil?: true

#duration_countInteger?

Validity duration of issued license keys. Provide both duration_count and duration_interval together for a fixed duration; omit both for non-expiring keys.

Parameters:

  • value (Integer, nil)

Returns:

  • (Integer, nil)


205
# File 'lib/dodopayments/models/integration_config.rb', line 205

optional :duration_count, Integer, nil?: true

#duration_intervalSymbol, ...

Unit of duration_count.

Parameters:

  • value (Dodopayments::Models::time_interval, nil)

Returns:



211
# File 'lib/dodopayments/models/integration_config.rb', line 211

optional :duration_interval, enum: -> { Dodopayments::TimeInterval }, nil?: true

#fulfillment_modeSymbol, ...

How license keys are fulfilled. auto (default) generates and delivers keys to customers automatically; manual creates pending grants that you fulfill with the supplied key via POST /grants/{grant_id}/license-key.

Parameters:

  • value (Dodopayments::Models::IntegrationConfig::LicenseKeyConfig::fulfillment_mode, nil)

Returns:



219
220
221
# File 'lib/dodopayments/models/integration_config.rb', line 219

optional :fulfillment_mode,
enum: -> { Dodopayments::IntegrationConfig::LicenseKeyConfig::FulfillmentMode },
nil?: true

Instance Method Details

#to_hash{

Returns:

  • ({)


170
# File 'sig/dodopayments/models/integration_config.rbs', line 170

def to_hash: -> {