Class: Dodopayments::Models::IntegrationConfigResponse::DigitalFilesConfig::DigitalFiles
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Dodopayments::Models::IntegrationConfigResponse::DigitalFilesConfig::DigitalFiles
- Defined in:
- lib/dodopayments/models/integration_config_response.rb,
sig/dodopayments/models/integration_config_response.rbs
Overview
Defined Under Namespace
Classes: File
Instance Attribute Summary collapse
-
#external_url ⇒ String?
Optional external URL, passed through from the entitlement configuration.
-
#files ⇒ Array<Dodopayments::Models::IntegrationConfigResponse::DigitalFilesConfig::DigitalFiles::File>
One entry per attached file.
-
#instructions ⇒ String?
Optional human-readable delivery instructions, passed through from the entitlement configuration.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
140 |
# File 'sig/dodopayments/models/integration_config_response.rbs', line 140
def initialize: (
|
Instance Attribute Details
#external_url ⇒ String?
Optional external URL, passed through from the entitlement configuration.
159 |
# File 'lib/dodopayments/models/integration_config_response.rb', line 159 optional :external_url, String, nil?: true |
#files ⇒ Array<Dodopayments::Models::IntegrationConfigResponse::DigitalFilesConfig::DigitalFiles::File>
One entry per attached file.
152 153 |
# File 'lib/dodopayments/models/integration_config_response.rb', line 152 required :files, -> { Dodopayments::Internal::Type::ArrayOf[Dodopayments::IntegrationConfigResponse::DigitalFilesConfig::DigitalFiles::File] } |
#instructions ⇒ String?
Optional human-readable delivery instructions, passed through from the entitlement configuration.
166 |
# File 'lib/dodopayments/models/integration_config_response.rb', line 166 optional :instructions, String, nil?: true |
Instance Method Details
#to_hash ⇒ {
146 |
# File 'sig/dodopayments/models/integration_config_response.rbs', line 146
def to_hash: -> {
|