Class: Dodopayments::Models::IntegrationConfigResponse::LicenseKeyConfig
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Dodopayments::Models::IntegrationConfigResponse::LicenseKeyConfig
- Defined in:
- lib/dodopayments/models/integration_config_response.rb,
sig/dodopayments/models/integration_config_response.rbs
Defined Under Namespace
Modules: FulfillmentMode
Instance Attribute Summary collapse
-
#activation_message ⇒ String?
Optional message displayed when a customer activates the license key (≤ 2500 characters).
-
#activations_limit ⇒ Integer?
Maximum activations allowed per issued license key.
-
#duration_count ⇒ Integer?
Validity duration of issued license keys.
-
#duration_interval ⇒ Symbol, ...
Unit of
duration_count. -
#fulfillment_mode ⇒ Symbol, ...
How license keys are fulfilled.
Instance Method Summary collapse
-
#initialize(activation_message: nil, activations_limit: nil, duration_count: nil, duration_interval: nil, fulfillment_mode: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see LicenseKeyConfig for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(activation_message: nil, activations_limit: nil, duration_count: nil, duration_interval: nil, fulfillment_mode: nil) ⇒ Object
Some parameter documentations has been truncated, see Dodopayments::Models::IntegrationConfigResponse::LicenseKeyConfig for more details.
|
|
# File 'lib/dodopayments/models/integration_config_response.rb', line 275
|
Instance Attribute Details
#activation_message ⇒ String?
Optional message displayed when a customer activates the license key (≤ 2500 characters).
243 |
# File 'lib/dodopayments/models/integration_config_response.rb', line 243 optional :activation_message, String, nil?: true |
#activations_limit ⇒ Integer?
Maximum activations allowed per issued license key. Omit for unlimited.
249 |
# File 'lib/dodopayments/models/integration_config_response.rb', line 249 optional :activations_limit, Integer, nil?: true |
#duration_count ⇒ Integer?
Validity duration of issued license keys. Provide both duration_count and
duration_interval together for a fixed duration; omit both for non-expiring
keys.
257 |
# File 'lib/dodopayments/models/integration_config_response.rb', line 257 optional :duration_count, Integer, nil?: true |
#duration_interval ⇒ Symbol, ...
Unit of duration_count.
263 |
# File 'lib/dodopayments/models/integration_config_response.rb', line 263 optional :duration_interval, enum: -> { Dodopayments::TimeInterval }, nil?: true |
#fulfillment_mode ⇒ Symbol, ...
How license keys are fulfilled. auto (default) generates and delivers keys to
customers automatically; manual creates pending grants that you fulfill with
the supplied key via POST /grants/{grant_id}/license-key.
271 272 273 |
# File 'lib/dodopayments/models/integration_config_response.rb', line 271 optional :fulfillment_mode, enum: -> { Dodopayments::IntegrationConfigResponse::LicenseKeyConfig::FulfillmentMode }, nil?: true |
Instance Method Details
#to_hash ⇒ {
224 |
# File 'sig/dodopayments/models/integration_config_response.rbs', line 224
def to_hash: -> {
|