Class: Dodopayments::Models::LicenseActivateResponse::Product

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/dodopayments/models/license_activate_response.rb,
sig/dodopayments/models/license_activate_response.rbs

Overview

See Also:

  • Dodopayments::Models::LicenseActivateResponse#product

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(product_id:, name: nil) ⇒ Product

Related product info. Present if the license key is tied to a product.

Parameters:

  • product_id (String)

    Unique identifier for the product.

  • name (String, nil) (defaults to: nil)

    Name of the product, if set by the merchant.

  • product_id: (String)
  • name: (String, nil) (defaults to: nil)


# File 'lib/dodopayments/models/license_activate_response.rb', line 78

Instance Attribute Details

#nameString?

Name of the product, if set by the merchant.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


76
# File 'lib/dodopayments/models/license_activate_response.rb', line 76

optional :name, String, nil?: true

#product_idString

Unique identifier for the product.

Parameters:

  • value (String)

Returns:

  • (String)


70
# File 'lib/dodopayments/models/license_activate_response.rb', line 70

required :product_id, String

Instance Method Details

#to_hash{ product_id: String, name: String? }

Returns:

  • ({ product_id: String, name: String? })


58
# File 'sig/dodopayments/models/license_activate_response.rbs', line 58

def to_hash: -> { product_id: String, name: String? }