Class: Dodopayments::Models::PaymentCreateParams::ProductCart

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/dodopayments/models/payment_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(product_id:, quantity:, amount: nil) ⇒ Object

Some parameter documentations has been truncated, see Dodopayments::Models::PaymentCreateParams::ProductCart for more details.

Parameters:

  • product_id (String)
  • quantity (Integer)
  • amount (Integer, nil) (defaults to: nil)

    Amount the customer pays if pay_what_you_want is enabled. If disabled then amoun



151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
# File 'lib/dodopayments/models/payment_create_params.rb', line 151

class ProductCart < Dodopayments::Internal::Type::BaseModel
  # @!attribute product_id
  #
  #   @return [String]
  required :product_id, String

  # @!attribute quantity
  #
  #   @return [Integer]
  required :quantity, Integer

  # @!attribute amount
  #   Amount the customer pays if pay_what_you_want is enabled. If disabled then
  #   amount will be ignored Represented in the lowest denomination of the currency
  #   (e.g., cents for USD). For example, to charge $1.00, pass `100`.
  #
  #   @return [Integer, nil]
  optional :amount, Integer, nil?: true

  # @!method initialize(product_id:, quantity:, amount: nil)
  #   Some parameter documentations has been truncated, see
  #   {Dodopayments::Models::PaymentCreateParams::ProductCart} for more details.
  #
  #   @param product_id [String]
  #
  #   @param quantity [Integer]
  #
  #   @param amount [Integer, nil] Amount the customer pays if pay_what_you_want is enabled. If disabled then amoun
end

Instance Attribute Details

#amountInteger?

Amount the customer pays if pay_what_you_want is enabled. If disabled then amount will be ignored Represented in the lowest denomination of the currency (e.g., cents for USD). For example, to charge $1.00, pass ‘100`.

Returns:

  • (Integer, nil)


168
# File 'lib/dodopayments/models/payment_create_params.rb', line 168

optional :amount, Integer, nil?: true

#product_idString

Returns:

  • (String)


155
# File 'lib/dodopayments/models/payment_create_params.rb', line 155

required :product_id, String

#quantityInteger

Returns:

  • (Integer)


160
# File 'lib/dodopayments/models/payment_create_params.rb', line 160

required :quantity, Integer