Class: Dodopayments::Models::PaymentCreateResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Dodopayments::Models::PaymentCreateResponse
- Defined in:
- lib/dodopayments/models/payment_create_response.rb
Overview
Defined Under Namespace
Classes: ProductCart
Instance Attribute Summary collapse
-
#client_secret ⇒ String
Client secret used to load Dodo checkout SDK NOTE : Dodo checkout SDK will be coming soon.
-
#customer ⇒ Dodopayments::Models::CustomerLimitedDetails
Limited details about the customer making the payment.
-
#discount_id ⇒ String?
The discount id if discount is applied.
-
#expires_on ⇒ Time?
Expiry timestamp of the payment link.
-
#metadata ⇒ Hash{Symbol=>String}
Additional metadata associated with the payment.
-
#payment_id ⇒ String
Unique identifier for the payment.
-
#payment_link ⇒ String?
Optional URL to a hosted payment page.
-
#product_cart ⇒ Array<Dodopayments::Models::PaymentCreateResponse::ProductCart>?
Optional list of products included in the payment.
-
#total_amount ⇒ Integer
Total amount of the payment in smallest currency unit (e.g. cents).
Method Summary
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from Dodopayments::Internal::Type::BaseModel
Instance Attribute Details
#client_secret ⇒ String
Client secret used to load Dodo checkout SDK NOTE : Dodo checkout SDK will be coming soon
12 |
# File 'lib/dodopayments/models/payment_create_response.rb', line 12 required :client_secret, String |
#customer ⇒ Dodopayments::Models::CustomerLimitedDetails
Limited details about the customer making the payment
18 |
# File 'lib/dodopayments/models/payment_create_response.rb', line 18 required :customer, -> { Dodopayments::CustomerLimitedDetails } |
#discount_id ⇒ String?
The discount id if discount is applied
42 |
# File 'lib/dodopayments/models/payment_create_response.rb', line 42 optional :discount_id, String, nil?: true |
#expires_on ⇒ Time?
Expiry timestamp of the payment link
48 |
# File 'lib/dodopayments/models/payment_create_response.rb', line 48 optional :expires_on, Time, nil?: true |
#metadata ⇒ Hash{Symbol=>String}
Additional metadata associated with the payment
24 |
# File 'lib/dodopayments/models/payment_create_response.rb', line 24 required :metadata, Dodopayments::Internal::Type::HashOf[String] |
#payment_id ⇒ String
Unique identifier for the payment
30 |
# File 'lib/dodopayments/models/payment_create_response.rb', line 30 required :payment_id, String |
#payment_link ⇒ String?
Optional URL to a hosted payment page
54 |
# File 'lib/dodopayments/models/payment_create_response.rb', line 54 optional :payment_link, String, nil?: true |
#product_cart ⇒ Array<Dodopayments::Models::PaymentCreateResponse::ProductCart>?
Optional list of products included in the payment
60 61 62 |
# File 'lib/dodopayments/models/payment_create_response.rb', line 60 optional :product_cart, -> { Dodopayments::Internal::Type::ArrayOf[Dodopayments::Models::PaymentCreateResponse::ProductCart] }, nil?: true |
#total_amount ⇒ Integer
Total amount of the payment in smallest currency unit (e.g. cents)
36 |
# File 'lib/dodopayments/models/payment_create_response.rb', line 36 required :total_amount, Integer |