Class: Dodopayments::Models::PayoutListResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/dodopayments/models/payout_list_response.rb

Overview

Defined Under Namespace

Modules: Status

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(amount:, business_id:, chargebacks:, created_at:, currency:, fee:, payment_method:, payout_id:, refunds:, status:, tax:, updated_at:, name: nil, payout_document_url: nil, remarks: nil) ⇒ Object

Parameters:

  • amount (Integer)

    The total amount of the payout.

  • business_id (String)

    The unique identifier of the business associated with the payout.

  • chargebacks (Integer)

    The total value of chargebacks associated with the payout.

  • created_at (Time)

    The timestamp when the payout was created, in UTC.

  • currency (Symbol, Dodopayments::Models::Currency)

    The currency of the payout, represented as an ISO 4217 currency code.

  • fee (Integer)

    The fee charged for processing the payout.

  • payment_method (String)

    The payment method used for the payout (e.g., bank transfer, card, etc.).

  • payout_id (String)

    The unique identifier of the payout.

  • refunds (Integer)

    The total value of refunds associated with the payout.

  • status (Symbol, Dodopayments::Models::PayoutListResponse::Status)

    The current status of the payout.

  • tax (Integer)

    The tax applied to the payout.

  • updated_at (Time)

    The timestamp when the payout was last updated, in UTC.

  • name (String, nil) (defaults to: nil)

    The name of the payout recipient or purpose.

  • payout_document_url (String, nil) (defaults to: nil)

    The URL of the document associated with the payout.

  • remarks (String, nil) (defaults to: nil)

    Any additional remarks or notes associated with the payout.



# File 'lib/dodopayments/models/payout_list_response.rb', line 106

Instance Attribute Details

#amountInteger

The total amount of the payout.

Returns:

  • (Integer)


11
# File 'lib/dodopayments/models/payout_list_response.rb', line 11

required :amount, Integer

#business_idString

The unique identifier of the business associated with the payout.

Returns:

  • (String)


17
# File 'lib/dodopayments/models/payout_list_response.rb', line 17

required :business_id, String

#chargebacksInteger

Deprecated.

Use the v3 payout breakup endpoints instead. Will be removed in a future

release.

The total value of chargebacks associated with the payout.

Returns:

  • (Integer)


26
# File 'lib/dodopayments/models/payout_list_response.rb', line 26

required :chargebacks, Integer

#created_atTime

The timestamp when the payout was created, in UTC.

Returns:

  • (Time)


32
# File 'lib/dodopayments/models/payout_list_response.rb', line 32

required :created_at, Time

#currencySymbol, Dodopayments::Models::Currency

The currency of the payout, represented as an ISO 4217 currency code.

Returns:



38
# File 'lib/dodopayments/models/payout_list_response.rb', line 38

required :currency, enum: -> { Dodopayments::Currency }

#feeInteger

The fee charged for processing the payout.

Returns:

  • (Integer)


44
# File 'lib/dodopayments/models/payout_list_response.rb', line 44

required :fee, Integer

#nameString?

The name of the payout recipient or purpose.

Returns:

  • (String, nil)


92
# File 'lib/dodopayments/models/payout_list_response.rb', line 92

optional :name, String, nil?: true

#payment_methodString

The payment method used for the payout (e.g., bank transfer, card, etc.).

Returns:

  • (String)


50
# File 'lib/dodopayments/models/payout_list_response.rb', line 50

required :payment_method, String

#payout_document_urlString?

The URL of the document associated with the payout.

Returns:

  • (String, nil)


98
# File 'lib/dodopayments/models/payout_list_response.rb', line 98

optional :payout_document_url, String, nil?: true

#payout_idString

The unique identifier of the payout.

Returns:

  • (String)


56
# File 'lib/dodopayments/models/payout_list_response.rb', line 56

required :payout_id, String

#refundsInteger

Deprecated.

Use the v3 payout breakup endpoints instead. Will be removed in a future

release.

The total value of refunds associated with the payout.

Returns:

  • (Integer)


65
# File 'lib/dodopayments/models/payout_list_response.rb', line 65

required :refunds, Integer

#remarksString?

Any additional remarks or notes associated with the payout.

Returns:

  • (String, nil)


104
# File 'lib/dodopayments/models/payout_list_response.rb', line 104

optional :remarks, String, nil?: true

#statusSymbol, Dodopayments::Models::PayoutListResponse::Status

The current status of the payout.



71
# File 'lib/dodopayments/models/payout_list_response.rb', line 71

required :status, enum: -> { Dodopayments::Models::PayoutListResponse::Status }

#taxInteger

Deprecated.

Use the v3 payout breakup endpoints instead. Will be removed in a future

release.

The tax applied to the payout.

Returns:

  • (Integer)


80
# File 'lib/dodopayments/models/payout_list_response.rb', line 80

required :tax, Integer

#updated_atTime

The timestamp when the payout was last updated, in UTC.

Returns:

  • (Time)


86
# File 'lib/dodopayments/models/payout_list_response.rb', line 86

required :updated_at, Time