Module: Dodopayments::Models::Payouts

Defined in:
lib/dodopayments/models/payouts/breakup_retrieve_params.rb,
lib/dodopayments/models/payouts/breakup_retrieve_response.rb,
lib/dodopayments/models/payouts/breakup/detail_list_params.rb,
lib/dodopayments/models/payouts/breakup/detail_list_response.rb,
lib/dodopayments/models/payouts/breakup/detail_download_csv_params.rb

Defined Under Namespace

Modules: Breakup Classes: BreakupRetrieveParams, BreakupRetrieveResponseItem

Constant Summary collapse

BreakupRetrieveResponse =
Dodopayments::Internal::Type::ArrayOf[-> { Dodopayments::Models::Payouts::BreakupRetrieveResponseItem }]

Instance Method Summary collapse

Instance Method Details

#initialize(event_type:, total:) ⇒ Object

Some parameter documentations has been truncated, see BreakupRetrieveResponseItem for more details.

Payout breakup aggregated by event type, with amounts in the payout’s currency.

Parameters:

  • event_type (String)

    The type of balance ledger event (e.g., “payment”, “refund”, “dispute”, “payment

  • total (Integer)

    Total amount for this event type in the payout’s currency (in smallest currency



# File 'lib/dodopayments/models/payouts/breakup_retrieve_response.rb', line 21