Class: Dodopayments::Models::Payouts::BreakupRetrieveResponseItem
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Dodopayments::Models::Payouts::BreakupRetrieveResponseItem
- Defined in:
- lib/dodopayments/models/payouts/breakup_retrieve_response.rb,
sig/dodopayments/models/payouts/breakup_retrieve_response.rbs
Instance Attribute Summary collapse
-
#event_type ⇒ String
The type of balance ledger event (e.g., "payment", "refund", "dispute", "payment_fees").
-
#total ⇒ Integer
Total amount for this event type in the payout's currency, in that currency's smallest unit (cents for USD, yen for JPY, fils for KWD).
Instance Method Summary collapse
-
#initialize ⇒ BreakupRetrieveResponseItem
constructor
A new instance of BreakupRetrieveResponseItem.
- #to_hash ⇒ { event_type: String, total: Integer }
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ BreakupRetrieveResponseItem
Returns a new instance of BreakupRetrieveResponseItem.
12 |
# File 'sig/dodopayments/models/payouts/breakup_retrieve_response.rbs', line 12
def initialize: (event_type: String, total: Integer) -> void
|
Instance Attribute Details
#event_type ⇒ String
The type of balance ledger event (e.g., "payment", "refund", "dispute", "payment_fees").
12 |
# File 'lib/dodopayments/models/payouts/breakup_retrieve_response.rb', line 12 required :event_type, String |
#total ⇒ Integer
Total amount for this event type in the payout's currency, in that currency's smallest unit (cents for USD, yen for JPY, fils for KWD).
19 |
# File 'lib/dodopayments/models/payouts/breakup_retrieve_response.rb', line 19 required :total, Integer |
Instance Method Details
#to_hash ⇒ { event_type: String, total: Integer }
14 |
# File 'sig/dodopayments/models/payouts/breakup_retrieve_response.rbs', line 14
def to_hash: -> { event_type: String, total: Integer }
|