Class: Dodopayments::Models::ProductCollectionCreateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/dodopayments/models/product_collection_create_params.rb

Overview

Defined Under Namespace

Modules: EffectiveAtOnDowngrade, EffectiveAtOnUpgrade, OnPaymentFailure, ProrationBillingModeOnDowngrade, ProrationBillingModeOnUpgrade

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(groups:, name:, brand_id: nil, description: nil, effective_at_on_downgrade: nil, effective_at_on_upgrade: nil, on_payment_failure: nil, proration_billing_mode_on_downgrade: nil, proration_billing_mode_on_upgrade: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Dodopayments::Models::ProductCollectionCreateParams for more details.

Parameters:



# File 'lib/dodopayments/models/product_collection_create_params.rb', line 80

Instance Attribute Details

#brand_idString?

Brand id for the collection, if not provided will default to primary brand

Returns:

  • (String, nil)


27
# File 'lib/dodopayments/models/product_collection_create_params.rb', line 27

optional :brand_id, String, nil?: true

#descriptionString?

Optional description of the product collection

Returns:

  • (String, nil)


33
# File 'lib/dodopayments/models/product_collection_create_params.rb', line 33

optional :description, String, nil?: true

#effective_at_on_downgradeSymbol, ...

Default effective_at setting for subscription plan downgrades (NULL = inherit from business)



40
41
42
# File 'lib/dodopayments/models/product_collection_create_params.rb', line 40

optional :effective_at_on_downgrade,
enum: -> { Dodopayments::ProductCollectionCreateParams::EffectiveAtOnDowngrade },
nil?: true

#effective_at_on_upgradeSymbol, ...

Default effective_at setting for subscription plan upgrades (NULL = inherit from business)



49
50
51
# File 'lib/dodopayments/models/product_collection_create_params.rb', line 49

optional :effective_at_on_upgrade,
enum: -> { Dodopayments::ProductCollectionCreateParams::EffectiveAtOnUpgrade },
nil?: true

#groupsArray<Dodopayments::Models::ProductCollections::ProductCollectionGroupDetails>

Groups of products in this collection



14
15
# File 'lib/dodopayments/models/product_collection_create_params.rb', line 14

required :groups,
-> { Dodopayments::Internal::Type::ArrayOf[Dodopayments::ProductCollections::ProductCollectionGroupDetails] }

#nameString

Name of the product collection

Returns:

  • (String)


21
# File 'lib/dodopayments/models/product_collection_create_params.rb', line 21

required :name, String

#on_payment_failureSymbol, ...

Default behavior for subscription plan changes on payment failure (NULL = inherit from business)



58
59
60
# File 'lib/dodopayments/models/product_collection_create_params.rb', line 58

optional :on_payment_failure,
enum: -> { Dodopayments::ProductCollectionCreateParams::OnPaymentFailure },
nil?: true

#proration_billing_mode_on_downgradeSymbol, ...

Default proration billing mode for subscription plan downgrades (NULL = inherit from business)



67
68
69
# File 'lib/dodopayments/models/product_collection_create_params.rb', line 67

optional :proration_billing_mode_on_downgrade,
enum: -> { Dodopayments::ProductCollectionCreateParams::ProrationBillingModeOnDowngrade },
nil?: true

#proration_billing_mode_on_upgradeSymbol, ...

Default proration billing mode for subscription plan upgrades (NULL = inherit from business)



76
77
78
# File 'lib/dodopayments/models/product_collection_create_params.rb', line 76

optional :proration_billing_mode_on_upgrade,
enum: -> { Dodopayments::ProductCollectionCreateParams::ProrationBillingModeOnUpgrade },
nil?: true

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/dodopayments/models/product_collection_create_params.rb', line 112