Class: Dodopayments::Models::ProductCollections::GroupUpdateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Dodopayments::Models::ProductCollections::GroupUpdateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/dodopayments/models/product_collections/group_update_params.rb
Overview
Instance Attribute Summary collapse
- #group_id ⇒ String
-
#group_name ⇒ String?
Optional group name update: Some(Some(name)) = set name, Some(None) = clear name, None = no change.
- #id ⇒ String
-
#product_order ⇒ Array<String>?
Optional new order for products in this group (array of product_collection_group_pdts UUIDs).
-
#status ⇒ Boolean?
Optional status update.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(id:, group_id:, group_name: nil, product_order: nil, status: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see GroupUpdateParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, group_id:, group_name: nil, product_order: nil, status: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Dodopayments::Models::ProductCollections::GroupUpdateParams for more details.
|
|
# File 'lib/dodopayments/models/product_collections/group_update_params.rb', line 41
|
Instance Attribute Details
#group_id ⇒ String
19 |
# File 'lib/dodopayments/models/product_collections/group_update_params.rb', line 19 required :group_id, String |
#group_name ⇒ String?
Optional group name update: Some(Some(name)) = set name, Some(None) = clear name, None = no change
26 |
# File 'lib/dodopayments/models/product_collections/group_update_params.rb', line 26 optional :group_name, String, nil?: true |
#id ⇒ String
14 |
# File 'lib/dodopayments/models/product_collections/group_update_params.rb', line 14 required :id, String |
#product_order ⇒ Array<String>?
Optional new order for products in this group (array of product_collection_group_pdts UUIDs)
33 |
# File 'lib/dodopayments/models/product_collections/group_update_params.rb', line 33 optional :product_order, Dodopayments::Internal::Type::ArrayOf[String], nil?: true |
#status ⇒ Boolean?
Optional status update
39 |
# File 'lib/dodopayments/models/product_collections/group_update_params.rb', line 39 optional :status, Dodopayments::Internal::Type::Boolean, nil?: true |