Class: Dodopayments::Models::ProductCreateParams::DigitalProductDelivery
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Dodopayments::Models::ProductCreateParams::DigitalProductDelivery
- Defined in:
- lib/dodopayments/models/product_create_params.rb
Instance Attribute Summary collapse
-
#external_url ⇒ String?
External URL to digital product.
-
#instructions ⇒ String?
Instructions to download and use the digital product.
Instance Method Summary collapse
-
#initialize(external_url: nil, instructions: nil) ⇒ Object
constructor
Choose how you would like you digital product delivered.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(external_url: nil, instructions: nil) ⇒ Object
Choose how you would like you digital product delivered
deprecated: use entitlements instead
157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 |
# File 'lib/dodopayments/models/product_create_params.rb', line 157 class DigitalProductDelivery < Dodopayments::Internal::Type::BaseModel # @!attribute external_url # External URL to digital product # # @return [String, nil] optional :external_url, String, nil?: true # @!attribute instructions # Instructions to download and use the digital product # # @return [String, nil] optional :instructions, String, nil?: true # @!method initialize(external_url: nil, instructions: nil) # Choose how you would like you digital product delivered # # deprecated: use entitlements instead # # @param external_url [String, nil] External URL to digital product # # @param instructions [String, nil] Instructions to download and use the digital product end |
Instance Attribute Details
#external_url ⇒ String?
External URL to digital product
162 |
# File 'lib/dodopayments/models/product_create_params.rb', line 162 optional :external_url, String, nil?: true |
#instructions ⇒ String?
Instructions to download and use the digital product
168 |
# File 'lib/dodopayments/models/product_create_params.rb', line 168 optional :instructions, String, nil?: true |