Class: Dodopayments::Models::ProductUpdateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/dodopayments/models/product_update_params.rb,
sig/dodopayments/models/product_update_params.rbs

Overview

See Also:

  • Dodopayments::Resources::Products#update

Defined Under Namespace

Classes: DigitalProductDelivery

Constant Summary

Constants included from Internal::Type::RequestParameters

Internal::Type::RequestParameters::Dodopayments

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeObject



63
# File 'sig/dodopayments/models/product_update_params.rbs', line 63

def initialize: (

Instance Attribute Details

#addonsArray<String>?

Available Addons for subscription products

Parameters:

  • value (::Array[String], nil)

Returns:

  • (Array<String>, nil)


19
# File 'lib/dodopayments/models/product_update_params.rb', line 19

optional :addons, Dodopayments::Internal::Type::ArrayOf[String], nil?: true

#brand_idString?

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


24
# File 'lib/dodopayments/models/product_update_params.rb', line 24

optional :brand_id, String, nil?: true

#credit_entitlementsArray<Dodopayments::Models::AttachCreditEntitlement>?

Credit entitlements to update (replaces all existing when present) Send empty array to remove all, omit field to leave unchanged

Parameters:

Returns:



31
32
33
# File 'lib/dodopayments/models/product_update_params.rb', line 31

optional :credit_entitlements,
-> { Dodopayments::Internal::Type::ArrayOf[Dodopayments::AttachCreditEntitlement] },
nil?: true

#descriptionString?

Description of the product, optional and must be at most 1000 characters.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


39
# File 'lib/dodopayments/models/product_update_params.rb', line 39

optional :description, String, nil?: true

#digital_product_deliveryDodopayments::Models::ProductUpdateParams::DigitalProductDelivery?

Choose how you would like you digital product delivered

deprecated: use entitlements instead

Parameters:

  • value (Dodopayments::ProductUpdateParams::DigitalProductDelivery, nil)

Returns:



47
48
49
# File 'lib/dodopayments/models/product_update_params.rb', line 47

optional :digital_product_delivery,
-> { Dodopayments::ProductUpdateParams::DigitalProductDelivery },
nil?: true

#entitlementsArray<Dodopayments::Models::AttachProductEntitlement>?

Entitlements to attach (replaces all existing when present) Send empty array to remove all, omit field to leave unchanged

Parameters:

Returns:



56
57
58
# File 'lib/dodopayments/models/product_update_params.rb', line 56

optional :entitlements,
-> { Dodopayments::Internal::Type::ArrayOf[Dodopayments::AttachProductEntitlement] },
nil?: true

#idString

Parameters:

  • value (String)

Returns:

  • (String)


13
# File 'lib/dodopayments/models/product_update_params.rb', line 13

required :id, String

#image_idString?

Product image id after its uploaded to S3

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


64
# File 'lib/dodopayments/models/product_update_params.rb', line 64

optional :image_id, String, nil?: true

#license_key_activation_messageString?

Deprecated.

Use the dedicated entitlements API to configure license-key delivery.

Message sent to the customer upon license key activation.

Only applicable if license_key_enabled is true. This message contains instructions for activating the license key.

deprecated: use entitlements instead

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


77
# File 'lib/dodopayments/models/product_update_params.rb', line 77

optional :license_key_activation_message, String, nil?: true

#license_key_activations_limitInteger?

Deprecated.

Use the dedicated entitlements API to configure license-key delivery.

Limit for the number of activations for the license key.

Only applicable if license_key_enabled is true. Represents the maximum number of times the license key can be activated.

deprecated: use entitlements instead

Parameters:

  • value (Integer, nil)

Returns:

  • (Integer, nil)


90
# File 'lib/dodopayments/models/product_update_params.rb', line 90

optional :license_key_activations_limit, Integer, nil?: true

#license_key_durationDodopayments::Models::LicenseKeyDuration?

Duration of the license key if enabled.

Only applicable if license_key_enabled is true. Represents the duration in days for which the license key is valid.

deprecated: use entitlements instead



101
# File 'lib/dodopayments/models/product_update_params.rb', line 101

optional :license_key_duration, -> { Dodopayments::LicenseKeyDuration }, nil?: true

#license_key_enabledBoolean?

Deprecated.

Use the dedicated entitlements API to configure license-key delivery.

Whether the product requires a license key.

If true, additional fields related to license key (duration, activations limit, activation message) become applicable.

deprecated: use entitlements instead

Parameters:

  • value (Boolean, nil)

Returns:

  • (Boolean, nil)


114
# File 'lib/dodopayments/models/product_update_params.rb', line 114

optional :license_key_enabled, Dodopayments::Internal::Type::Boolean, nil?: true

#metadataHash{Symbol=>String, Float, Boolean}?

Additional metadata for the product

Parameters:

  • value (Dodopayments::Models::metadata, nil)

Returns:

  • (Hash{Symbol=>String, Float, Boolean}, nil)


120
121
122
# File 'lib/dodopayments/models/product_update_params.rb', line 120

optional :metadata,
-> { Dodopayments::Internal::Type::HashOf[union: Dodopayments::MetadataItem] },
nil?: true

#nameString?

Name of the product, optional and must be at most 100 characters.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


128
# File 'lib/dodopayments/models/product_update_params.rb', line 128

optional :name, String, nil?: true

#priceDodopayments::Models::Price::OneTimePrice, ...

Price details of the product.



134
# File 'lib/dodopayments/models/product_update_params.rb', line 134

optional :price, union: -> { Dodopayments::Price }, nil?: true

#pricing_modeSymbol, ...

Update the pricing mode. Omit to leave unchanged; set to null to clear (which archives all active localized rules for this product). Changing to a different non-null mode also archives any rules whose mode doesn't match the new mode.

Parameters:

  • value (Dodopayments::Models::Products::pricing_mode, nil)

Returns:



142
# File 'lib/dodopayments/models/product_update_params.rb', line 142

optional :pricing_mode, enum: -> { Dodopayments::Products::PricingMode }, nil?: true

#tax_categorySymbol, ...

Tax category of the product.

Parameters:

  • value (Dodopayments::Models::tax_category, nil)

Returns:



148
# File 'lib/dodopayments/models/product_update_params.rb', line 148

optional :tax_category, enum: -> { Dodopayments::TaxCategory }, nil?: true

Instance Method Details

#to_hash{

Returns:

  • ({)


84
# File 'sig/dodopayments/models/product_update_params.rbs', line 84

def to_hash: -> {