Module: Dodopayments::Models::ProductUpdateParams::PricingMode

Extended by:
Internal::Type::Enum
Defined in:
lib/dodopayments/models/product_update_params.rb

Overview

Update the pricing mode. Omit to leave unchanged; set to null to clear (which archives all active localized rules for this product). Changing to a different non-null mode also archives any rules whose mode doesn’t match the new mode.

Constant Summary collapse

BY_CURRENCY =
:by_currency
BY_COUNTRY =
:by_country

Class Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/dodopayments/models/product_update_params.rb', line 228