Class: Dodopayments::Models::RefundListItem

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/dodopayments/models/refund_list_item.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(business_id:, created_at:, is_partial:, payment_id:, refund_id:, status:, amount: nil, currency: nil, reason: nil) ⇒ Object

Parameters:

  • business_id (String)

    The unique identifier of the business issuing the refund.

  • created_at (Time)

    The timestamp of when the refund was created in UTC.

  • is_partial (Boolean)

    If true the refund is a partial refund

  • payment_id (String)

    The unique identifier of the payment associated with the refund.

  • refund_id (String)

    The unique identifier of the refund.

  • status (Symbol, Dodopayments::Models::RefundStatus)

    The current status of the refund.

  • amount (Integer, nil) (defaults to: nil)

    The refunded amount.

  • currency (Symbol, Dodopayments::Models::Currency, nil) (defaults to: nil)

    The currency of the refund, represented as an ISO 4217 currency code.

  • reason (String, nil) (defaults to: nil)

    The reason provided for the refund, if any. Optional.



# File 'lib/dodopayments/models/refund_list_item.rb', line 60

Instance Attribute Details

#amountInteger?

The refunded amount.

Returns:

  • (Integer, nil)


46
# File 'lib/dodopayments/models/refund_list_item.rb', line 46

optional :amount, Integer, nil?: true

#business_idString

The unique identifier of the business issuing the refund.

Returns:

  • (String)


10
# File 'lib/dodopayments/models/refund_list_item.rb', line 10

required :business_id, String

#created_atTime

The timestamp of when the refund was created in UTC.

Returns:

  • (Time)


16
# File 'lib/dodopayments/models/refund_list_item.rb', line 16

required :created_at, Time

#currencySymbol, ...

The currency of the refund, represented as an ISO 4217 currency code.

Returns:



52
# File 'lib/dodopayments/models/refund_list_item.rb', line 52

optional :currency, enum: -> { Dodopayments::Currency }, nil?: true

#is_partialBoolean

If true the refund is a partial refund

Returns:

  • (Boolean)


22
# File 'lib/dodopayments/models/refund_list_item.rb', line 22

required :is_partial, Dodopayments::Internal::Type::Boolean

#payment_idString

The unique identifier of the payment associated with the refund.

Returns:

  • (String)


28
# File 'lib/dodopayments/models/refund_list_item.rb', line 28

required :payment_id, String

#reasonString?

The reason provided for the refund, if any. Optional.

Returns:

  • (String, nil)


58
# File 'lib/dodopayments/models/refund_list_item.rb', line 58

optional :reason, String, nil?: true

#refund_idString

The unique identifier of the refund.

Returns:

  • (String)


34
# File 'lib/dodopayments/models/refund_list_item.rb', line 34

required :refund_id, String

#statusSymbol, Dodopayments::Models::RefundStatus

The current status of the refund.



40
# File 'lib/dodopayments/models/refund_list_item.rb', line 40

required :status, enum: -> { Dodopayments::RefundStatus }