Class: Dodopayments::Models::SubscriptionCreateParams::OneTimeProductCart

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/dodopayments/models/subscription_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(product_id:, quantity:, amount: nil) ⇒ Object

Some parameter documentations has been truncated, see Dodopayments::Models::SubscriptionCreateParams::OneTimeProductCart for more details.

Parameters:

  • product_id (String)
  • quantity (Integer)
  • amount (Integer, nil) (defaults to: nil)

    Amount the customer pays if pay_what_you_want is enabled. If disabled then amoun



193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
# File 'lib/dodopayments/models/subscription_create_params.rb', line 193

class OneTimeProductCart < Dodopayments::Internal::Type::BaseModel
  # @!attribute product_id
  #
  #   @return [String]
  required :product_id, String

  # @!attribute quantity
  #
  #   @return [Integer]
  required :quantity, Integer

  # @!attribute amount
  #   Amount the customer pays if pay_what_you_want is enabled. If disabled then
  #   amount will be ignored Represented in the lowest denomination of the currency
  #   (e.g., cents for USD). For example, to charge $1.00, pass `100`.
  #
  #   @return [Integer, nil]
  optional :amount, Integer, nil?: true

  # @!method initialize(product_id:, quantity:, amount: nil)
  #   Some parameter documentations has been truncated, see
  #   {Dodopayments::Models::SubscriptionCreateParams::OneTimeProductCart} for more
  #   details.
  #
  #   @param product_id [String]
  #
  #   @param quantity [Integer]
  #
  #   @param amount [Integer, nil] Amount the customer pays if pay_what_you_want is enabled. If disabled then amoun
end

Instance Attribute Details

#amountInteger?

Amount the customer pays if pay_what_you_want is enabled. If disabled then amount will be ignored Represented in the lowest denomination of the currency (e.g., cents for USD). For example, to charge $1.00, pass ‘100`.

Returns:

  • (Integer, nil)


210
# File 'lib/dodopayments/models/subscription_create_params.rb', line 210

optional :amount, Integer, nil?: true

#product_idString

Returns:

  • (String)


197
# File 'lib/dodopayments/models/subscription_create_params.rb', line 197

required :product_id, String

#quantityInteger

Returns:

  • (Integer)


202
# File 'lib/dodopayments/models/subscription_create_params.rb', line 202

required :quantity, Integer