Class: Dodopayments::Models::SubscriptionCreateResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Dodopayments::Models::SubscriptionCreateResponse
- Defined in:
- lib/dodopayments/models/subscription_create_response.rb,
sig/dodopayments/models/subscription_create_response.rbs
Overview
Defined Under Namespace
Classes: OneTimeProductCart
Instance Attribute Summary collapse
-
#addons ⇒ Array<Dodopayments::Models::AddonCartResponseItem>
Addons associated with this subscription.
-
#client_secret ⇒ String?
Client secret used to load Dodo checkout SDK NOTE : Dodo checkout SDK will be coming soon.
-
#customer ⇒ Dodopayments::Models::CustomerLimitedDetails
Customer details associated with this subscription.
-
#discount_id ⇒ String?
deprecated
Deprecated.
Use
discountsinstead. -
#discount_ids ⇒ Array<String>?
All stacked discount IDs applied, in order of application.
-
#expires_on ⇒ Time?
Expiry timestamp of the payment link.
-
#metadata ⇒ Hash{Symbol=>String, Float, Boolean}
Additional metadata associated with the subscription.
-
#one_time_product_cart ⇒ Array<Dodopayments::Models::SubscriptionCreateResponse::OneTimeProductCart>?
One time products associated with the purchase of subscription.
-
#payment_id ⇒ String
First payment id for the subscription.
-
#payment_link ⇒ String?
URL to checkout page.
-
#payment_method_required ⇒ Boolean
False when the customer can start this subscription with no card.
-
#recurring_pre_tax_amount ⇒ Integer
Tax will be added to the amount and charged to the customer on each billing cycle.
-
#subscription_id ⇒ String
Unique identifier for the subscription.
-
#trial_amount ⇒ Integer?
Per-unit trial amount after discounts, in the price currency's minor units (pre-quantity, pre-tax).
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
50 |
# File 'sig/dodopayments/models/subscription_create_response.rbs', line 50
def initialize: (
|
Instance Attribute Details
#addons ⇒ Array<Dodopayments::Models::AddonCartResponseItem>
Addons associated with this subscription
11 |
# File 'lib/dodopayments/models/subscription_create_response.rb', line 11 required :addons, -> { Dodopayments::Internal::Type::ArrayOf[Dodopayments::AddonCartResponseItem] } |
#client_secret ⇒ String?
Client secret used to load Dodo checkout SDK NOTE : Dodo checkout SDK will be coming soon
56 |
# File 'lib/dodopayments/models/subscription_create_response.rb', line 56 optional :client_secret, String, nil?: true |
#customer ⇒ Dodopayments::Models::CustomerLimitedDetails
Customer details associated with this subscription
17 |
# File 'lib/dodopayments/models/subscription_create_response.rb', line 17 required :customer, -> { Dodopayments::CustomerLimitedDetails } |
#discount_id ⇒ String?
Use discounts instead.
DEPRECATED: Use discount_ids instead. Returns the first discount's ID if present.
65 |
# File 'lib/dodopayments/models/subscription_create_response.rb', line 65 optional :discount_id, String, nil?: true |
#discount_ids ⇒ Array<String>?
All stacked discount IDs applied, in order of application
71 |
# File 'lib/dodopayments/models/subscription_create_response.rb', line 71 optional :discount_ids, Dodopayments::Internal::Type::ArrayOf[String], nil?: true |
#expires_on ⇒ Time?
Expiry timestamp of the payment link
77 |
# File 'lib/dodopayments/models/subscription_create_response.rb', line 77 optional :expires_on, Time, nil?: true |
#metadata ⇒ Hash{Symbol=>String, Float, Boolean}
Additional metadata associated with the subscription
23 |
# File 'lib/dodopayments/models/subscription_create_response.rb', line 23 required :metadata, -> { Dodopayments::Internal::Type::HashOf[union: Dodopayments::MetadataItem] } |
#one_time_product_cart ⇒ Array<Dodopayments::Models::SubscriptionCreateResponse::OneTimeProductCart>?
One time products associated with the purchase of subscription
83 84 85 |
# File 'lib/dodopayments/models/subscription_create_response.rb', line 83 optional :one_time_product_cart, -> { Dodopayments::Internal::Type::ArrayOf[Dodopayments::Models::SubscriptionCreateResponse::OneTimeProductCart] }, nil?: true |
#payment_id ⇒ String
First payment id for the subscription
29 |
# File 'lib/dodopayments/models/subscription_create_response.rb', line 29 required :payment_id, String |
#payment_link ⇒ String?
URL to checkout page
91 |
# File 'lib/dodopayments/models/subscription_create_response.rb', line 91 optional :payment_link, String, nil?: true |
#payment_method_required ⇒ Boolean
False when the customer can start this subscription with no card. True for every other subscription.
36 |
# File 'lib/dodopayments/models/subscription_create_response.rb', line 36 required :payment_method_required, Dodopayments::Internal::Type::Boolean |
#recurring_pre_tax_amount ⇒ Integer
Tax will be added to the amount and charged to the customer on each billing cycle
43 |
# File 'lib/dodopayments/models/subscription_create_response.rb', line 43 required :recurring_pre_tax_amount, Integer |
#subscription_id ⇒ String
Unique identifier for the subscription
49 |
# File 'lib/dodopayments/models/subscription_create_response.rb', line 49 required :subscription_id, String |
#trial_amount ⇒ Integer?
Per-unit trial amount after discounts, in the price currency's minor units (pre-quantity, pre-tax). Null for a free trial or no trial.
98 |
# File 'lib/dodopayments/models/subscription_create_response.rb', line 98 optional :trial_amount, Integer, nil?: true |
Instance Method Details
#to_hash ⇒ {
67 |
# File 'sig/dodopayments/models/subscription_create_response.rbs', line 67
def to_hash: -> {
|