Class: Dodopayments::Models::SubscriptionListResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/dodopayments/models/subscription_list_response.rb

Overview

Defined Under Namespace

Classes: Discount

Instance Attribute Summary collapse

Method Summary

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

This class inherits a constructor from Dodopayments::Internal::Type::BaseModel

Instance Attribute Details

#billingDodopayments::Models::BillingAddress

Billing address details for payments



11
# File 'lib/dodopayments/models/subscription_list_response.rb', line 11

required :billing, -> { Dodopayments::BillingAddress }

#cancel_at_next_billing_dateBoolean

Indicates if the subscription will cancel at the next billing date

Returns:

  • (Boolean)


17
# File 'lib/dodopayments/models/subscription_list_response.rb', line 17

required :cancel_at_next_billing_date, Dodopayments::Internal::Type::Boolean

#cancelled_atTime?

Cancelled timestamp if the subscription is cancelled

Returns:

  • (Time, nil)


140
# File 'lib/dodopayments/models/subscription_list_response.rb', line 140

optional :cancelled_at, Time, nil?: true

#created_atTime

Timestamp when the subscription was created

Returns:

  • (Time)


23
# File 'lib/dodopayments/models/subscription_list_response.rb', line 23

required :created_at, Time

#currencySymbol, Dodopayments::Models::Currency

Currency used for the subscription payments

Returns:



29
# File 'lib/dodopayments/models/subscription_list_response.rb', line 29

required :currency, enum: -> { Dodopayments::Currency }

#customerDodopayments::Models::CustomerLimitedDetails

Customer details associated with the subscription



35
# File 'lib/dodopayments/models/subscription_list_response.rb', line 35

required :customer, -> { Dodopayments::CustomerLimitedDetails }

#discount_cycles_remainingInteger?

DEPRECATED: Use discounts[].cycles_remaining instead.

Returns:

  • (Integer, nil)


146
# File 'lib/dodopayments/models/subscription_list_response.rb', line 146

optional :discount_cycles_remaining, Integer, nil?: true

#discount_idString?

DEPRECATED: Use discounts instead.

Returns:

  • (String, nil)


152
# File 'lib/dodopayments/models/subscription_list_response.rb', line 152

optional :discount_id, String, nil?: true

#discountsArray<Dodopayments::Models::SubscriptionListResponse::Discount>

All stacked discounts applied, in order of application



41
42
# File 'lib/dodopayments/models/subscription_list_response.rb', line 41

required :discounts,
-> { Dodopayments::Internal::Type::ArrayOf[Dodopayments::Models::SubscriptionListResponse::Discount] }

#metadataHash{Symbol=>String}

Additional custom data associated with the subscription

Returns:

  • (Hash{Symbol=>String})


48
# File 'lib/dodopayments/models/subscription_list_response.rb', line 48

required :metadata, Dodopayments::Internal::Type::HashOf[String]

#next_billing_dateTime

Timestamp of the next scheduled billing. Indicates the end of current billing period

Returns:

  • (Time)


55
# File 'lib/dodopayments/models/subscription_list_response.rb', line 55

required :next_billing_date, Time

#on_demandBoolean

Wether the subscription is on-demand or not

Returns:

  • (Boolean)


61
# File 'lib/dodopayments/models/subscription_list_response.rb', line 61

required :on_demand, Dodopayments::Internal::Type::Boolean

#payment_frequency_countInteger

Number of payment frequency intervals

Returns:

  • (Integer)


67
# File 'lib/dodopayments/models/subscription_list_response.rb', line 67

required :payment_frequency_count, Integer

#payment_frequency_intervalSymbol, Dodopayments::Models::TimeInterval

Time interval for payment frequency (e.g. month, year)



73
# File 'lib/dodopayments/models/subscription_list_response.rb', line 73

required :payment_frequency_interval, enum: -> { Dodopayments::TimeInterval }

#payment_method_idString?

Saved payment method id used for recurring charges

Returns:

  • (String, nil)


158
# File 'lib/dodopayments/models/subscription_list_response.rb', line 158

optional :payment_method_id, String, nil?: true

#previous_billing_dateTime

Timestamp of the last payment. Indicates the start of current billing period

Returns:

  • (Time)


79
# File 'lib/dodopayments/models/subscription_list_response.rb', line 79

required :previous_billing_date, Time

#product_idString

Identifier of the product associated with this subscription

Returns:

  • (String)


85
# File 'lib/dodopayments/models/subscription_list_response.rb', line 85

required :product_id, String

#product_nameString?

Name of the product associated with this subscription

Returns:

  • (String, nil)


164
# File 'lib/dodopayments/models/subscription_list_response.rb', line 164

optional :product_name, String, nil?: true

#quantityInteger

Number of units/items included in the subscription

Returns:

  • (Integer)


91
# File 'lib/dodopayments/models/subscription_list_response.rb', line 91

required :quantity, Integer

#recurring_pre_tax_amountInteger

Amount charged before tax for each recurring payment in smallest currency unit (e.g. cents)

Returns:

  • (Integer)


98
# File 'lib/dodopayments/models/subscription_list_response.rb', line 98

required :recurring_pre_tax_amount, Integer

#scheduled_changeDodopayments::Models::ScheduledPlanChange?

Scheduled plan change details, if any



170
# File 'lib/dodopayments/models/subscription_list_response.rb', line 170

optional :scheduled_change, -> { Dodopayments::ScheduledPlanChange }, nil?: true

#statusSymbol, Dodopayments::Models::SubscriptionStatus

Current status of the subscription



104
# File 'lib/dodopayments/models/subscription_list_response.rb', line 104

required :status, enum: -> { Dodopayments::SubscriptionStatus }

#subscription_idString

Unique identifier for the subscription

Returns:

  • (String)


110
# File 'lib/dodopayments/models/subscription_list_response.rb', line 110

required :subscription_id, String

#subscription_period_countInteger

Number of subscription period intervals

Returns:

  • (Integer)


116
# File 'lib/dodopayments/models/subscription_list_response.rb', line 116

required :subscription_period_count, Integer

#subscription_period_intervalSymbol, Dodopayments::Models::TimeInterval

Time interval for the subscription period (e.g. month, year)



122
# File 'lib/dodopayments/models/subscription_list_response.rb', line 122

required :subscription_period_interval, enum: -> { Dodopayments::TimeInterval }

#tax_idString?

Tax identifier provided for this subscription (if applicable)

Returns:

  • (String, nil)


176
# File 'lib/dodopayments/models/subscription_list_response.rb', line 176

optional :tax_id, String, nil?: true

#tax_inclusiveBoolean

Indicates if the recurring_pre_tax_amount is tax inclusive

Returns:

  • (Boolean)


128
# File 'lib/dodopayments/models/subscription_list_response.rb', line 128

required :tax_inclusive, Dodopayments::Internal::Type::Boolean

#trial_period_daysInteger

Number of days in the trial period (0 if no trial)

Returns:

  • (Integer)


134
# File 'lib/dodopayments/models/subscription_list_response.rb', line 134

required :trial_period_days, Integer