Class: Dodopayments::Models::SubscriptionPreviewChangePlanResponse::ImmediateCharge::LineItem::Addon
Defined Under Namespace
Modules: Type
Instance Attribute Summary collapse
Instance Method Summary
collapse
-
#initialize(id:, currency:, name:, proration_factor:, quantity:, tax_category:, tax_inclusive:, tax_rate:, type:, unit_price:, description: nil, tax: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Addon for more details.
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, currency:, name:, proration_factor:, quantity:, tax_category:, tax_inclusive:, tax_rate:, type:, unit_price:, description: nil, tax: nil) ⇒ Object
|
# File 'lib/dodopayments/models/subscription_preview_change_plan_response.rb', line 211
|
Instance Attribute Details
156
|
# File 'lib/dodopayments/models/subscription_preview_change_plan_response.rb', line 156
required :currency, enum: -> { Dodopayments::Currency }
|
#description ⇒ String?
204
|
# File 'lib/dodopayments/models/subscription_preview_change_plan_response.rb', line 204
optional :description, String, nil?: true
|
#id ⇒ String
151
|
# File 'lib/dodopayments/models/subscription_preview_change_plan_response.rb', line 151
required :id, String
|
#name ⇒ String
161
|
# File 'lib/dodopayments/models/subscription_preview_change_plan_response.rb', line 161
required :name, String
|
#proration_factor ⇒ Float
166
|
# File 'lib/dodopayments/models/subscription_preview_change_plan_response.rb', line 166
required :proration_factor, Float
|
#quantity ⇒ Integer
171
|
# File 'lib/dodopayments/models/subscription_preview_change_plan_response.rb', line 171
required :quantity, Integer
|
#tax ⇒ Integer?
209
|
# File 'lib/dodopayments/models/subscription_preview_change_plan_response.rb', line 209
optional :tax, Integer, nil?: true
|
Represents the different categories of taxation applicable to various products and services.
178
|
# File 'lib/dodopayments/models/subscription_preview_change_plan_response.rb', line 178
required :tax_category, enum: -> { Dodopayments::TaxCategory }
|
#tax_rate ⇒ Float
188
|
# File 'lib/dodopayments/models/subscription_preview_change_plan_response.rb', line 188
required :tax_rate, Float
|
#unit_price ⇒ Integer
199
|
# File 'lib/dodopayments/models/subscription_preview_change_plan_response.rb', line 199
required :unit_price, Integer
|