Class: Dodopayments::Models::SubscriptionRetrieveUsageHistoryResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Dodopayments::Models::SubscriptionRetrieveUsageHistoryResponse
- Defined in:
- lib/dodopayments/models/subscription_retrieve_usage_history_response.rb,
sig/dodopayments/models/subscription_retrieve_usage_history_response.rbs
Overview
Defined Under Namespace
Classes: Meter
Instance Attribute Summary collapse
-
#end_date ⇒ Time
End date of the billing period.
-
#meters ⇒ Array<Dodopayments::Models::SubscriptionRetrieveUsageHistoryResponse::Meter>
List of meters and their usage for this billing period.
-
#start_date ⇒ Time
Start date of the billing period.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
17 |
# File 'sig/dodopayments/models/subscription_retrieve_usage_history_response.rbs', line 17
def initialize: (
|
Instance Attribute Details
#end_date ⇒ Time
End date of the billing period
11 |
# File 'lib/dodopayments/models/subscription_retrieve_usage_history_response.rb', line 11 required :end_date, Time |
#meters ⇒ Array<Dodopayments::Models::SubscriptionRetrieveUsageHistoryResponse::Meter>
List of meters and their usage for this billing period
17 18 |
# File 'lib/dodopayments/models/subscription_retrieve_usage_history_response.rb', line 17 required :meters, -> { Dodopayments::Internal::Type::ArrayOf[Dodopayments::Models::SubscriptionRetrieveUsageHistoryResponse::Meter] } |
#start_date ⇒ Time
Start date of the billing period
24 |
# File 'lib/dodopayments/models/subscription_retrieve_usage_history_response.rb', line 24 required :start_date, Time |
Instance Method Details
#to_hash ⇒ {
23 |
# File 'sig/dodopayments/models/subscription_retrieve_usage_history_response.rbs', line 23
def to_hash: -> {
|