Module: Dodopayments::Internal::Type::Union Private
- Includes:
- Converter, Util::SorbetRuntimeSupport
- Included in:
- Models::Blocklist::BlockIdentifier, Models::Blocklist::CreateBlockedCustomerRequest, Models::CustomerRequest, Models::Event::Metadata, Models::EventInput::Metadata, Models::FilterType, Models::FilterType::MeterFilterConditionList::Value, Models::IntegrationConfig, Models::IntegrationConfigResponse, Models::MetadataItem, Models::Price, Models::SubscriptionPreviewChangePlanResponse::ImmediateCharge::LineItem, Models::SubscriptionUpdatePaymentMethodParams::PaymentMethod, Models::UnsafeUnwrapWebhookEvent, Models::UnwrapWebhookEvent, Models::WebhookPayload::Data
- Defined in:
- lib/dodopayments/internal/type/union.rb,
sig/dodopayments/internal/type/union.rbs
Overview
This module is part of a private API. You should avoid using this module if possible, as it may be removed or be changed in the future.
Class Method Summary collapse
- .derefed_variants ⇒ ::Array[[Symbol?, top, ::Hash[Symbol, top]]] private
- .variants ⇒ ::Array[top] private
Instance Method Summary collapse
- #==(other) ⇒ Boolean
- #===(other) ⇒ Boolean
-
#coerce(value, state:) ⇒ Object
private
Tries to efficiently coerce the given value to one of the known variants.
- #dump(value, state:) ⇒ Object private
- #hash ⇒ Integer
- #inspect(depth: 0) ⇒ String private
- #to_sorbet_type ⇒ Object private
-
#variants ⇒ Array<Object>
private
All of the specified variants for this union.
Methods included from Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, to_sorbet_type
Methods included from Converter
coerce, dump, inspect, meta_info, new_coerce_state, type_info
Class Method Details
.derefed_variants ⇒ ::Array[[Symbol?, top, ::Hash[Symbol, top]]]
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
10 |
# File 'sig/dodopayments/internal/type/union.rbs', line 10
def self.derefed_variants: -> ::Array[[Symbol?, top, ::Hash[Symbol, top]]]
|
.variants ⇒ ::Array[top]
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
12 |
# File 'sig/dodopayments/internal/type/union.rbs', line 12
def self.variants: -> ::Array[top]
|
Instance Method Details
#==(other) ⇒ Boolean
144 145 146 |
# File 'lib/dodopayments/internal/type/union.rb', line 144 def ==(other) Dodopayments::Internal::Type::Union === other && other.derefed_variants == derefed_variants end |
#===(other) ⇒ Boolean
133 134 135 136 137 |
# File 'lib/dodopayments/internal/type/union.rb', line 133 def ===(other) known_variants.any? do |_, variant_fn| variant_fn.call === other end end |
#coerce(value, state:) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Tries to efficiently coerce the given value to one of the known variants.
If the value cannot match any of the known variants, the coercion is considered non-viable and returns the original value.
175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 |
# File 'lib/dodopayments/internal/type/union.rb', line 175 def coerce(value, state:) if (target = resolve_variant(value)) return Dodopayments::Internal::Type::Converter.coerce(target, value, state: state) end strictness = state.fetch(:strictness) exactness = state.fetch(:exactness) alternatives = [] known_variants.each do |_, variant_fn| target = variant_fn.call exact = state[:exactness] = {yes: 0, no: 0, maybe: 0} state[:branched] += 1 coerced = Dodopayments::Internal::Type::Converter.coerce(target, value, state: state) yes, no, maybe = exact.values if (no + maybe).zero? || (!strictness && yes.positive?) exact.each { exactness[_1] += _2 } state[:exactness] = exactness return coerced elsif maybe.positive? alternatives << [[-yes, -maybe, no], exact, coerced] end end case alternatives.sort_by!(&:first) in [] exactness[:no] += 1 state[:error] = ArgumentError.new("no matching variant for #{value.inspect}") value in [[_, exact, coerced], *] exact.each { exactness[_1] += _2 } coerced end .tap { state[:exactness] = exactness } ensure state[:strictness] = strictness end |
#dump(value, state:) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 |
# File 'lib/dodopayments/internal/type/union.rb', line 223 def dump(value, state:) if (target = resolve_variant(value)) return Dodopayments::Internal::Type::Converter.dump(target, value, state: state) end known_variants.each do target = _2.call if target === value return Dodopayments::Internal::Type::Converter.dump( target, value, state: state ) end end super end |
#hash ⇒ Integer
151 |
# File 'lib/dodopayments/internal/type/union.rb', line 151 def hash = variants.hash |
#inspect(depth: 0) ⇒ String
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
265 266 267 268 269 270 271 272 273 274 |
# File 'lib/dodopayments/internal/type/union.rb', line 265 def inspect(depth: 0) if depth.positive? return is_a?(Module) ? super() : self.class.name end members = variants.map { Dodopayments::Internal::Type::Converter.inspect(_1, depth: depth.succ) } prefix = is_a?(Module) ? name : self.class.name "#{prefix}[#{members.join(' | ')}]" end |
#to_sorbet_type ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
245 246 247 248 249 250 251 252 253 254 255 |
# File 'lib/dodopayments/internal/type/union.rb', line 245 def to_sorbet_type types = variants.map { Dodopayments::Internal::Util::SorbetRuntimeSupport.to_sorbet_type(_1) }.uniq case types in [] T.noreturn in [type] type else T.any(*types) end end |
#variants ⇒ Array<Object>
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
All of the specified variants for this union.
63 |
# File 'lib/dodopayments/internal/type/union.rb', line 63 def variants = derefed_variants.map { _2 } |