Class: Dodopayments::Models::Blocklist::CustomerListParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Dodopayments::Models::Blocklist::CustomerListParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/dodopayments/models/blocklist/customer_list_params.rb,
sig/dodopayments/models/blocklist/customer_list_params.rbs
Overview
Constant Summary
Constants included from Internal::Type::RequestParameters
Internal::Type::RequestParameters::Dodopayments
Instance Attribute Summary collapse
-
#blocked_by_email ⇒ String?
Filter by the dashboard user who blocked the customer.
-
#created_at_gte ⇒ Time?
Blocked on or after this time.
-
#created_at_lte ⇒ Time?
Blocked on or before this time.
-
#identifier ⇒ String?
Partial, case-insensitive match on the email and on the customer id.
-
#page_number ⇒ Integer?
Page number.
-
#page_size ⇒ Integer?
Page size.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
- #initialize(blocked_by_email: nil, created_at_gte: nil, created_at_lte: nil, identifier: nil, page_number: nil, page_size: nil, request_options: {}) ⇒ Object constructor
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(blocked_by_email: nil, created_at_gte: nil, created_at_lte: nil, identifier: nil, page_number: nil, page_size: nil, request_options: {}) ⇒ Object
|
|
# File 'lib/dodopayments/models/blocklist/customer_list_params.rb', line 47
|
Instance Attribute Details
#blocked_by_email ⇒ String?
Filter by the dashboard user who blocked the customer.
15 |
# File 'lib/dodopayments/models/blocklist/customer_list_params.rb', line 15 optional :blocked_by_email, String, nil?: true |
#created_at_gte ⇒ Time?
Blocked on or after this time.
21 |
# File 'lib/dodopayments/models/blocklist/customer_list_params.rb', line 21 optional :created_at_gte, Time, nil?: true |
#created_at_lte ⇒ Time?
Blocked on or before this time.
27 |
# File 'lib/dodopayments/models/blocklist/customer_list_params.rb', line 27 optional :created_at_lte, Time, nil?: true |
#identifier ⇒ String?
Partial, case-insensitive match on the email and on the customer id.
33 |
# File 'lib/dodopayments/models/blocklist/customer_list_params.rb', line 33 optional :identifier, String, nil?: true |
#page_number ⇒ Integer?
Page number. Default 0.
39 |
# File 'lib/dodopayments/models/blocklist/customer_list_params.rb', line 39 optional :page_number, Integer, nil?: true |
#page_size ⇒ Integer?
Page size. Default 10, maximum 100.
45 |
# File 'lib/dodopayments/models/blocklist/customer_list_params.rb', line 45 optional :page_size, Integer, nil?: true |
Instance Method Details
#to_hash ⇒ {
41 |
# File 'sig/dodopayments/models/blocklist/customer_list_params.rbs', line 41
def to_hash: -> {
|