Class: Dodopayments::Models::BrandArchiveResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Dodopayments::Models::BrandArchiveResponse
- Defined in:
- lib/dodopayments/models/brand_archive_response.rb,
sig/dodopayments/models/brand_archive_response.rbs
Overview
Instance Attribute Summary collapse
-
#archived_at ⇒ Time
Time the brand was archived.
-
#brand_id ⇒ String
The archived brand.
-
#collections_moved ⇒ Integer
Count of product collections moved to the target brand.
-
#moved_to_brand_id ⇒ String?
Brand that received the moved records.
-
#products_moved ⇒ Integer
Count of products moved to the target brand.
-
#subscriptions_moved ⇒ Integer
Count of live subscriptions moved to the target brand.
Instance Method Summary collapse
- #initialize(archived_at:, brand_id:, collections_moved:, products_moved:, subscriptions_moved:, moved_to_brand_id: nil) ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(archived_at:, brand_id:, collections_moved:, products_moved:, subscriptions_moved:, moved_to_brand_id: nil) ⇒ Object
|
|
# File 'lib/dodopayments/models/brand_archive_response.rb', line 43
|
Instance Attribute Details
#archived_at ⇒ Time
Time the brand was archived.
11 |
# File 'lib/dodopayments/models/brand_archive_response.rb', line 11 required :archived_at, Time |
#brand_id ⇒ String
The archived brand.
17 |
# File 'lib/dodopayments/models/brand_archive_response.rb', line 17 required :brand_id, String |
#collections_moved ⇒ Integer
Count of product collections moved to the target brand.
23 |
# File 'lib/dodopayments/models/brand_archive_response.rb', line 23 required :collections_moved, Integer |
#moved_to_brand_id ⇒ String?
Brand that received the moved records. Null when no target was given.
41 |
# File 'lib/dodopayments/models/brand_archive_response.rb', line 41 optional :moved_to_brand_id, String, nil?: true |
#products_moved ⇒ Integer
Count of products moved to the target brand.
29 |
# File 'lib/dodopayments/models/brand_archive_response.rb', line 29 required :products_moved, Integer |
#subscriptions_moved ⇒ Integer
Count of live subscriptions moved to the target brand.
35 |
# File 'lib/dodopayments/models/brand_archive_response.rb', line 35 required :subscriptions_moved, Integer |
Instance Method Details
#to_hash ⇒ {
35 |
# File 'sig/dodopayments/models/brand_archive_response.rbs', line 35
def to_hash: -> {
|