Class: Dodopayments::Models::CheckoutSessionFlags

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/dodopayments/models/checkout_session_flags.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(allow_currency_selection: nil, allow_customer_editing_city: nil, allow_customer_editing_country: nil, allow_customer_editing_email: nil, allow_customer_editing_name: nil, allow_customer_editing_state: nil, allow_customer_editing_street: nil, allow_customer_editing_tax_id: nil, allow_customer_editing_zipcode: nil, allow_discount_code: nil, allow_phone_number_collection: nil, allow_tax_id: nil, always_create_new_customer: nil, redirect_immediately: nil) ⇒ Object

Some parameter documentations has been truncated, see Dodopayments::Models::CheckoutSessionFlags for more details.

Parameters:

  • allow_currency_selection (Boolean) (defaults to: nil)

    if customer is allowed to change currency, set it to true

  • allow_customer_editing_city (Boolean) (defaults to: nil)
  • allow_customer_editing_country (Boolean) (defaults to: nil)
  • allow_customer_editing_email (Boolean) (defaults to: nil)
  • allow_customer_editing_name (Boolean) (defaults to: nil)
  • allow_customer_editing_state (Boolean) (defaults to: nil)
  • allow_customer_editing_street (Boolean) (defaults to: nil)
  • allow_customer_editing_tax_id (Boolean) (defaults to: nil)
  • allow_customer_editing_zipcode (Boolean) (defaults to: nil)
  • allow_discount_code (Boolean) (defaults to: nil)

    If the customer is allowed to apply discount code, set it to true.

  • allow_phone_number_collection (Boolean) (defaults to: nil)

    If phone number is collected from customer, set it to rue

  • allow_tax_id (Boolean) (defaults to: nil)

    If the customer is allowed to add tax id, set it to true

  • always_create_new_customer (Boolean) (defaults to: nil)

    Set to true if a new customer object should be created.

  • redirect_immediately (Boolean) (defaults to: nil)

    If true, redirects the customer immediately after payment completion



# File 'lib/dodopayments/models/checkout_session_flags.rb', line 95

Instance Attribute Details

#allow_currency_selectionBoolean?

if customer is allowed to change currency, set it to true

Default is true

Returns:

  • (Boolean, nil)


12
# File 'lib/dodopayments/models/checkout_session_flags.rb', line 12

optional :allow_currency_selection, Dodopayments::Internal::Type::Boolean

#allow_customer_editing_cityBoolean?

Returns:

  • (Boolean, nil)


17
# File 'lib/dodopayments/models/checkout_session_flags.rb', line 17

optional :allow_customer_editing_city, Dodopayments::Internal::Type::Boolean

#allow_customer_editing_countryBoolean?

Returns:

  • (Boolean, nil)


22
# File 'lib/dodopayments/models/checkout_session_flags.rb', line 22

optional :allow_customer_editing_country, Dodopayments::Internal::Type::Boolean

#allow_customer_editing_emailBoolean?

Returns:

  • (Boolean, nil)


27
# File 'lib/dodopayments/models/checkout_session_flags.rb', line 27

optional :allow_customer_editing_email, Dodopayments::Internal::Type::Boolean

#allow_customer_editing_nameBoolean?

Returns:

  • (Boolean, nil)


32
# File 'lib/dodopayments/models/checkout_session_flags.rb', line 32

optional :allow_customer_editing_name, Dodopayments::Internal::Type::Boolean

#allow_customer_editing_stateBoolean?

Returns:

  • (Boolean, nil)


37
# File 'lib/dodopayments/models/checkout_session_flags.rb', line 37

optional :allow_customer_editing_state, Dodopayments::Internal::Type::Boolean

#allow_customer_editing_streetBoolean?

Returns:

  • (Boolean, nil)


42
# File 'lib/dodopayments/models/checkout_session_flags.rb', line 42

optional :allow_customer_editing_street, Dodopayments::Internal::Type::Boolean

#allow_customer_editing_tax_idBoolean?

Returns:

  • (Boolean, nil)


47
# File 'lib/dodopayments/models/checkout_session_flags.rb', line 47

optional :allow_customer_editing_tax_id, Dodopayments::Internal::Type::Boolean

#allow_customer_editing_zipcodeBoolean?

Returns:

  • (Boolean, nil)


52
# File 'lib/dodopayments/models/checkout_session_flags.rb', line 52

optional :allow_customer_editing_zipcode, Dodopayments::Internal::Type::Boolean

#allow_discount_codeBoolean?

If the customer is allowed to apply discount code, set it to true.

Default is true

Returns:

  • (Boolean, nil)


60
# File 'lib/dodopayments/models/checkout_session_flags.rb', line 60

optional :allow_discount_code, Dodopayments::Internal::Type::Boolean

#allow_phone_number_collectionBoolean?

If phone number is collected from customer, set it to rue

Default is true

Returns:

  • (Boolean, nil)


68
# File 'lib/dodopayments/models/checkout_session_flags.rb', line 68

optional :allow_phone_number_collection, Dodopayments::Internal::Type::Boolean

#allow_tax_idBoolean?

If the customer is allowed to add tax id, set it to true

Default is true

Returns:

  • (Boolean, nil)


76
# File 'lib/dodopayments/models/checkout_session_flags.rb', line 76

optional :allow_tax_id, Dodopayments::Internal::Type::Boolean

#always_create_new_customerBoolean?

Set to true if a new customer object should be created. By default email is used to find an existing customer to attach the session to

Default is false

Returns:

  • (Boolean, nil)


85
# File 'lib/dodopayments/models/checkout_session_flags.rb', line 85

optional :always_create_new_customer, Dodopayments::Internal::Type::Boolean

#redirect_immediatelyBoolean?

If true, redirects the customer immediately after payment completion

Default is false

Returns:

  • (Boolean, nil)


93
# File 'lib/dodopayments/models/checkout_session_flags.rb', line 93

optional :redirect_immediately, Dodopayments::Internal::Type::Boolean