Class: Dodopayments::Models::CheckoutSessionFlags
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Dodopayments::Models::CheckoutSessionFlags
- Defined in:
- lib/dodopayments/models/checkout_session_flags.rb
Instance Attribute Summary collapse
-
#allow_currency_selection ⇒ Boolean?
if customer is allowed to change currency, set it to true.
- #allow_customer_editing_city ⇒ Boolean?
- #allow_customer_editing_country ⇒ Boolean?
- #allow_customer_editing_email ⇒ Boolean?
- #allow_customer_editing_name ⇒ Boolean?
- #allow_customer_editing_state ⇒ Boolean?
- #allow_customer_editing_street ⇒ Boolean?
- #allow_customer_editing_tax_id ⇒ Boolean?
- #allow_customer_editing_zipcode ⇒ Boolean?
-
#allow_discount_code ⇒ Boolean?
If the customer is allowed to apply discount code, set it to true.
-
#allow_phone_number_collection ⇒ Boolean?
If phone number is collected from customer, set it to rue.
-
#allow_tax_id ⇒ Boolean?
If the customer is allowed to add tax id, set it to true.
-
#always_create_new_customer ⇒ Boolean?
Set to true if a new customer object should be created.
-
#redirect_immediately ⇒ Boolean?
If true, redirects the customer immediately after payment completion.
Instance Method Summary collapse
-
#initialize(allow_currency_selection: nil, allow_customer_editing_city: nil, allow_customer_editing_country: nil, allow_customer_editing_email: nil, allow_customer_editing_name: nil, allow_customer_editing_state: nil, allow_customer_editing_street: nil, allow_customer_editing_tax_id: nil, allow_customer_editing_zipcode: nil, allow_discount_code: nil, allow_phone_number_collection: nil, allow_tax_id: nil, always_create_new_customer: nil, redirect_immediately: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see CheckoutSessionFlags for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(allow_currency_selection: nil, allow_customer_editing_city: nil, allow_customer_editing_country: nil, allow_customer_editing_email: nil, allow_customer_editing_name: nil, allow_customer_editing_state: nil, allow_customer_editing_street: nil, allow_customer_editing_tax_id: nil, allow_customer_editing_zipcode: nil, allow_discount_code: nil, allow_phone_number_collection: nil, allow_tax_id: nil, always_create_new_customer: nil, redirect_immediately: nil) ⇒ Object
Some parameter documentations has been truncated, see Dodopayments::Models::CheckoutSessionFlags for more details.
|
|
# File 'lib/dodopayments/models/checkout_session_flags.rb', line 95
|
Instance Attribute Details
#allow_currency_selection ⇒ Boolean?
if customer is allowed to change currency, set it to true
Default is true
12 |
# File 'lib/dodopayments/models/checkout_session_flags.rb', line 12 optional :allow_currency_selection, Dodopayments::Internal::Type::Boolean |
#allow_customer_editing_city ⇒ Boolean?
17 |
# File 'lib/dodopayments/models/checkout_session_flags.rb', line 17 optional :allow_customer_editing_city, Dodopayments::Internal::Type::Boolean |
#allow_customer_editing_country ⇒ Boolean?
22 |
# File 'lib/dodopayments/models/checkout_session_flags.rb', line 22 optional :allow_customer_editing_country, Dodopayments::Internal::Type::Boolean |
#allow_customer_editing_email ⇒ Boolean?
27 |
# File 'lib/dodopayments/models/checkout_session_flags.rb', line 27 optional :allow_customer_editing_email, Dodopayments::Internal::Type::Boolean |
#allow_customer_editing_name ⇒ Boolean?
32 |
# File 'lib/dodopayments/models/checkout_session_flags.rb', line 32 optional :allow_customer_editing_name, Dodopayments::Internal::Type::Boolean |
#allow_customer_editing_state ⇒ Boolean?
37 |
# File 'lib/dodopayments/models/checkout_session_flags.rb', line 37 optional :allow_customer_editing_state, Dodopayments::Internal::Type::Boolean |
#allow_customer_editing_street ⇒ Boolean?
42 |
# File 'lib/dodopayments/models/checkout_session_flags.rb', line 42 optional :allow_customer_editing_street, Dodopayments::Internal::Type::Boolean |
#allow_customer_editing_tax_id ⇒ Boolean?
47 |
# File 'lib/dodopayments/models/checkout_session_flags.rb', line 47 optional :allow_customer_editing_tax_id, Dodopayments::Internal::Type::Boolean |
#allow_customer_editing_zipcode ⇒ Boolean?
52 |
# File 'lib/dodopayments/models/checkout_session_flags.rb', line 52 optional :allow_customer_editing_zipcode, Dodopayments::Internal::Type::Boolean |
#allow_discount_code ⇒ Boolean?
If the customer is allowed to apply discount code, set it to true.
Default is true
60 |
# File 'lib/dodopayments/models/checkout_session_flags.rb', line 60 optional :allow_discount_code, Dodopayments::Internal::Type::Boolean |
#allow_phone_number_collection ⇒ Boolean?
If phone number is collected from customer, set it to rue
Default is true
68 |
# File 'lib/dodopayments/models/checkout_session_flags.rb', line 68 optional :allow_phone_number_collection, Dodopayments::Internal::Type::Boolean |
#allow_tax_id ⇒ Boolean?
If the customer is allowed to add tax id, set it to true
Default is true
76 |
# File 'lib/dodopayments/models/checkout_session_flags.rb', line 76 optional :allow_tax_id, Dodopayments::Internal::Type::Boolean |
#always_create_new_customer ⇒ Boolean?
Set to true if a new customer object should be created. By default email is used to find an existing customer to attach the session to
Default is false
85 |
# File 'lib/dodopayments/models/checkout_session_flags.rb', line 85 optional :always_create_new_customer, Dodopayments::Internal::Type::Boolean |
#redirect_immediately ⇒ Boolean?
If true, redirects the customer immediately after payment completion
Default is false
93 |
# File 'lib/dodopayments/models/checkout_session_flags.rb', line 93 optional :redirect_immediately, Dodopayments::Internal::Type::Boolean |