Class: Dodopayments::Models::CheckoutSessionResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Dodopayments::Models::CheckoutSessionResponse
- Defined in:
- lib/dodopayments/models/checkout_session_response.rb
Overview
Instance Attribute Summary collapse
-
#checkout_url ⇒ String?
Checkout url (None when payment_method_id is provided).
-
#client_secret ⇒ String?
Client secret used to load the Dodo Payments checkout SDK.
-
#payment_id ⇒ String?
Underlying payment id when ‘confirm: true` was passed and a PaymentIntent was created at session-creation time.
-
#publishable_key ⇒ String?
Publishable key for the Dodo Payments checkout SDK.
-
#session_id ⇒ String
The ID of the created checkout session.
Instance Method Summary collapse
-
#initialize(session_id:, checkout_url: nil, client_secret: nil, payment_id: nil, publishable_key: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see CheckoutSessionResponse for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(session_id:, checkout_url: nil, client_secret: nil, payment_id: nil, publishable_key: nil) ⇒ Object
Some parameter documentations has been truncated, see Dodopayments::Models::CheckoutSessionResponse for more details.
|
|
# File 'lib/dodopayments/models/checkout_session_response.rb', line 42
|
Instance Attribute Details
#checkout_url ⇒ String?
Checkout url (None when payment_method_id is provided)
17 |
# File 'lib/dodopayments/models/checkout_session_response.rb', line 17 optional :checkout_url, String, nil?: true |
#client_secret ⇒ String?
Client secret used to load the Dodo Payments checkout SDK. Returned when ‘confirm: true` was passed and a PaymentIntent was created at session-creation time. `None` otherwise.
25 |
# File 'lib/dodopayments/models/checkout_session_response.rb', line 25 optional :client_secret, String, nil?: true |
#payment_id ⇒ String?
Underlying payment id when ‘confirm: true` was passed and a PaymentIntent was created at session-creation time. `None` otherwise.
32 |
# File 'lib/dodopayments/models/checkout_session_response.rb', line 32 optional :payment_id, String, nil?: true |
#publishable_key ⇒ String?
Publishable key for the Dodo Payments checkout SDK. Returned when ‘confirm: true` was passed and a PaymentIntent was created at session-creation time. `None` otherwise.
40 |
# File 'lib/dodopayments/models/checkout_session_response.rb', line 40 optional :publishable_key, String, nil?: true |
#session_id ⇒ String
The ID of the created checkout session
11 |
# File 'lib/dodopayments/models/checkout_session_response.rb', line 11 required :session_id, String |