Class: Dodopayments::Models::Customers::EmailBody
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Dodopayments::Models::Customers::EmailBody
- Defined in:
- lib/dodopayments/models/customers/email_body.rb,
sig/dodopayments/models/customers/email_body.rbs
Overview
Instance Attribute Summary collapse
-
#failure_code ⇒ Symbol, ...
Why the email did not arrive.
-
#failure_reason ⇒ String?
A sentence that explains
failure_code. -
#html ⇒ String?
The stored HTML.
-
#merchant_authored ⇒ Boolean
Whether the merchant wrote this content.
-
#text ⇒ String?
The stored plain text.
Instance Method Summary collapse
-
#initialize(merchant_authored:, failure_code: nil, failure_reason: nil, html: nil, text: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see EmailBody for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(merchant_authored:, failure_code: nil, failure_reason: nil, html: nil, text: nil) ⇒ Object
Some parameter documentations has been truncated, see Dodopayments::Models::Customers::EmailBody for more details.
|
|
# File 'lib/dodopayments/models/customers/email_body.rb', line 41
|
Instance Attribute Details
#failure_code ⇒ Symbol, ...
Why the email did not arrive. It is null unless the email failed.
21 |
# File 'lib/dodopayments/models/customers/email_body.rb', line 21 optional :failure_code, enum: -> { Dodopayments::Customers::EmailFailureCode }, nil?: true |
#failure_reason ⇒ String?
A sentence that explains failure_code. It is null unless the email failed.
27 |
# File 'lib/dodopayments/models/customers/email_body.rb', line 27 optional :failure_reason, String, nil?: true |
#html ⇒ String?
The stored HTML. It is null on a text-only email.
33 |
# File 'lib/dodopayments/models/customers/email_body.rb', line 33 optional :html, String, nil?: true |
#merchant_authored ⇒ Boolean
Whether the merchant wrote this content. It is true for the recovery and dunning emails, which the merchant writes.
The content is email HTML. Render it in a sandbox, whatever this value is.
15 |
# File 'lib/dodopayments/models/customers/email_body.rb', line 15 required :merchant_authored, Dodopayments::Internal::Type::Boolean |
#text ⇒ String?
The stored plain text.
39 |
# File 'lib/dodopayments/models/customers/email_body.rb', line 39 optional :text, String, nil?: true |
Instance Method Details
#to_hash ⇒ {
32 |
# File 'sig/dodopayments/models/customers/email_body.rbs', line 32
def to_hash: -> {
|