Class: Dodopayments::Models::Discount

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/dodopayments/models/discount.rb,
sig/dodopayments/models/discount.rbs

Overview

See Also:

  • Dodopayments::Resources::Discounts#create

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(amount:, business_id:, code:, created_at:, discount_id:, metadata:, preserve_on_plan_change:, restricted_to:, times_used:, type:, expires_at: nil, name: nil, subscription_cycles: nil, usage_limit: nil) ⇒ Object

Some parameter documentations has been truncated, see Dodopayments::Models::Discount for more details.

Parameters:

  • amount (Integer)

    The discount amount in basis points (e.g., 540 => 5.4%).

  • business_id (String)

    The business this discount belongs to.

  • code (String)

    The discount code (up to 16 chars).

  • created_at (Time)

    Timestamp when the discount is created

  • discount_id (String)

    The unique discount ID

  • metadata (Hash{Symbol=>String, Float, Boolean})

    Arbitrary key-value metadata. Values can be string, integer, number, or boolean.

  • preserve_on_plan_change (Boolean)

    Whether this discount should be preserved when a subscription changes plans.

  • restricted_to (Array<String>)

    List of product IDs to which this discount is restricted.

  • times_used (Integer)

    How many times this discount has been used.

  • type (Symbol, Dodopayments::Models::DiscountType)

    The type of discount. Currently only percentage is supported.

  • expires_at (Time, nil) (defaults to: nil)

    Optional date/time after which discount is expired.

  • name (String, nil) (defaults to: nil)

    Name for the Discount

  • subscription_cycles (Integer, nil) (defaults to: nil)

    Number of subscription billing cycles this discount is valid for.

  • usage_limit (Integer, nil) (defaults to: nil)

    Usage limit for this discount, if any.



# File 'lib/dodopayments/models/discount.rb', line 94

Instance Attribute Details

#amountInteger

The discount amount in basis points (e.g., 540 => 5.4%).

Parameters:

  • value (Integer)

Returns:

  • (Integer)


11
# File 'lib/dodopayments/models/discount.rb', line 11

required :amount, Integer

#business_idString

The business this discount belongs to.

Parameters:

  • value (String)

Returns:

  • (String)


17
# File 'lib/dodopayments/models/discount.rb', line 17

required :business_id, String

#codeString

The discount code (up to 16 chars).

Parameters:

  • value (String)

Returns:

  • (String)


23
# File 'lib/dodopayments/models/discount.rb', line 23

required :code, String

#created_atTime

Timestamp when the discount is created

Parameters:

  • value (Time)

Returns:

  • (Time)


29
# File 'lib/dodopayments/models/discount.rb', line 29

required :created_at, Time

#discount_idString

The unique discount ID

Parameters:

  • value (String)

Returns:

  • (String)


35
# File 'lib/dodopayments/models/discount.rb', line 35

required :discount_id, String

#expires_atTime?

Optional date/time after which discount is expired.

Parameters:

  • value (Time, nil)

Returns:

  • (Time, nil)


72
# File 'lib/dodopayments/models/discount.rb', line 72

optional :expires_at, Time, nil?: true

#metadataHash{Symbol=>String, Float, Boolean}

Arbitrary key-value metadata. Values can be string, integer, number, or boolean.

Parameters:

  • value (Dodopayments::Models::metadata)

Returns:

  • (Hash{Symbol=>String, Float, Boolean})


41
# File 'lib/dodopayments/models/discount.rb', line 41

required :metadata, -> { Dodopayments::Internal::Type::HashOf[union: Dodopayments::MetadataItem] }

#nameString?

Name for the Discount

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


78
# File 'lib/dodopayments/models/discount.rb', line 78

optional :name, String, nil?: true

#preserve_on_plan_changeBoolean

Whether this discount should be preserved when a subscription changes plans. Default: false (discount is removed on plan change)

Parameters:

  • value (Boolean)

Returns:

  • (Boolean)


48
# File 'lib/dodopayments/models/discount.rb', line 48

required :preserve_on_plan_change, Dodopayments::Internal::Type::Boolean

#restricted_toArray<String>

List of product IDs to which this discount is restricted.

Parameters:

  • value (::Array[String])

Returns:

  • (Array<String>)


54
# File 'lib/dodopayments/models/discount.rb', line 54

required :restricted_to, Dodopayments::Internal::Type::ArrayOf[String]

#subscription_cyclesInteger?

Number of subscription billing cycles this discount is valid for. If not provided, the discount will be applied indefinitely to all recurring payments related to the subscription.

Parameters:

  • value (Integer, nil)

Returns:

  • (Integer, nil)


86
# File 'lib/dodopayments/models/discount.rb', line 86

optional :subscription_cycles, Integer, nil?: true

#times_usedInteger

How many times this discount has been used.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


60
# File 'lib/dodopayments/models/discount.rb', line 60

required :times_used, Integer

#typeSymbol, Dodopayments::Models::DiscountType

The type of discount. Currently only percentage is supported.

Parameters:

  • value (Dodopayments::Models::discount_type)

Returns:



66
# File 'lib/dodopayments/models/discount.rb', line 66

required :type, enum: -> { Dodopayments::DiscountType }

#usage_limitInteger?

Usage limit for this discount, if any.

Parameters:

  • value (Integer, nil)

Returns:

  • (Integer, nil)


92
# File 'lib/dodopayments/models/discount.rb', line 92

optional :usage_limit, Integer, nil?: true

Instance Method Details

#to_hash{

Returns:

  • ({)


67
# File 'sig/dodopayments/models/discount.rbs', line 67

def to_hash: -> {