Class: Dodopayments::Models::Entitlements::GrantFulfillLicenseKeyParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Dodopayments::Models::Entitlements::GrantFulfillLicenseKeyParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/dodopayments/models/entitlements/grant_fulfill_license_key_params.rb
Overview
Instance Attribute Summary collapse
-
#activations_limit ⇒ Integer?
Per-key activation limit.
-
#expires_at ⇒ Time?
When the key expires.
- #grant_id ⇒ String
-
#key ⇒ String
The license key value to deliver to the customer.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(grant_id:, key:, activations_limit: nil, expires_at: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see GrantFulfillLicenseKeyParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(grant_id:, key:, activations_limit: nil, expires_at: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Dodopayments::Models::Entitlements::GrantFulfillLicenseKeyParams for more details.
|
|
# File 'lib/dodopayments/models/entitlements/grant_fulfill_license_key_params.rb', line 36
|
Instance Attribute Details
#activations_limit ⇒ Integer?
Per-key activation limit. Defaults to the entitlement’s license-key configuration.
27 |
# File 'lib/dodopayments/models/entitlements/grant_fulfill_license_key_params.rb', line 27 optional :activations_limit, Integer, nil?: true |
#expires_at ⇒ Time?
When the key expires. Defaults to the duration in the entitlement’s license-key configuration.
34 |
# File 'lib/dodopayments/models/entitlements/grant_fulfill_license_key_params.rb', line 34 optional :expires_at, Time, nil?: true |
#grant_id ⇒ String
14 |
# File 'lib/dodopayments/models/entitlements/grant_fulfill_license_key_params.rb', line 14 required :grant_id, String |
#key ⇒ String
The license key value to deliver to the customer.
20 |
# File 'lib/dodopayments/models/entitlements/grant_fulfill_license_key_params.rb', line 20 required :key, String |