Class: Dodopayments::Models::IntegrationConfig::LicenseKeyConfig
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Dodopayments::Models::IntegrationConfig::LicenseKeyConfig
- Defined in:
- lib/dodopayments/models/integration_config.rb
Instance Attribute Summary collapse
-
#activation_message ⇒ String?
Optional message displayed when a customer activates the license key (≤ 2500 characters).
-
#activations_limit ⇒ Integer?
Maximum activations allowed per issued license key.
-
#duration_count ⇒ Integer?
Validity duration of issued license keys.
-
#duration_interval ⇒ Symbol, ...
Unit of ‘duration_count`.
Instance Method Summary collapse
-
#initialize(activation_message: nil, activations_limit: nil, duration_count: nil, duration_interval: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see LicenseKeyConfig for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(activation_message: nil, activations_limit: nil, duration_count: nil, duration_interval: nil) ⇒ Object
Some parameter documentations has been truncated, see Dodopayments::Models::IntegrationConfig::LicenseKeyConfig for more details.
|
|
# File 'lib/dodopayments/models/integration_config.rb', line 200
|
Instance Attribute Details
#activation_message ⇒ String?
Optional message displayed when a customer activates the license key (≤ 2500 characters).
178 |
# File 'lib/dodopayments/models/integration_config.rb', line 178 optional :activation_message, String, nil?: true |
#activations_limit ⇒ Integer?
Maximum activations allowed per issued license key. Omit for unlimited.
184 |
# File 'lib/dodopayments/models/integration_config.rb', line 184 optional :activations_limit, Integer, nil?: true |
#duration_count ⇒ Integer?
Validity duration of issued license keys. Provide both ‘duration_count` and `duration_interval` together for a fixed duration; omit both for non-expiring keys.
192 |
# File 'lib/dodopayments/models/integration_config.rb', line 192 optional :duration_count, Integer, nil?: true |
#duration_interval ⇒ Symbol, ...
Unit of ‘duration_count`.
198 |
# File 'lib/dodopayments/models/integration_config.rb', line 198 optional :duration_interval, enum: -> { Dodopayments::TimeInterval }, nil?: true |