Class: Dodopayments::Models::IntegrationConfigResponse::LicenseKeyConfig

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/dodopayments/models/integration_config_response.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(activation_message: nil, activations_limit: nil, duration_count: nil, duration_interval: nil) ⇒ Object

Some parameter documentations has been truncated, see Dodopayments::Models::IntegrationConfigResponse::LicenseKeyConfig for more details.

Parameters:

  • activation_message (String, nil) (defaults to: nil)

    Optional message displayed when a customer activates the license

  • activations_limit (Integer, nil) (defaults to: nil)

    Maximum activations allowed per issued license key. Omit for unlimited.

  • duration_count (Integer, nil) (defaults to: nil)

    Validity duration of issued license keys. Provide both

  • duration_interval (Symbol, Dodopayments::Models::TimeInterval, nil) (defaults to: nil)

    Unit of ‘duration_count`.



# File 'lib/dodopayments/models/integration_config_response.rb', line 260

Instance Attribute Details

#activation_messageString?

Optional message displayed when a customer activates the license key (≤ 2500 characters).

Returns:

  • (String, nil)


238
# File 'lib/dodopayments/models/integration_config_response.rb', line 238

optional :activation_message, String, nil?: true

#activations_limitInteger?

Maximum activations allowed per issued license key. Omit for unlimited.

Returns:

  • (Integer, nil)


244
# File 'lib/dodopayments/models/integration_config_response.rb', line 244

optional :activations_limit, Integer, nil?: true

#duration_countInteger?

Validity duration of issued license keys. Provide both ‘duration_count` and `duration_interval` together for a fixed duration; omit both for non-expiring keys.

Returns:

  • (Integer, nil)


252
# File 'lib/dodopayments/models/integration_config_response.rb', line 252

optional :duration_count, Integer, nil?: true

#duration_intervalSymbol, ...

Unit of ‘duration_count`.

Returns:



258
# File 'lib/dodopayments/models/integration_config_response.rb', line 258

optional :duration_interval, enum: -> { Dodopayments::TimeInterval }, nil?: true