Class: Dodopayments::Models::LicenseKey
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Dodopayments::Models::LicenseKey
- Defined in:
- lib/dodopayments/models/license_key.rb
Overview
Direct Known Subclasses
Defined Under Namespace
Modules: Source
Instance Attribute Summary collapse
-
#activations_limit ⇒ Integer?
The maximum number of activations allowed for this license key.
-
#business_id ⇒ String
The unique identifier of the business associated with the license key.
-
#created_at ⇒ Time
The timestamp indicating when the license key was created, in UTC.
-
#customer_id ⇒ String
The unique identifier of the customer associated with the license key.
-
#expires_at ⇒ Time?
The timestamp indicating when the license key expires, in UTC.
-
#id ⇒ String
The unique identifier of the license key.
-
#instances_count ⇒ Integer
The current number of instances activated for this license key.
-
#key ⇒ String
The license key string.
-
#payment_id ⇒ String?
The unique identifier of the payment associated with the license key, if any.
-
#product_id ⇒ String
The unique identifier of the product associated with the license key.
-
#source ⇒ Symbol, Dodopayments::Models::LicenseKey::Source
The source of the license key - ‘auto’ for keys generated by payment/subscription flows, ‘import’ for merchant-imported keys.
-
#status ⇒ Symbol, Dodopayments::Models::LicenseKeyStatus
The current status of the license key (e.g., active, inactive, expired).
-
#subscription_id ⇒ String?
The unique identifier of the subscription associated with the license key, if any.
Instance Method Summary collapse
-
#initialize(id:, business_id:, created_at:, customer_id:, instances_count:, key:, product_id:, source:, status:, activations_limit: nil, expires_at: nil, payment_id: nil, subscription_id: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see LicenseKey for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, business_id:, created_at:, customer_id:, instances_count:, key:, product_id:, source:, status:, activations_limit: nil, expires_at: nil, payment_id: nil, subscription_id: nil) ⇒ Object
Some parameter documentations has been truncated, see Dodopayments::Models::LicenseKey for more details.
|
|
# File 'lib/dodopayments/models/license_key.rb', line 87
|
Instance Attribute Details
#activations_limit ⇒ Integer?
The maximum number of activations allowed for this license key.
66 |
# File 'lib/dodopayments/models/license_key.rb', line 66 optional :activations_limit, Integer, nil?: true |
#business_id ⇒ String
The unique identifier of the business associated with the license key.
17 |
# File 'lib/dodopayments/models/license_key.rb', line 17 required :business_id, String |
#created_at ⇒ Time
The timestamp indicating when the license key was created, in UTC.
23 |
# File 'lib/dodopayments/models/license_key.rb', line 23 required :created_at, Time |
#customer_id ⇒ String
The unique identifier of the customer associated with the license key.
29 |
# File 'lib/dodopayments/models/license_key.rb', line 29 required :customer_id, String |
#expires_at ⇒ Time?
The timestamp indicating when the license key expires, in UTC.
72 |
# File 'lib/dodopayments/models/license_key.rb', line 72 optional :expires_at, Time, nil?: true |
#id ⇒ String
The unique identifier of the license key.
11 |
# File 'lib/dodopayments/models/license_key.rb', line 11 required :id, String |
#instances_count ⇒ Integer
The current number of instances activated for this license key.
35 |
# File 'lib/dodopayments/models/license_key.rb', line 35 required :instances_count, Integer |
#key ⇒ String
The license key string.
41 |
# File 'lib/dodopayments/models/license_key.rb', line 41 required :key, String |
#payment_id ⇒ String?
The unique identifier of the payment associated with the license key, if any.
78 |
# File 'lib/dodopayments/models/license_key.rb', line 78 optional :payment_id, String, nil?: true |
#product_id ⇒ String
The unique identifier of the product associated with the license key.
47 |
# File 'lib/dodopayments/models/license_key.rb', line 47 required :product_id, String |
#source ⇒ Symbol, Dodopayments::Models::LicenseKey::Source
The source of the license key - ‘auto’ for keys generated by payment/subscription flows, ‘import’ for merchant-imported keys.
54 |
# File 'lib/dodopayments/models/license_key.rb', line 54 required :source, enum: -> { Dodopayments::LicenseKey::Source } |
#status ⇒ Symbol, Dodopayments::Models::LicenseKeyStatus
The current status of the license key (e.g., active, inactive, expired).
60 |
# File 'lib/dodopayments/models/license_key.rb', line 60 required :status, enum: -> { Dodopayments::LicenseKeyStatus } |
#subscription_id ⇒ String?
The unique identifier of the subscription associated with the license key, if any.
85 |
# File 'lib/dodopayments/models/license_key.rb', line 85 optional :subscription_id, String, nil?: true |