Class: Dodopayments::Models::Payment

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/dodopayments/models/payment.rb

Overview

Direct Known Subclasses

WebhookPayload::Data::Payment

Defined Under Namespace

Classes: ProductCart

Instance Attribute Summary collapse

Method Summary

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

This class inherits a constructor from Dodopayments::Internal::Type::BaseModel

Instance Attribute Details

#billingDodopayments::Models::BillingAddress

Billing address details for payments



11
# File 'lib/dodopayments/models/payment.rb', line 11

required :billing, -> { Dodopayments::BillingAddress }

#brand_idString

brand id this payment belongs to

Returns:

  • (String)


17
# File 'lib/dodopayments/models/payment.rb', line 17

required :brand_id, String

#business_idString

Identifier of the business associated with the payment

Returns:

  • (String)


23
# File 'lib/dodopayments/models/payment.rb', line 23

required :business_id, String

#card_holder_nameString?

Cardholder name

Returns:

  • (String, nil)


108
# File 'lib/dodopayments/models/payment.rb', line 108

optional :card_holder_name, String, nil?: true

#card_issuing_countrySymbol, ...

ISO2 country code of the card

Returns:



114
# File 'lib/dodopayments/models/payment.rb', line 114

optional :card_issuing_country, enum: -> { Dodopayments::CountryCode }, nil?: true

#card_last_fourString?

The last four digits of the card

Returns:

  • (String, nil)


120
# File 'lib/dodopayments/models/payment.rb', line 120

optional :card_last_four, String, nil?: true

#card_networkString?

Card network like VISA, MASTERCARD etc.

Returns:

  • (String, nil)


126
# File 'lib/dodopayments/models/payment.rb', line 126

optional :card_network, String, nil?: true

#card_typeString?

The type of card DEBIT or CREDIT

Returns:

  • (String, nil)


132
# File 'lib/dodopayments/models/payment.rb', line 132

optional :card_type, String, nil?: true

#checkout_session_idString?

If payment is made using a checkout session, this field is set to the id of the session.

Returns:

  • (String, nil)


139
# File 'lib/dodopayments/models/payment.rb', line 139

optional :checkout_session_id, String, nil?: true

#created_atTime

Timestamp when the payment was created

Returns:

  • (Time)


29
# File 'lib/dodopayments/models/payment.rb', line 29

required :created_at, Time

#currencySymbol, Dodopayments::Models::Currency

Currency used for the payment

Returns:



35
# File 'lib/dodopayments/models/payment.rb', line 35

required :currency, enum: -> { Dodopayments::Currency }

#custom_field_responsesArray<Dodopayments::Models::CustomFieldResponse>?

Customer’s responses to custom fields collected during checkout



145
146
147
# File 'lib/dodopayments/models/payment.rb', line 145

optional :custom_field_responses,
-> { Dodopayments::Internal::Type::ArrayOf[Dodopayments::CustomFieldResponse] },
nil?: true

#customerDodopayments::Models::CustomerLimitedDetails

Details about the customer who made the payment



41
# File 'lib/dodopayments/models/payment.rb', line 41

required :customer, -> { Dodopayments::CustomerLimitedDetails }

#digital_products_deliveredBoolean

brand id this payment belongs to

Returns:

  • (Boolean)


47
# File 'lib/dodopayments/models/payment.rb', line 47

required :digital_products_delivered, Dodopayments::Internal::Type::Boolean

#discount_idString?

Deprecated.

Use ‘discounts` instead.

DEPRECATED: Use discounts instead. Returns the first discount’s ID if present.

Returns:

  • (String, nil)


155
# File 'lib/dodopayments/models/payment.rb', line 155

optional :discount_id, String, nil?: true

#discountsArray<Dodopayments::Models::DiscountDetail>?

All stacked discounts applied, ordered by position

Returns:



161
162
163
# File 'lib/dodopayments/models/payment.rb', line 161

optional :discounts,
-> { Dodopayments::Internal::Type::ArrayOf[Dodopayments::DiscountDetail] },
nil?: true

#disputesArray<Dodopayments::Models::Dispute>

List of disputes associated with this payment

Returns:



53
# File 'lib/dodopayments/models/payment.rb', line 53

required :disputes, -> { Dodopayments::Internal::Type::ArrayOf[Dodopayments::Dispute] }

#error_codeString?

An error code if the payment failed

Returns:

  • (String, nil)


169
# File 'lib/dodopayments/models/payment.rb', line 169

optional :error_code, String, nil?: true

#error_messageString?

An error message if the payment failed

Returns:

  • (String, nil)


175
# File 'lib/dodopayments/models/payment.rb', line 175

optional :error_message, String, nil?: true

#invoice_idString?

Invoice ID for this payment. Uses India-specific invoice ID if available.

Returns:

  • (String, nil)


181
# File 'lib/dodopayments/models/payment.rb', line 181

optional :invoice_id, String, nil?: true

#invoice_urlString?

URL to download the invoice PDF for this payment.

Returns:

  • (String, nil)


187
# File 'lib/dodopayments/models/payment.rb', line 187

optional :invoice_url, String, nil?: true

#metadataHash{Symbol=>String}

Additional custom data associated with the payment

Returns:

  • (Hash{Symbol=>String})


59
# File 'lib/dodopayments/models/payment.rb', line 59

required :metadata, Dodopayments::Internal::Type::HashOf[String]

#payment_idString

Unique identifier for the payment

Returns:

  • (String)


65
# File 'lib/dodopayments/models/payment.rb', line 65

required :payment_id, String

Checkout URL

Returns:

  • (String, nil)


193
# File 'lib/dodopayments/models/payment.rb', line 193

optional :payment_link, String, nil?: true

#payment_methodString?

Payment method used by customer (e.g. “card”, “bank_transfer”)

Returns:

  • (String, nil)


199
# File 'lib/dodopayments/models/payment.rb', line 199

optional :payment_method, String, nil?: true

#payment_method_typeString?

Specific type of payment method (e.g. “visa”, “mastercard”)

Returns:

  • (String, nil)


205
# File 'lib/dodopayments/models/payment.rb', line 205

optional :payment_method_type, String, nil?: true

#product_cartArray<Dodopayments::Models::Payment::ProductCart>?

List of products purchased in a one-time payment



211
212
213
# File 'lib/dodopayments/models/payment.rb', line 211

optional :product_cart,
-> { Dodopayments::Internal::Type::ArrayOf[Dodopayments::Payment::ProductCart] },
nil?: true

#refund_statusSymbol, ...

Summary of the refund status for this payment. None if no succeeded refunds exist.



220
# File 'lib/dodopayments/models/payment.rb', line 220

optional :refund_status, enum: -> { Dodopayments::PaymentRefundStatus }, nil?: true

#refundsArray<Dodopayments::Models::RefundListItem>

List of refunds issued for this payment



71
# File 'lib/dodopayments/models/payment.rb', line 71

required :refunds, -> { Dodopayments::Internal::Type::ArrayOf[Dodopayments::RefundListItem] }

#retry_attemptInteger

Retry attempt number for subscription renewal payments. ‘0` for the original payment, `1`+ for each scheduled off-session retry after a failed renewal. Always `0` for non-subscription payments.

Returns:

  • (Integer)


79
# File 'lib/dodopayments/models/payment.rb', line 79

required :retry_attempt, Integer

#settlement_amountInteger

The amount that will be credited to your Dodo balance after currency conversion and processing. Especially relevant for adaptive pricing where the customer’s payment currency differs from your settlement currency.

Returns:

  • (Integer)


87
# File 'lib/dodopayments/models/payment.rb', line 87

required :settlement_amount, Integer

#settlement_currencySymbol, Dodopayments::Models::Currency

The currency in which the settlement_amount will be credited to your Dodo balance. This may differ from the customer’s payment currency in adaptive pricing scenarios.

Returns:



95
# File 'lib/dodopayments/models/payment.rb', line 95

required :settlement_currency, enum: -> { Dodopayments::Currency }

#settlement_taxInteger?

This represents the portion of settlement_amount that corresponds to taxes collected. Especially relevant for adaptive pricing where the tax component must be tracked separately in your Dodo balance.

Returns:

  • (Integer, nil)


228
# File 'lib/dodopayments/models/payment.rb', line 228

optional :settlement_tax, Integer, nil?: true

#statusSymbol, ...

Current status of the payment intent

Returns:



234
# File 'lib/dodopayments/models/payment.rb', line 234

optional :status, enum: -> { Dodopayments::IntentStatus }, nil?: true

#subscription_idString?

Identifier of the subscription if payment is part of a subscription

Returns:

  • (String, nil)


240
# File 'lib/dodopayments/models/payment.rb', line 240

optional :subscription_id, String, nil?: true

#taxInteger?

Amount of tax collected in smallest currency unit (e.g. cents)

Returns:

  • (Integer, nil)


246
# File 'lib/dodopayments/models/payment.rb', line 246

optional :tax, Integer, nil?: true

#total_amountInteger

Total amount charged to the customer including tax, in smallest currency unit (e.g. cents)

Returns:

  • (Integer)


102
# File 'lib/dodopayments/models/payment.rb', line 102

required :total_amount, Integer

#updated_atTime?

Timestamp when the payment was last updated

Returns:

  • (Time, nil)


252
# File 'lib/dodopayments/models/payment.rb', line 252

optional :updated_at, Time, nil?: true