Class: Dodopayments::Models::Payment

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/dodopayments/models/payment.rb

Overview

Direct Known Subclasses

WebhookPayload::Data::Payment

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(billing:, brand_id:, business_id:, created_at:, currency:, customer:, digital_products_delivered:, disputes:, metadata:, payment_id:, refunds:, settlement_amount:, settlement_currency:, total_amount:, card_holder_name: nil, card_issuing_country: nil, card_last_four: nil, card_network: nil, card_type: nil, checkout_session_id: nil, custom_field_responses: nil, discount_id: nil, error_code: nil, error_message: nil, invoice_id: nil, invoice_url: nil, payment_link: nil, payment_method: nil, payment_method_type: nil, product_cart: nil, refund_status: nil, settlement_tax: nil, status: nil, subscription_id: nil, tax: nil, updated_at: nil) ⇒ Object

Some parameter documentations has been truncated, see Dodopayments::Models::Payment for more details.

Parameters:

  • billing (Dodopayments::Models::BillingAddress)

    Billing address details for payments

  • brand_id (String)

    brand id this payment belongs to

  • business_id (String)

    Identifier of the business associated with the payment

  • created_at (Time)

    Timestamp when the payment was created

  • currency (Symbol, Dodopayments::Models::Currency)

    Currency used for the payment

  • customer (Dodopayments::Models::CustomerLimitedDetails)

    Details about the customer who made the payment

  • digital_products_delivered (Boolean)

    brand id this payment belongs to

  • disputes (Array<Dodopayments::Models::Dispute>)

    List of disputes associated with this payment

  • metadata (Hash{Symbol=>String})

    Additional custom data associated with the payment

  • payment_id (String)

    Unique identifier for the payment

  • refunds (Array<Dodopayments::Models::RefundListItem>)

    List of refunds issued for this payment

  • settlement_amount (Integer)

    The amount that will be credited to your Dodo balance after currency conversion

  • settlement_currency (Symbol, Dodopayments::Models::Currency)

    The currency in which the settlement_amount will be credited to your Dodo balanc

  • total_amount (Integer)

    Total amount charged to the customer including tax, in smallest currency unit (e

  • card_holder_name (String, nil) (defaults to: nil)

    Cardholder name

  • card_issuing_country (Symbol, Dodopayments::Models::CountryCode, nil) (defaults to: nil)

    ISO2 country code of the card

  • card_last_four (String, nil) (defaults to: nil)

    The last four digits of the card

  • card_network (String, nil) (defaults to: nil)

    Card network like VISA, MASTERCARD etc.

  • card_type (String, nil) (defaults to: nil)

    The type of card DEBIT or CREDIT

  • checkout_session_id (String, nil) (defaults to: nil)

    If payment is made using a checkout session,

  • custom_field_responses (Array<Dodopayments::Models::CustomFieldResponse>, nil) (defaults to: nil)

    Customer’s responses to custom fields collected during checkout

  • discount_id (String, nil) (defaults to: nil)

    The discount id if discount is applied

  • error_code (String, nil) (defaults to: nil)

    An error code if the payment failed

  • error_message (String, nil) (defaults to: nil)

    An error message if the payment failed

  • invoice_id (String, nil) (defaults to: nil)

    Invoice ID for this payment. Uses India-specific invoice ID if available.

  • invoice_url (String, nil) (defaults to: nil)

    URL to download the invoice PDF for this payment.

  • payment_link (String, nil) (defaults to: nil)

    Checkout URL

  • payment_method (String, nil) (defaults to: nil)

    Payment method used by customer (e.g. “card”, “bank_transfer”)

  • payment_method_type (String, nil) (defaults to: nil)

    Specific type of payment method (e.g. “visa”, “mastercard”)

  • product_cart (Array<Dodopayments::Models::OneTimeProductCartItem>, nil) (defaults to: nil)

    List of products purchased in a one-time payment

  • refund_status (Symbol, Dodopayments::Models::PaymentRefundStatus, nil) (defaults to: nil)

    Summary of the refund status for this payment. None if no succeeded refunds exis

  • settlement_tax (Integer, nil) (defaults to: nil)

    This represents the portion of settlement_amount that corresponds to taxes colle

  • status (Symbol, Dodopayments::Models::IntentStatus, nil) (defaults to: nil)

    Current status of the payment intent

  • subscription_id (String, nil) (defaults to: nil)

    Identifier of the subscription if payment is part of a subscription

  • tax (Integer, nil) (defaults to: nil)

    Amount of tax collected in smallest currency unit (e.g. cents)

  • updated_at (Time, nil) (defaults to: nil)

    Timestamp when the payment was last updated



# File 'lib/dodopayments/models/payment.rb', line 236

Instance Attribute Details

#billingDodopayments::Models::BillingAddress

Billing address details for payments



11
# File 'lib/dodopayments/models/payment.rb', line 11

required :billing, -> { Dodopayments::BillingAddress }

#brand_idString

brand id this payment belongs to

Returns:

  • (String)


17
# File 'lib/dodopayments/models/payment.rb', line 17

required :brand_id, String

#business_idString

Identifier of the business associated with the payment

Returns:

  • (String)


23
# File 'lib/dodopayments/models/payment.rb', line 23

required :business_id, String

#card_holder_nameString?

Cardholder name

Returns:

  • (String, nil)


100
# File 'lib/dodopayments/models/payment.rb', line 100

optional :card_holder_name, String, nil?: true

#card_issuing_countrySymbol, ...

ISO2 country code of the card

Returns:



106
# File 'lib/dodopayments/models/payment.rb', line 106

optional :card_issuing_country, enum: -> { Dodopayments::CountryCode }, nil?: true

#card_last_fourString?

The last four digits of the card

Returns:

  • (String, nil)


112
# File 'lib/dodopayments/models/payment.rb', line 112

optional :card_last_four, String, nil?: true

#card_networkString?

Card network like VISA, MASTERCARD etc.

Returns:

  • (String, nil)


118
# File 'lib/dodopayments/models/payment.rb', line 118

optional :card_network, String, nil?: true

#card_typeString?

The type of card DEBIT or CREDIT

Returns:

  • (String, nil)


124
# File 'lib/dodopayments/models/payment.rb', line 124

optional :card_type, String, nil?: true

#checkout_session_idString?

If payment is made using a checkout session, this field is set to the id of the session.

Returns:

  • (String, nil)


131
# File 'lib/dodopayments/models/payment.rb', line 131

optional :checkout_session_id, String, nil?: true

#created_atTime

Timestamp when the payment was created

Returns:

  • (Time)


29
# File 'lib/dodopayments/models/payment.rb', line 29

required :created_at, Time

#currencySymbol, Dodopayments::Models::Currency

Currency used for the payment

Returns:



35
# File 'lib/dodopayments/models/payment.rb', line 35

required :currency, enum: -> { Dodopayments::Currency }

#custom_field_responsesArray<Dodopayments::Models::CustomFieldResponse>?

Customer’s responses to custom fields collected during checkout



137
138
139
# File 'lib/dodopayments/models/payment.rb', line 137

optional :custom_field_responses,
-> { Dodopayments::Internal::Type::ArrayOf[Dodopayments::CustomFieldResponse] },
nil?: true

#customerDodopayments::Models::CustomerLimitedDetails

Details about the customer who made the payment



41
# File 'lib/dodopayments/models/payment.rb', line 41

required :customer, -> { Dodopayments::CustomerLimitedDetails }

#digital_products_deliveredBoolean

brand id this payment belongs to

Returns:

  • (Boolean)


47
# File 'lib/dodopayments/models/payment.rb', line 47

required :digital_products_delivered, Dodopayments::Internal::Type::Boolean

#discount_idString?

The discount id if discount is applied

Returns:

  • (String, nil)


145
# File 'lib/dodopayments/models/payment.rb', line 145

optional :discount_id, String, nil?: true

#disputesArray<Dodopayments::Models::Dispute>

List of disputes associated with this payment

Returns:



53
# File 'lib/dodopayments/models/payment.rb', line 53

required :disputes, -> { Dodopayments::Internal::Type::ArrayOf[Dodopayments::Dispute] }

#error_codeString?

An error code if the payment failed

Returns:

  • (String, nil)


151
# File 'lib/dodopayments/models/payment.rb', line 151

optional :error_code, String, nil?: true

#error_messageString?

An error message if the payment failed

Returns:

  • (String, nil)


157
# File 'lib/dodopayments/models/payment.rb', line 157

optional :error_message, String, nil?: true

#invoice_idString?

Invoice ID for this payment. Uses India-specific invoice ID if available.

Returns:

  • (String, nil)


163
# File 'lib/dodopayments/models/payment.rb', line 163

optional :invoice_id, String, nil?: true

#invoice_urlString?

URL to download the invoice PDF for this payment.

Returns:

  • (String, nil)


169
# File 'lib/dodopayments/models/payment.rb', line 169

optional :invoice_url, String, nil?: true

#metadataHash{Symbol=>String}

Additional custom data associated with the payment

Returns:

  • (Hash{Symbol=>String})


59
# File 'lib/dodopayments/models/payment.rb', line 59

required :metadata, Dodopayments::Internal::Type::HashOf[String]

#payment_idString

Unique identifier for the payment

Returns:

  • (String)


65
# File 'lib/dodopayments/models/payment.rb', line 65

required :payment_id, String

Checkout URL

Returns:

  • (String, nil)


175
# File 'lib/dodopayments/models/payment.rb', line 175

optional :payment_link, String, nil?: true

#payment_methodString?

Payment method used by customer (e.g. “card”, “bank_transfer”)

Returns:

  • (String, nil)


181
# File 'lib/dodopayments/models/payment.rb', line 181

optional :payment_method, String, nil?: true

#payment_method_typeString?

Specific type of payment method (e.g. “visa”, “mastercard”)

Returns:

  • (String, nil)


187
# File 'lib/dodopayments/models/payment.rb', line 187

optional :payment_method_type, String, nil?: true

#product_cartArray<Dodopayments::Models::OneTimeProductCartItem>?

List of products purchased in a one-time payment



193
194
195
# File 'lib/dodopayments/models/payment.rb', line 193

optional :product_cart,
-> { Dodopayments::Internal::Type::ArrayOf[Dodopayments::OneTimeProductCartItem] },
nil?: true

#refund_statusSymbol, ...

Summary of the refund status for this payment. None if no succeeded refunds exist.



202
# File 'lib/dodopayments/models/payment.rb', line 202

optional :refund_status, enum: -> { Dodopayments::PaymentRefundStatus }, nil?: true

#refundsArray<Dodopayments::Models::RefundListItem>

List of refunds issued for this payment



71
# File 'lib/dodopayments/models/payment.rb', line 71

required :refunds, -> { Dodopayments::Internal::Type::ArrayOf[Dodopayments::RefundListItem] }

#settlement_amountInteger

The amount that will be credited to your Dodo balance after currency conversion and processing. Especially relevant for adaptive pricing where the customer’s payment currency differs from your settlement currency.

Returns:

  • (Integer)


79
# File 'lib/dodopayments/models/payment.rb', line 79

required :settlement_amount, Integer

#settlement_currencySymbol, Dodopayments::Models::Currency

The currency in which the settlement_amount will be credited to your Dodo balance. This may differ from the customer’s payment currency in adaptive pricing scenarios.

Returns:



87
# File 'lib/dodopayments/models/payment.rb', line 87

required :settlement_currency, enum: -> { Dodopayments::Currency }

#settlement_taxInteger?

This represents the portion of settlement_amount that corresponds to taxes collected. Especially relevant for adaptive pricing where the tax component must be tracked separately in your Dodo balance.

Returns:

  • (Integer, nil)


210
# File 'lib/dodopayments/models/payment.rb', line 210

optional :settlement_tax, Integer, nil?: true

#statusSymbol, ...

Current status of the payment intent

Returns:



216
# File 'lib/dodopayments/models/payment.rb', line 216

optional :status, enum: -> { Dodopayments::IntentStatus }, nil?: true

#subscription_idString?

Identifier of the subscription if payment is part of a subscription

Returns:

  • (String, nil)


222
# File 'lib/dodopayments/models/payment.rb', line 222

optional :subscription_id, String, nil?: true

#taxInteger?

Amount of tax collected in smallest currency unit (e.g. cents)

Returns:

  • (Integer, nil)


228
# File 'lib/dodopayments/models/payment.rb', line 228

optional :tax, Integer, nil?: true

#total_amountInteger

Total amount charged to the customer including tax, in smallest currency unit (e.g. cents)

Returns:

  • (Integer)


94
# File 'lib/dodopayments/models/payment.rb', line 94

required :total_amount, Integer

#updated_atTime?

Timestamp when the payment was last updated

Returns:

  • (Time, nil)


234
# File 'lib/dodopayments/models/payment.rb', line 234

optional :updated_at, Time, nil?: true