Class: Dodopayments::Models::PaymentCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Dodopayments::Models::PaymentCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/dodopayments/models/payment_create_params.rb
Overview
Instance Attribute Summary collapse
-
#adaptive_currency_fees_inclusive ⇒ Boolean?
Whether adaptive currency fees should be included in the price (true) or added on top (false).
-
#allowed_payment_method_types ⇒ Array<Symbol, Dodopayments::Models::PaymentMethodTypes>?
List of payment methods allowed during checkout.
-
#billing ⇒ Dodopayments::Models::BillingAddress
Billing address details for the payment.
-
#billing_currency ⇒ Symbol, ...
Fix the currency in which the end customer is billed.
-
#customer ⇒ Dodopayments::Models::AttachExistingCustomer, Dodopayments::Models::NewCustomer
Customer information for the payment.
-
#discount_code ⇒ String?
Discount Code to apply to the transaction.
-
#force_3ds ⇒ Boolean?
Override merchant default 3DS behaviour for this payment.
-
#metadata ⇒ Hash{Symbol=>String}?
Additional metadata associated with the payment.
-
#payment_link ⇒ Boolean?
Whether to generate a payment link.
-
#payment_method_id ⇒ String?
Optional payment method ID to use for this payment.
-
#product_cart ⇒ Array<Dodopayments::Models::OneTimeProductCartItem>
List of products in the cart.
-
#redirect_immediately ⇒ Boolean?
If true, redirects the customer immediately after payment completion False by default.
-
#require_phone_number ⇒ Boolean?
If true, the customer’s phone number is required to create this payment.
-
#return_url ⇒ String?
Optional URL to redirect the customer after payment.
-
#short_link ⇒ Boolean?
If true, returns a shortened payment link.
-
#show_saved_payment_methods ⇒ Boolean?
Display saved payment methods of a returning customer False by default.
-
#tax_id ⇒ String?
Tax ID in case the payment is B2B.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(billing:, customer:, product_cart:, adaptive_currency_fees_inclusive: nil, allowed_payment_method_types: nil, billing_currency: nil, discount_code: nil, force_3ds: nil, metadata: nil, payment_link: nil, payment_method_id: nil, redirect_immediately: nil, require_phone_number: nil, return_url: nil, short_link: nil, show_saved_payment_methods: nil, tax_id: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see PaymentCreateParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(billing:, customer:, product_cart:, adaptive_currency_fees_inclusive: nil, allowed_payment_method_types: nil, billing_currency: nil, discount_code: nil, force_3ds: nil, metadata: nil, payment_link: nil, payment_method_id: nil, redirect_immediately: nil, require_phone_number: nil, return_url: nil, short_link: nil, show_saved_payment_methods: nil, tax_id: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Dodopayments::Models::PaymentCreateParams for more details.
|
|
# File 'lib/dodopayments/models/payment_create_params.rb', line 129
|
Instance Attribute Details
#adaptive_currency_fees_inclusive ⇒ Boolean?
Whether adaptive currency fees should be included in the price (true) or added on top (false). If not specified, defaults to the business-level setting.
33 |
# File 'lib/dodopayments/models/payment_create_params.rb', line 33 optional :adaptive_currency_fees_inclusive, Dodopayments::Internal::Type::Boolean, nil?: true |
#allowed_payment_method_types ⇒ Array<Symbol, Dodopayments::Models::PaymentMethodTypes>?
List of payment methods allowed during checkout.
Customers will never see payment methods that are not in this list. However, adding a method here **does not guarantee** customers will see it. Availability still depends on other factors (e.g., customer location, merchant settings).
44 45 46 |
# File 'lib/dodopayments/models/payment_create_params.rb', line 44 optional :allowed_payment_method_types, -> { Dodopayments::Internal::Type::ArrayOf[enum: Dodopayments::PaymentMethodTypes] }, nil?: true |
#billing ⇒ Dodopayments::Models::BillingAddress
Billing address details for the payment
14 |
# File 'lib/dodopayments/models/payment_create_params.rb', line 14 required :billing, -> { Dodopayments::BillingAddress } |
#billing_currency ⇒ Symbol, ...
Fix the currency in which the end customer is billed. If Dodo Payments cannot support that currency for this transaction, it will not proceed
53 |
# File 'lib/dodopayments/models/payment_create_params.rb', line 53 optional :billing_currency, enum: -> { Dodopayments::Currency }, nil?: true |
#customer ⇒ Dodopayments::Models::AttachExistingCustomer, Dodopayments::Models::NewCustomer
Customer information for the payment
20 |
# File 'lib/dodopayments/models/payment_create_params.rb', line 20 required :customer, union: -> { Dodopayments::CustomerRequest } |
#discount_code ⇒ String?
Discount Code to apply to the transaction
59 |
# File 'lib/dodopayments/models/payment_create_params.rb', line 59 optional :discount_code, String, nil?: true |
#force_3ds ⇒ Boolean?
Override merchant default 3DS behaviour for this payment
65 |
# File 'lib/dodopayments/models/payment_create_params.rb', line 65 optional :force_3ds, Dodopayments::Internal::Type::Boolean, nil?: true |
#metadata ⇒ Hash{Symbol=>String}?
Additional metadata associated with the payment. Defaults to empty if not provided.
72 |
# File 'lib/dodopayments/models/payment_create_params.rb', line 72 optional :metadata, Dodopayments::Internal::Type::HashOf[String] |
#payment_link ⇒ Boolean?
Whether to generate a payment link. Defaults to false if not specified.
78 |
# File 'lib/dodopayments/models/payment_create_params.rb', line 78 optional :payment_link, Dodopayments::Internal::Type::Boolean, nil?: true |
#payment_method_id ⇒ String?
Optional payment method ID to use for this payment. If provided, customer_id must also be provided. The payment method will be validated for eligibility with the payment’s currency.
86 |
# File 'lib/dodopayments/models/payment_create_params.rb', line 86 optional :payment_method_id, String, nil?: true |
#product_cart ⇒ Array<Dodopayments::Models::OneTimeProductCartItem>
List of products in the cart. Must contain at least 1 and at most 100 items.
26 |
# File 'lib/dodopayments/models/payment_create_params.rb', line 26 required :product_cart, -> { Dodopayments::Internal::Type::ArrayOf[Dodopayments::OneTimeProductCartItem] } |
#redirect_immediately ⇒ Boolean?
If true, redirects the customer immediately after payment completion False by default
93 |
# File 'lib/dodopayments/models/payment_create_params.rb', line 93 optional :redirect_immediately, Dodopayments::Internal::Type::Boolean |
#require_phone_number ⇒ Boolean?
If true, the customer’s phone number is required to create this payment. Typically set alongside ‘payment_link=true` so merchants can enforce phone collection on the hosted payment page. Defaults to false.
101 |
# File 'lib/dodopayments/models/payment_create_params.rb', line 101 optional :require_phone_number, Dodopayments::Internal::Type::Boolean |
#return_url ⇒ String?
Optional URL to redirect the customer after payment. Must be a valid URL if provided.
108 |
# File 'lib/dodopayments/models/payment_create_params.rb', line 108 optional :return_url, String, nil?: true |
#short_link ⇒ Boolean?
If true, returns a shortened payment link. Defaults to false if not specified.
114 |
# File 'lib/dodopayments/models/payment_create_params.rb', line 114 optional :short_link, Dodopayments::Internal::Type::Boolean, nil?: true |
#show_saved_payment_methods ⇒ Boolean?
Display saved payment methods of a returning customer False by default
120 |
# File 'lib/dodopayments/models/payment_create_params.rb', line 120 optional :show_saved_payment_methods, Dodopayments::Internal::Type::Boolean |
#tax_id ⇒ String?
Tax ID in case the payment is B2B. If tax id validation fails the payment creation will fail
127 |
# File 'lib/dodopayments/models/payment_create_params.rb', line 127 optional :tax_id, String, nil?: true |