Class: Dodopayments::Models::Payouts::Breakup::DetailListResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/dodopayments/models/payouts/breakup/detail_list_response.rb

Overview

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, created_at:, event_type:, original_amount:, original_currency:, payout_currency_amount:, usd_equivalent_amount:, description: nil, reference_object_id: nil) ⇒ Object

Some parameter documentations has been truncated, see Dodopayments::Models::Payouts::Breakup::DetailListResponse for more details.

Individual balance ledger entry for a payout, with amounts pro-rated into the payout’s currency.

Parameters:

  • id (String)

    Unique identifier of the balance ledger entry.

  • created_at (Time)

    Timestamp when this entry was created.

  • event_type (String)

    The type of balance ledger event (e.g., “payment”, “refund”, “dispute”, “payment

  • original_amount (Integer)

    Original amount in the original currency (in smallest currency unit, e.g., cents

  • original_currency (String)

    Original currency as ISO 4217 code (e.g., “USD”, “EUR”).

  • payout_currency_amount (Integer)

    Amount in the payout’s currency (in smallest currency unit). Uses cumulative rou

  • usd_equivalent_amount (Integer)

    USD equivalent of the original amount (in cents).

  • description (String, nil) (defaults to: nil)

    Human-readable description of the transaction.

  • reference_object_id (String, nil) (defaults to: nil)

    ID of the related object (e.g., payment ID, refund ID) if applicable.



# File 'lib/dodopayments/models/payouts/breakup/detail_list_response.rb', line 66

Instance Attribute Details

#created_atTime

Timestamp when this entry was created.

Returns:

  • (Time)


19
# File 'lib/dodopayments/models/payouts/breakup/detail_list_response.rb', line 19

required :created_at, Time

#descriptionString?

Human-readable description of the transaction.

Returns:

  • (String, nil)


58
# File 'lib/dodopayments/models/payouts/breakup/detail_list_response.rb', line 58

optional :description, String, nil?: true

#event_typeString

The type of balance ledger event (e.g., “payment”, “refund”, “dispute”, “payment_fees”).

Returns:

  • (String)


26
# File 'lib/dodopayments/models/payouts/breakup/detail_list_response.rb', line 26

required :event_type, String

#idString

Unique identifier of the balance ledger entry.

Returns:

  • (String)


13
# File 'lib/dodopayments/models/payouts/breakup/detail_list_response.rb', line 13

required :id, String

#original_amountInteger

Original amount in the original currency (in smallest currency unit, e.g., cents).

Returns:

  • (Integer)


33
# File 'lib/dodopayments/models/payouts/breakup/detail_list_response.rb', line 33

required :original_amount, Integer

#original_currencyString

Original currency as ISO 4217 code (e.g., “USD”, “EUR”).

Returns:

  • (String)


39
# File 'lib/dodopayments/models/payouts/breakup/detail_list_response.rb', line 39

required :original_currency, String

#payout_currency_amountInteger

Amount in the payout’s currency (in smallest currency unit). Uses cumulative rounding to ensure sum matches payout total exactly.

Returns:

  • (Integer)


46
# File 'lib/dodopayments/models/payouts/breakup/detail_list_response.rb', line 46

required :payout_currency_amount, Integer

#reference_object_idString?

ID of the related object (e.g., payment ID, refund ID) if applicable.

Returns:

  • (String, nil)


64
# File 'lib/dodopayments/models/payouts/breakup/detail_list_response.rb', line 64

optional :reference_object_id, String, nil?: true

#usd_equivalent_amountInteger

USD equivalent of the original amount (in cents).

Returns:

  • (Integer)


52
# File 'lib/dodopayments/models/payouts/breakup/detail_list_response.rb', line 52

required :usd_equivalent_amount, Integer