Class: Dodopayments::Models::Price::RecurringPrice
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Dodopayments::Models::Price::RecurringPrice
- Defined in:
- lib/dodopayments/models/price.rb
Instance Attribute Summary collapse
-
#currency ⇒ Symbol, Dodopayments::Models::Currency
The currency in which the payment is made.
-
#discount ⇒ Integer
Discount applied to the price, represented as a percentage (0 to 100).
-
#payment_frequency_count ⇒ Integer
Number of units for the payment frequency.
-
#payment_frequency_interval ⇒ Symbol, Dodopayments::Models::TimeInterval
The time interval for the payment frequency (e.g., day, month, year).
-
#price ⇒ Integer
The payment amount.
-
#purchasing_power_parity ⇒ Boolean
Indicates if purchasing power parity adjustments are applied to the price.
-
#subscription_period_count ⇒ Integer
Number of units for the subscription period.
-
#subscription_period_interval ⇒ Symbol, Dodopayments::Models::TimeInterval
The time interval for the subscription period (e.g., day, month, year).
-
#tax_inclusive ⇒ Boolean?
Indicates if the price is tax inclusive.
-
#trial_period_days ⇒ Integer?
Number of days for the trial period.
- #type ⇒ Symbol, :recurring_price
Method Summary
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from Dodopayments::Internal::Type::BaseModel
Instance Attribute Details
#currency ⇒ Symbol, Dodopayments::Models::Currency
The currency in which the payment is made.
104 |
# File 'lib/dodopayments/models/price.rb', line 104 required :currency, enum: -> { Dodopayments::Currency } |
#discount ⇒ Integer
Discount applied to the price, represented as a percentage (0 to 100).
110 |
# File 'lib/dodopayments/models/price.rb', line 110 required :discount, Integer |
#payment_frequency_count ⇒ Integer
Number of units for the payment frequency. For example, a value of ‘1` with a `payment_frequency_interval` of `month` represents monthly payments.
117 |
# File 'lib/dodopayments/models/price.rb', line 117 required :payment_frequency_count, Integer |
#payment_frequency_interval ⇒ Symbol, Dodopayments::Models::TimeInterval
The time interval for the payment frequency (e.g., day, month, year).
123 |
# File 'lib/dodopayments/models/price.rb', line 123 required :payment_frequency_interval, enum: -> { Dodopayments::TimeInterval } |
#price ⇒ Integer
The payment amount. Represented in the lowest denomination of the currency (e.g., cents for USD). For example, to charge $1.00, pass ‘100`.
130 |
# File 'lib/dodopayments/models/price.rb', line 130 required :price, Integer |
#purchasing_power_parity ⇒ Boolean
Indicates if purchasing power parity adjustments are applied to the price. Purchasing power parity feature is not available as of now
137 |
# File 'lib/dodopayments/models/price.rb', line 137 required :purchasing_power_parity, Dodopayments::Internal::Type::Boolean |
#subscription_period_count ⇒ Integer
Number of units for the subscription period. For example, a value of ‘12` with a `subscription_period_interval` of `month` represents a one-year subscription.
144 |
# File 'lib/dodopayments/models/price.rb', line 144 required :subscription_period_count, Integer |
#subscription_period_interval ⇒ Symbol, Dodopayments::Models::TimeInterval
The time interval for the subscription period (e.g., day, month, year).
150 |
# File 'lib/dodopayments/models/price.rb', line 150 required :subscription_period_interval, enum: -> { Dodopayments::TimeInterval } |
#tax_inclusive ⇒ Boolean?
Indicates if the price is tax inclusive
161 |
# File 'lib/dodopayments/models/price.rb', line 161 optional :tax_inclusive, Dodopayments::Internal::Type::Boolean, nil?: true |
#trial_period_days ⇒ Integer?
Number of days for the trial period. A value of ‘0` indicates no trial period.
167 |
# File 'lib/dodopayments/models/price.rb', line 167 optional :trial_period_days, Integer |
#type ⇒ Symbol, :recurring_price
155 |
# File 'lib/dodopayments/models/price.rb', line 155 required :type, const: :recurring_price |