Class: Dodopayments::Models::Product
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Dodopayments::Models::Product
- Defined in:
- lib/dodopayments/models/product.rb
Overview
Defined Under Namespace
Classes: Entitlement
Instance Attribute Summary collapse
-
#addons ⇒ Array<String>?
Available Addons for subscription products.
- #brand_id ⇒ String
-
#business_id ⇒ String
Unique identifier for the business to which the product belongs.
-
#created_at ⇒ Time
Timestamp when the product was created.
-
#credit_entitlements ⇒ Array<Dodopayments::Models::CreditEntitlementMappingResponse>
Attached credit entitlements with settings.
-
#description ⇒ String?
Description of the product, optional.
- #digital_product_delivery ⇒ Dodopayments::Models::DigitalProductDelivery?
-
#entitlements ⇒ Array<Dodopayments::Models::Product::Entitlement>
Attached entitlements (integration-based access grants).
-
#image ⇒ String?
URL of the product image, optional.
-
#is_recurring ⇒ Boolean
Indicates if the product is recurring (e.g., subscriptions).
- #license_key_activation_message ⇒ String? deprecated Deprecated.
- #license_key_activations_limit ⇒ Integer? deprecated Deprecated.
-
#license_key_duration ⇒ Dodopayments::Models::LicenseKeyDuration?
Duration of the license key validity, if enabled.
- #license_key_enabled ⇒ Boolean deprecated Deprecated.
-
#metadata ⇒ Hash{Symbol=>String}
Additional custom data associated with the product.
-
#name ⇒ String?
Name of the product, optional.
-
#price ⇒ Dodopayments::Models::Price::OneTimePrice, ...
Pricing information for the product.
-
#product_collection_id ⇒ String?
The product collection ID this product belongs to, if any.
-
#product_id ⇒ String
Unique identifier for the product.
-
#tax_category ⇒ Symbol, Dodopayments::Models::TaxCategory
Tax category associated with the product.
-
#updated_at ⇒ Time
Timestamp when the product was last updated.
Method Summary
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from Dodopayments::Internal::Type::BaseModel
Instance Attribute Details
#addons ⇒ Array<String>?
Available Addons for subscription products
85 |
# File 'lib/dodopayments/models/product.rb', line 85 optional :addons, Dodopayments::Internal::Type::ArrayOf[String], nil?: true |
#brand_id ⇒ String
10 |
# File 'lib/dodopayments/models/product.rb', line 10 required :brand_id, String |
#business_id ⇒ String
Unique identifier for the business to which the product belongs.
16 |
# File 'lib/dodopayments/models/product.rb', line 16 required :business_id, String |
#created_at ⇒ Time
Timestamp when the product was created.
22 |
# File 'lib/dodopayments/models/product.rb', line 22 required :created_at, Time |
#credit_entitlements ⇒ Array<Dodopayments::Models::CreditEntitlementMappingResponse>
Attached credit entitlements with settings
28 29 |
# File 'lib/dodopayments/models/product.rb', line 28 required :credit_entitlements, -> { Dodopayments::Internal::Type::ArrayOf[Dodopayments::CreditEntitlementMappingResponse] } |
#description ⇒ String?
Description of the product, optional.
91 |
# File 'lib/dodopayments/models/product.rb', line 91 optional :description, String, nil?: true |
#digital_product_delivery ⇒ Dodopayments::Models::DigitalProductDelivery?
96 |
# File 'lib/dodopayments/models/product.rb', line 96 optional :digital_product_delivery, -> { Dodopayments::DigitalProductDelivery }, nil?: true |
#entitlements ⇒ Array<Dodopayments::Models::Product::Entitlement>
Attached entitlements (integration-based access grants)
35 |
# File 'lib/dodopayments/models/product.rb', line 35 required :entitlements, -> { Dodopayments::Internal::Type::ArrayOf[Dodopayments::Product::Entitlement] } |
#image ⇒ String?
URL of the product image, optional.
102 |
# File 'lib/dodopayments/models/product.rb', line 102 optional :image, String, nil?: true |
#is_recurring ⇒ Boolean
Indicates if the product is recurring (e.g., subscriptions).
41 |
# File 'lib/dodopayments/models/product.rb', line 41 required :is_recurring, Dodopayments::Internal::Type::Boolean |
#license_key_activation_message ⇒ String?
Message sent upon license key activation, if applicable.
110 |
# File 'lib/dodopayments/models/product.rb', line 110 optional :license_key_activation_message, String, nil?: true |
#license_key_activations_limit ⇒ Integer?
Limit on the number of activations for the license key, if enabled.
118 |
# File 'lib/dodopayments/models/product.rb', line 118 optional :license_key_activations_limit, Integer, nil?: true |
#license_key_duration ⇒ Dodopayments::Models::LicenseKeyDuration?
Duration of the license key validity, if enabled.
124 |
# File 'lib/dodopayments/models/product.rb', line 124 optional :license_key_duration, -> { Dodopayments::LicenseKeyDuration }, nil?: true |
#license_key_enabled ⇒ Boolean
Indicates whether the product requires a license key.
49 |
# File 'lib/dodopayments/models/product.rb', line 49 required :license_key_enabled, Dodopayments::Internal::Type::Boolean |
#metadata ⇒ Hash{Symbol=>String}
Additional custom data associated with the product
55 |
# File 'lib/dodopayments/models/product.rb', line 55 required :metadata, Dodopayments::Internal::Type::HashOf[String] |
#name ⇒ String?
Name of the product, optional.
130 |
# File 'lib/dodopayments/models/product.rb', line 130 optional :name, String, nil?: true |
#price ⇒ Dodopayments::Models::Price::OneTimePrice, ...
Pricing information for the product.
61 |
# File 'lib/dodopayments/models/product.rb', line 61 required :price, union: -> { Dodopayments::Price } |
#product_collection_id ⇒ String?
The product collection ID this product belongs to, if any
136 |
# File 'lib/dodopayments/models/product.rb', line 136 optional :product_collection_id, String, nil?: true |
#product_id ⇒ String
Unique identifier for the product.
67 |
# File 'lib/dodopayments/models/product.rb', line 67 required :product_id, String |
#tax_category ⇒ Symbol, Dodopayments::Models::TaxCategory
Tax category associated with the product.
73 |
# File 'lib/dodopayments/models/product.rb', line 73 required :tax_category, enum: -> { Dodopayments::TaxCategory } |
#updated_at ⇒ Time
Timestamp when the product was last updated.
79 |
# File 'lib/dodopayments/models/product.rb', line 79 required :updated_at, Time |