Class: Dodopayments::Models::ProductCollection
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Dodopayments::Models::ProductCollection
- Defined in:
- lib/dodopayments/models/product_collection.rb
Overview
Defined Under Namespace
Modules: EffectiveAtOnDowngrade, EffectiveAtOnUpgrade, OnPaymentFailure, ProrationBillingModeOnDowngrade, ProrationBillingModeOnUpgrade
Instance Attribute Summary collapse
-
#brand_id ⇒ String
Brand ID for the collection.
-
#created_at ⇒ Time
Timestamp when the collection was created.
-
#description ⇒ String?
Description of the collection.
-
#effective_at_on_downgrade ⇒ Symbol, ...
Default effective_at setting for subscription plan downgrades (null = inherit from business).
-
#effective_at_on_upgrade ⇒ Symbol, ...
Default effective_at setting for subscription plan upgrades (null = inherit from business).
-
#groups ⇒ Array<Dodopayments::Models::ProductCollections::ProductCollectionGroupResponse>
Groups in this collection.
-
#id ⇒ String
Unique identifier for the product collection.
-
#image ⇒ String?
URL of the collection image.
-
#name ⇒ String
Name of the collection.
-
#on_payment_failure ⇒ Symbol, ...
Default behavior for subscription plan changes on payment failure (null = inherit from business).
-
#proration_billing_mode_on_downgrade ⇒ Symbol, ...
Default proration billing mode for subscription plan downgrades (null = inherit from business).
-
#proration_billing_mode_on_upgrade ⇒ Symbol, ...
Default proration billing mode for subscription plan upgrades (null = inherit from business).
-
#updated_at ⇒ Time
Timestamp when the collection was last updated.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(id:, brand_id:, created_at:, groups:, name:, updated_at:, description: nil, effective_at_on_downgrade: nil, effective_at_on_upgrade: nil, image: nil, on_payment_failure: nil, proration_billing_mode_on_downgrade: nil, proration_billing_mode_on_upgrade: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see ProductCollection for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, brand_id:, created_at:, groups:, name:, updated_at:, description: nil, effective_at_on_downgrade: nil, effective_at_on_upgrade: nil, image: nil, on_payment_failure: nil, proration_billing_mode_on_downgrade: nil, proration_billing_mode_on_upgrade: nil) ⇒ Object
Some parameter documentations has been truncated, see Dodopayments::Models::ProductCollection for more details.
|
|
# File 'lib/dodopayments/models/product_collection.rb', line 99
|
Instance Attribute Details
#brand_id ⇒ String
Brand ID for the collection
17 |
# File 'lib/dodopayments/models/product_collection.rb', line 17 required :brand_id, String |
#created_at ⇒ Time
Timestamp when the collection was created
23 |
# File 'lib/dodopayments/models/product_collection.rb', line 23 required :created_at, Time |
#description ⇒ String?
Description of the collection
48 |
# File 'lib/dodopayments/models/product_collection.rb', line 48 optional :description, String, nil?: true |
#effective_at_on_downgrade ⇒ Symbol, ...
Default effective_at setting for subscription plan downgrades (null = inherit from business)
55 56 57 |
# File 'lib/dodopayments/models/product_collection.rb', line 55 optional :effective_at_on_downgrade, enum: -> { Dodopayments::ProductCollection::EffectiveAtOnDowngrade }, nil?: true |
#effective_at_on_upgrade ⇒ Symbol, ...
Default effective_at setting for subscription plan upgrades (null = inherit from business)
64 65 66 |
# File 'lib/dodopayments/models/product_collection.rb', line 64 optional :effective_at_on_upgrade, enum: -> { Dodopayments::ProductCollection::EffectiveAtOnUpgrade }, nil?: true |
#groups ⇒ Array<Dodopayments::Models::ProductCollections::ProductCollectionGroupResponse>
Groups in this collection
29 30 |
# File 'lib/dodopayments/models/product_collection.rb', line 29 required :groups, -> { Dodopayments::Internal::Type::ArrayOf[Dodopayments::ProductCollections::ProductCollectionGroupResponse] } |
#id ⇒ String
Unique identifier for the product collection
11 |
# File 'lib/dodopayments/models/product_collection.rb', line 11 required :id, String |
#image ⇒ String?
URL of the collection image
72 |
# File 'lib/dodopayments/models/product_collection.rb', line 72 optional :image, String, nil?: true |
#name ⇒ String
Name of the collection
36 |
# File 'lib/dodopayments/models/product_collection.rb', line 36 required :name, String |
#on_payment_failure ⇒ Symbol, ...
Default behavior for subscription plan changes on payment failure (null = inherit from business)
79 |
# File 'lib/dodopayments/models/product_collection.rb', line 79 optional :on_payment_failure, enum: -> { Dodopayments::ProductCollection::OnPaymentFailure }, nil?: true |
#proration_billing_mode_on_downgrade ⇒ Symbol, ...
Default proration billing mode for subscription plan downgrades (null = inherit from business)
86 87 88 |
# File 'lib/dodopayments/models/product_collection.rb', line 86 optional :proration_billing_mode_on_downgrade, enum: -> { Dodopayments::ProductCollection::ProrationBillingModeOnDowngrade }, nil?: true |
#proration_billing_mode_on_upgrade ⇒ Symbol, ...
Default proration billing mode for subscription plan upgrades (null = inherit from business)
95 96 97 |
# File 'lib/dodopayments/models/product_collection.rb', line 95 optional :proration_billing_mode_on_upgrade, enum: -> { Dodopayments::ProductCollection::ProrationBillingModeOnUpgrade }, nil?: true |
#updated_at ⇒ Time
Timestamp when the collection was last updated
42 |
# File 'lib/dodopayments/models/product_collection.rb', line 42 required :updated_at, Time |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/dodopayments/models/product_collection.rb', line 139
|