Class: Dodopayments::Models::ProductCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Dodopayments::Models::ProductCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/dodopayments/models/product_create_params.rb
Overview
Defined Under Namespace
Classes: DigitalProductDelivery
Instance Attribute Summary collapse
-
#addons ⇒ Array<String>?
Addons available for subscription product.
-
#brand_id ⇒ String?
Brand id for the product, if not provided will default to primary brand.
-
#credit_entitlements ⇒ Array<Dodopayments::Models::AttachCreditEntitlement>?
Optional credit entitlements to attach (max 3).
-
#description ⇒ String?
Optional description of the product.
-
#digital_product_delivery ⇒ Dodopayments::Models::ProductCreateParams::DigitalProductDelivery?
Choose how you would like you digital product delivered.
-
#entitlement_ids ⇒ Array<String>?
Optional entitlement IDs to attach to this product (max 20).
- #license_key_activation_message ⇒ String? deprecated Deprecated.
- #license_key_activations_limit ⇒ Integer? deprecated Deprecated.
-
#license_key_duration ⇒ Dodopayments::Models::LicenseKeyDuration?
Duration configuration for the license key.
- #license_key_enabled ⇒ Boolean? deprecated Deprecated.
-
#metadata ⇒ Hash{Symbol=>String}?
Additional metadata for the product.
-
#name ⇒ String
Name of the product.
-
#price ⇒ Dodopayments::Models::Price::OneTimePrice, ...
Price configuration for the product.
-
#tax_category ⇒ Symbol, Dodopayments::Models::TaxCategory
Tax category applied to this product.
Attributes included from Internal::Type::RequestParameters
Method Summary
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from Dodopayments::Internal::Type::BaseModel
Instance Attribute Details
#addons ⇒ Array<String>?
Addons available for subscription product
32 |
# File 'lib/dodopayments/models/product_create_params.rb', line 32 optional :addons, Dodopayments::Internal::Type::ArrayOf[String], nil?: true |
#brand_id ⇒ String?
Brand id for the product, if not provided will default to primary brand
38 |
# File 'lib/dodopayments/models/product_create_params.rb', line 38 optional :brand_id, String, nil?: true |
#credit_entitlements ⇒ Array<Dodopayments::Models::AttachCreditEntitlement>?
Optional credit entitlements to attach (max 3)
44 45 46 |
# File 'lib/dodopayments/models/product_create_params.rb', line 44 optional :credit_entitlements, -> { Dodopayments::Internal::Type::ArrayOf[Dodopayments::AttachCreditEntitlement] }, nil?: true |
#description ⇒ String?
Optional description of the product
52 |
# File 'lib/dodopayments/models/product_create_params.rb', line 52 optional :description, String, nil?: true |
#digital_product_delivery ⇒ Dodopayments::Models::ProductCreateParams::DigitalProductDelivery?
Choose how you would like you digital product delivered
58 59 60 |
# File 'lib/dodopayments/models/product_create_params.rb', line 58 optional :digital_product_delivery, -> { Dodopayments::ProductCreateParams::DigitalProductDelivery }, nil?: true |
#entitlement_ids ⇒ Array<String>?
Optional entitlement IDs to attach to this product (max 20)
66 |
# File 'lib/dodopayments/models/product_create_params.rb', line 66 optional :entitlement_ids, Dodopayments::Internal::Type::ArrayOf[String], nil?: true |
#license_key_activation_message ⇒ String?
Optional message displayed during license key activation
74 |
# File 'lib/dodopayments/models/product_create_params.rb', line 74 optional :license_key_activation_message, String, nil?: true |
#license_key_activations_limit ⇒ Integer?
The number of times the license key can be activated. Must be 0 or greater
82 |
# File 'lib/dodopayments/models/product_create_params.rb', line 82 optional :license_key_activations_limit, Integer, nil?: true |
#license_key_duration ⇒ Dodopayments::Models::LicenseKeyDuration?
Duration configuration for the license key. Set to null if you don’t want the license key to expire. For subscriptions, the lifetime of the license key is tied to the subscription period
90 |
# File 'lib/dodopayments/models/product_create_params.rb', line 90 optional :license_key_duration, -> { Dodopayments::LicenseKeyDuration }, nil?: true |
#license_key_enabled ⇒ Boolean?
When true, generates and sends a license key to your customer. Defaults to false
98 |
# File 'lib/dodopayments/models/product_create_params.rb', line 98 optional :license_key_enabled, Dodopayments::Internal::Type::Boolean, nil?: true |
#metadata ⇒ Hash{Symbol=>String}?
Additional metadata for the product
104 |
# File 'lib/dodopayments/models/product_create_params.rb', line 104 optional :metadata, Dodopayments::Internal::Type::HashOf[String] |
#name ⇒ String
Name of the product
14 |
# File 'lib/dodopayments/models/product_create_params.rb', line 14 required :name, String |
#price ⇒ Dodopayments::Models::Price::OneTimePrice, ...
Price configuration for the product
20 |
# File 'lib/dodopayments/models/product_create_params.rb', line 20 required :price, union: -> { Dodopayments::Price } |
#tax_category ⇒ Symbol, Dodopayments::Models::TaxCategory
Tax category applied to this product
26 |
# File 'lib/dodopayments/models/product_create_params.rb', line 26 required :tax_category, enum: -> { Dodopayments::TaxCategory } |