Class: Dodopayments::Models::ProductItemReq

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/dodopayments/models/product_item_req.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(product_id:, quantity:, addons: nil, amount: nil) ⇒ Object

Some parameter documentations has been truncated, see Dodopayments::Models::ProductItemReq for more details.

Parameters:

  • product_id (String)

    unique id of the product

  • quantity (Integer)
  • addons (Array<Dodopayments::Models::AttachAddon>, nil) (defaults to: nil)

    only valid if product is a subscription

  • amount (Integer, nil) (defaults to: nil)

    Amount the customer pays if pay_what_you_want is enabled. If disabled then amoun



# File 'lib/dodopayments/models/product_item_req.rb', line 35

Instance Attribute Details

#addonsArray<Dodopayments::Models::AttachAddon>?

only valid if product is a subscription

Returns:



21
# File 'lib/dodopayments/models/product_item_req.rb', line 21

optional :addons, -> { Dodopayments::Internal::Type::ArrayOf[Dodopayments::AttachAddon] }, nil?: true

#amountInteger?

Amount the customer pays if pay_what_you_want is enabled. If disabled then amount will be ignored Represented in the lowest denomination of the currency (e.g., cents for USD). For example, to charge $1.00, pass ‘100`. Only applicable for one time payments

If amount is not set for pay_what_you_want product, customer is allowed to select the amount.

Returns:

  • (Integer, nil)


33
# File 'lib/dodopayments/models/product_item_req.rb', line 33

optional :amount, Integer, nil?: true

#product_idString

unique id of the product

Returns:

  • (String)


10
# File 'lib/dodopayments/models/product_item_req.rb', line 10

required :product_id, String

#quantityInteger

Returns:

  • (Integer)


15
# File 'lib/dodopayments/models/product_item_req.rb', line 15

required :quantity, Integer