Class: Dodopayments::Models::ProductUpdateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Dodopayments::Models::ProductUpdateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/dodopayments/models/product_update_params.rb,
sig/dodopayments/models/product_update_params.rbs
Overview
Defined Under Namespace
Classes: DigitalProductDelivery
Constant Summary
Constants included from Internal::Type::RequestParameters
Internal::Type::RequestParameters::Dodopayments
Instance Attribute Summary collapse
-
#addons ⇒ Array<String>?
Available Addons for subscription products.
- #brand_id ⇒ String?
-
#credit_entitlements ⇒ Array<Dodopayments::Models::AttachCreditEntitlement>?
Credit entitlements to update (replaces all existing when present) Send empty array to remove all, omit field to leave unchanged.
-
#description ⇒ String?
Description of the product, optional and must be at most 1000 characters.
-
#digital_product_delivery ⇒ Dodopayments::Models::ProductUpdateParams::DigitalProductDelivery?
Choose how you would like you digital product delivered.
-
#entitlements ⇒ Array<Dodopayments::Models::AttachProductEntitlement>?
Entitlements to attach (replaces all existing when present) Send empty array to remove all, omit field to leave unchanged.
- #id ⇒ String
-
#image_id ⇒ String?
Product image id after its uploaded to S3.
-
#license_key_activation_message ⇒ String?
deprecated
Deprecated.
Use the dedicated entitlements API to configure license-key delivery.
-
#license_key_activations_limit ⇒ Integer?
deprecated
Deprecated.
Use the dedicated entitlements API to configure license-key delivery.
-
#license_key_duration ⇒ Dodopayments::Models::LicenseKeyDuration?
Duration of the license key if enabled.
-
#license_key_enabled ⇒ Boolean?
deprecated
Deprecated.
Use the dedicated entitlements API to configure license-key delivery.
-
#metadata ⇒ Hash{Symbol=>String, Float, Boolean}?
Additional metadata for the product.
-
#name ⇒ String?
Name of the product, optional and must be at most 100 characters.
-
#price ⇒ Dodopayments::Models::Price::OneTimePrice, ...
Price details of the product.
-
#pricing_mode ⇒ Symbol, ...
Update the pricing mode.
-
#tax_category ⇒ Symbol, ...
Tax category of the product.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
63 |
# File 'sig/dodopayments/models/product_update_params.rbs', line 63
def initialize: (
|
Instance Attribute Details
#addons ⇒ Array<String>?
Available Addons for subscription products
19 |
# File 'lib/dodopayments/models/product_update_params.rb', line 19 optional :addons, Dodopayments::Internal::Type::ArrayOf[String], nil?: true |
#brand_id ⇒ String?
24 |
# File 'lib/dodopayments/models/product_update_params.rb', line 24 optional :brand_id, String, nil?: true |
#credit_entitlements ⇒ Array<Dodopayments::Models::AttachCreditEntitlement>?
Credit entitlements to update (replaces all existing when present) Send empty array to remove all, omit field to leave unchanged
31 32 33 |
# File 'lib/dodopayments/models/product_update_params.rb', line 31 optional :credit_entitlements, -> { Dodopayments::Internal::Type::ArrayOf[Dodopayments::AttachCreditEntitlement] }, nil?: true |
#description ⇒ String?
Description of the product, optional and must be at most 1000 characters.
39 |
# File 'lib/dodopayments/models/product_update_params.rb', line 39 optional :description, String, nil?: true |
#digital_product_delivery ⇒ Dodopayments::Models::ProductUpdateParams::DigitalProductDelivery?
Choose how you would like you digital product delivered
deprecated: use entitlements instead
47 48 49 |
# File 'lib/dodopayments/models/product_update_params.rb', line 47 optional :digital_product_delivery, -> { Dodopayments::ProductUpdateParams::DigitalProductDelivery }, nil?: true |
#entitlements ⇒ Array<Dodopayments::Models::AttachProductEntitlement>?
Entitlements to attach (replaces all existing when present) Send empty array to remove all, omit field to leave unchanged
56 57 58 |
# File 'lib/dodopayments/models/product_update_params.rb', line 56 optional :entitlements, -> { Dodopayments::Internal::Type::ArrayOf[Dodopayments::AttachProductEntitlement] }, nil?: true |
#id ⇒ String
13 |
# File 'lib/dodopayments/models/product_update_params.rb', line 13 required :id, String |
#image_id ⇒ String?
Product image id after its uploaded to S3
64 |
# File 'lib/dodopayments/models/product_update_params.rb', line 64 optional :image_id, String, nil?: true |
#license_key_activation_message ⇒ String?
Use the dedicated entitlements API to configure license-key delivery.
Message sent to the customer upon license key activation.
Only applicable if license_key_enabled is true. This message contains
instructions for activating the license key.
deprecated: use entitlements instead
77 |
# File 'lib/dodopayments/models/product_update_params.rb', line 77 optional :license_key_activation_message, String, nil?: true |
#license_key_activations_limit ⇒ Integer?
Use the dedicated entitlements API to configure license-key delivery.
Limit for the number of activations for the license key.
Only applicable if license_key_enabled is true. Represents the maximum
number of times the license key can be activated.
deprecated: use entitlements instead
90 |
# File 'lib/dodopayments/models/product_update_params.rb', line 90 optional :license_key_activations_limit, Integer, nil?: true |
#license_key_duration ⇒ Dodopayments::Models::LicenseKeyDuration?
Duration of the license key if enabled.
Only applicable if license_key_enabled is true. Represents the duration in
days for which the license key is valid.
deprecated: use entitlements instead
101 |
# File 'lib/dodopayments/models/product_update_params.rb', line 101 optional :license_key_duration, -> { Dodopayments::LicenseKeyDuration }, nil?: true |
#license_key_enabled ⇒ Boolean?
Use the dedicated entitlements API to configure license-key delivery.
Whether the product requires a license key.
If true, additional fields related to license key (duration, activations
limit, activation message) become applicable.
deprecated: use entitlements instead
114 |
# File 'lib/dodopayments/models/product_update_params.rb', line 114 optional :license_key_enabled, Dodopayments::Internal::Type::Boolean, nil?: true |
#metadata ⇒ Hash{Symbol=>String, Float, Boolean}?
Additional metadata for the product
120 121 122 |
# File 'lib/dodopayments/models/product_update_params.rb', line 120 optional :metadata, -> { Dodopayments::Internal::Type::HashOf[union: Dodopayments::MetadataItem] }, nil?: true |
#name ⇒ String?
Name of the product, optional and must be at most 100 characters.
128 |
# File 'lib/dodopayments/models/product_update_params.rb', line 128 optional :name, String, nil?: true |
#price ⇒ Dodopayments::Models::Price::OneTimePrice, ...
Price details of the product.
134 |
# File 'lib/dodopayments/models/product_update_params.rb', line 134 optional :price, union: -> { Dodopayments::Price }, nil?: true |
#pricing_mode ⇒ Symbol, ...
Update the pricing mode. Omit to leave unchanged; set to null to clear (which archives all active localized rules for this product). Changing to a different non-null mode also archives any rules whose mode doesn't match the new mode.
142 |
# File 'lib/dodopayments/models/product_update_params.rb', line 142 optional :pricing_mode, enum: -> { Dodopayments::Products::PricingMode }, nil?: true |
#tax_category ⇒ Symbol, ...
Tax category of the product.
148 |
# File 'lib/dodopayments/models/product_update_params.rb', line 148 optional :tax_category, enum: -> { Dodopayments::TaxCategory }, nil?: true |
Instance Method Details
#to_hash ⇒ {
84 |
# File 'sig/dodopayments/models/product_update_params.rbs', line 84
def to_hash: -> {
|