Class: Dodopayments::Models::ProductUpdateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Dodopayments::Models::ProductUpdateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/dodopayments/models/product_update_params.rb
Overview
Defined Under Namespace
Classes: DigitalProductDelivery
Instance Attribute Summary collapse
-
#addons ⇒ Array<String>?
Available Addons for subscription products.
- #brand_id ⇒ String?
-
#credit_entitlements ⇒ Array<Dodopayments::Models::AttachCreditEntitlement>?
Credit entitlements to update (replaces all existing when present) Send empty array to remove all, omit field to leave unchanged.
-
#description ⇒ String?
Description of the product, optional and must be at most 1000 characters.
-
#digital_product_delivery ⇒ Dodopayments::Models::ProductUpdateParams::DigitalProductDelivery?
Choose how you would like you digital product delivered.
-
#entitlement_ids ⇒ Array<String>?
Entitlement IDs to attach (replaces all existing when present) Send empty array to remove all, omit field to leave unchanged.
- #id ⇒ String
-
#image_id ⇒ String?
Product image id after its uploaded to S3.
- #license_key_activation_message ⇒ String? deprecated Deprecated.
- #license_key_activations_limit ⇒ Integer? deprecated Deprecated.
-
#license_key_duration ⇒ Dodopayments::Models::LicenseKeyDuration?
Duration of the license key if enabled.
- #license_key_enabled ⇒ Boolean? deprecated Deprecated.
-
#metadata ⇒ Hash{Symbol=>String}?
Additional metadata for the product.
-
#name ⇒ String?
Name of the product, optional and must be at most 100 characters.
-
#price ⇒ Dodopayments::Models::Price::OneTimePrice, ...
Price details of the product.
-
#tax_category ⇒ Symbol, ...
Tax category of the product.
Attributes included from Internal::Type::RequestParameters
Method Summary
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from Dodopayments::Internal::Type::BaseModel
Instance Attribute Details
#addons ⇒ Array<String>?
Available Addons for subscription products
19 |
# File 'lib/dodopayments/models/product_update_params.rb', line 19 optional :addons, Dodopayments::Internal::Type::ArrayOf[String], nil?: true |
#brand_id ⇒ String?
24 |
# File 'lib/dodopayments/models/product_update_params.rb', line 24 optional :brand_id, String, nil?: true |
#credit_entitlements ⇒ Array<Dodopayments::Models::AttachCreditEntitlement>?
Credit entitlements to update (replaces all existing when present) Send empty array to remove all, omit field to leave unchanged
31 32 33 |
# File 'lib/dodopayments/models/product_update_params.rb', line 31 optional :credit_entitlements, -> { Dodopayments::Internal::Type::ArrayOf[Dodopayments::AttachCreditEntitlement] }, nil?: true |
#description ⇒ String?
Description of the product, optional and must be at most 1000 characters.
39 |
# File 'lib/dodopayments/models/product_update_params.rb', line 39 optional :description, String, nil?: true |
#digital_product_delivery ⇒ Dodopayments::Models::ProductUpdateParams::DigitalProductDelivery?
Choose how you would like you digital product delivered
45 46 47 |
# File 'lib/dodopayments/models/product_update_params.rb', line 45 optional :digital_product_delivery, -> { Dodopayments::ProductUpdateParams::DigitalProductDelivery }, nil?: true |
#entitlement_ids ⇒ Array<String>?
Entitlement IDs to attach (replaces all existing when present) Send empty array to remove all, omit field to leave unchanged
54 |
# File 'lib/dodopayments/models/product_update_params.rb', line 54 optional :entitlement_ids, Dodopayments::Internal::Type::ArrayOf[String], nil?: true |
#id ⇒ String
13 |
# File 'lib/dodopayments/models/product_update_params.rb', line 13 required :id, String |
#image_id ⇒ String?
Product image id after its uploaded to S3
60 |
# File 'lib/dodopayments/models/product_update_params.rb', line 60 optional :image_id, String, nil?: true |
#license_key_activation_message ⇒ String?
Message sent to the customer upon license key activation.
Only applicable if ‘license_key_enabled` is `true`. This message contains instructions for activating the license key.
71 |
# File 'lib/dodopayments/models/product_update_params.rb', line 71 optional :license_key_activation_message, String, nil?: true |
#license_key_activations_limit ⇒ Integer?
Limit for the number of activations for the license key.
Only applicable if ‘license_key_enabled` is `true`. Represents the maximum number of times the license key can be activated.
82 |
# File 'lib/dodopayments/models/product_update_params.rb', line 82 optional :license_key_activations_limit, Integer, nil?: true |
#license_key_duration ⇒ Dodopayments::Models::LicenseKeyDuration?
Duration of the license key if enabled.
Only applicable if ‘license_key_enabled` is `true`. Represents the duration in days for which the license key is valid.
91 |
# File 'lib/dodopayments/models/product_update_params.rb', line 91 optional :license_key_duration, -> { Dodopayments::LicenseKeyDuration }, nil?: true |
#license_key_enabled ⇒ Boolean?
Whether the product requires a license key.
If ‘true`, additional fields related to license key (duration, activations limit, activation message) become applicable.
102 |
# File 'lib/dodopayments/models/product_update_params.rb', line 102 optional :license_key_enabled, Dodopayments::Internal::Type::Boolean, nil?: true |
#metadata ⇒ Hash{Symbol=>String}?
Additional metadata for the product
108 |
# File 'lib/dodopayments/models/product_update_params.rb', line 108 optional :metadata, Dodopayments::Internal::Type::HashOf[String], nil?: true |
#name ⇒ String?
Name of the product, optional and must be at most 100 characters.
114 |
# File 'lib/dodopayments/models/product_update_params.rb', line 114 optional :name, String, nil?: true |
#price ⇒ Dodopayments::Models::Price::OneTimePrice, ...
Price details of the product.
120 |
# File 'lib/dodopayments/models/product_update_params.rb', line 120 optional :price, union: -> { Dodopayments::Price }, nil?: true |
#tax_category ⇒ Symbol, ...
Tax category of the product.
126 |
# File 'lib/dodopayments/models/product_update_params.rb', line 126 optional :tax_category, enum: -> { Dodopayments::TaxCategory }, nil?: true |