Class: Dodopayments::Models::ProductUpdateParams::DigitalProductDelivery

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/dodopayments/models/product_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(external_url: nil, files: nil, instructions: nil) ⇒ Object

Choose how you would like you digital product delivered

deprecated: use entitlements instead

Parameters:

  • external_url (String, nil) (defaults to: nil)

    External URL to digital product

  • files (Array<String>, nil) (defaults to: nil)

    Uploaded files ids of digital product

  • instructions (String, nil) (defaults to: nil)

    Instructions to download and use the digital product



188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
# File 'lib/dodopayments/models/product_update_params.rb', line 188

class DigitalProductDelivery < Dodopayments::Internal::Type::BaseModel
  # @!attribute external_url
  #   External URL to digital product
  #
  #   @return [String, nil]
  optional :external_url, String, nil?: true

  # @!attribute files
  #   Uploaded files ids of digital product
  #
  #   @return [Array<String>, nil]
  optional :files, Dodopayments::Internal::Type::ArrayOf[String], nil?: true

  # @!attribute instructions
  #   Instructions to download and use the digital product
  #
  #   @return [String, nil]
  optional :instructions, String, nil?: true

  # @!method initialize(external_url: nil, files: nil, instructions: nil)
  #   Choose how you would like you digital product delivered
  #
  #   deprecated: use entitlements instead
  #
  #   @param external_url [String, nil] External URL to digital product
  #
  #   @param files [Array<String>, nil] Uploaded files ids of digital product
  #
  #   @param instructions [String, nil] Instructions to download and use the digital product
end

Instance Attribute Details

#external_urlString?

External URL to digital product

Returns:

  • (String, nil)


193
# File 'lib/dodopayments/models/product_update_params.rb', line 193

optional :external_url, String, nil?: true

#filesArray<String>?

Uploaded files ids of digital product

Returns:

  • (Array<String>, nil)


199
# File 'lib/dodopayments/models/product_update_params.rb', line 199

optional :files, Dodopayments::Internal::Type::ArrayOf[String], nil?: true

#instructionsString?

Instructions to download and use the digital product

Returns:

  • (String, nil)


205
# File 'lib/dodopayments/models/product_update_params.rb', line 205

optional :instructions, String, nil?: true