Class: Dodopayments::Models::ProductUpdateParams::DigitalProductDelivery
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Dodopayments::Models::ProductUpdateParams::DigitalProductDelivery
- Defined in:
- lib/dodopayments/models/product_update_params.rb
Instance Attribute Summary collapse
-
#external_url ⇒ String?
External URL to digital product.
-
#files ⇒ Array<String>?
Uploaded files ids of digital product.
-
#instructions ⇒ String?
Instructions to download and use the digital product.
Instance Method Summary collapse
-
#initialize(external_url: nil, files: nil, instructions: nil) ⇒ Object
constructor
Choose how you would like you digital product delivered.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(external_url: nil, files: nil, instructions: nil) ⇒ Object
Choose how you would like you digital product delivered
166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 |
# File 'lib/dodopayments/models/product_update_params.rb', line 166 class DigitalProductDelivery < Dodopayments::Internal::Type::BaseModel # @!attribute external_url # External URL to digital product # # @return [String, nil] optional :external_url, String, nil?: true # @!attribute files # Uploaded files ids of digital product # # @return [Array<String>, nil] optional :files, Dodopayments::Internal::Type::ArrayOf[String], nil?: true # @!attribute instructions # Instructions to download and use the digital product # # @return [String, nil] optional :instructions, String, nil?: true # @!method initialize(external_url: nil, files: nil, instructions: nil) # Choose how you would like you digital product delivered # # @param external_url [String, nil] External URL to digital product # # @param files [Array<String>, nil] Uploaded files ids of digital product # # @param instructions [String, nil] Instructions to download and use the digital product end |
Instance Attribute Details
#external_url ⇒ String?
External URL to digital product
171 |
# File 'lib/dodopayments/models/product_update_params.rb', line 171 optional :external_url, String, nil?: true |
#files ⇒ Array<String>?
Uploaded files ids of digital product
177 |
# File 'lib/dodopayments/models/product_update_params.rb', line 177 optional :files, Dodopayments::Internal::Type::ArrayOf[String], nil?: true |
#instructions ⇒ String?
Instructions to download and use the digital product
183 |
# File 'lib/dodopayments/models/product_update_params.rb', line 183 optional :instructions, String, nil?: true |