Class: Dodopayments::Models::SubscriptionCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Dodopayments::Models::SubscriptionCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/dodopayments/models/subscription_create_params.rb
Overview
Defined Under Namespace
Classes: OneTimeProductCart
Instance Attribute Summary collapse
-
#addons ⇒ Array<Dodopayments::Models::AttachAddon>?
Attach addons to this subscription.
-
#allowed_payment_method_types ⇒ Array<Symbol, Dodopayments::Models::PaymentMethodTypes>?
List of payment methods allowed during checkout.
-
#billing ⇒ Dodopayments::Models::BillingAddress
Billing address information for the subscription.
-
#billing_currency ⇒ Symbol, ...
Fix the currency in which the end customer is billed.
-
#customer ⇒ Dodopayments::Models::AttachExistingCustomer, Dodopayments::Models::NewCustomer
Customer details for the subscription.
-
#discount_code ⇒ String?
Discount Code to apply to the subscription.
-
#force_3ds ⇒ Boolean?
Override merchant default 3DS behaviour for this subscription.
-
#metadata ⇒ Hash{Symbol=>String}?
Additional metadata for the subscription Defaults to empty if not specified.
- #on_demand ⇒ Dodopayments::Models::OnDemandSubscription?
-
#one_time_product_cart ⇒ Array<Dodopayments::Models::SubscriptionCreateParams::OneTimeProductCart>?
List of one time products that will be bundled with the first payment for this subscription.
-
#payment_link ⇒ Boolean?
If true, generates a payment link.
-
#payment_method_id ⇒ String?
Optional payment method ID to use for this subscription.
-
#product_id ⇒ String
Unique identifier of the product to subscribe to.
-
#quantity ⇒ Integer
Number of units to subscribe for.
-
#redirect_immediately ⇒ Boolean?
If true, redirects the customer immediately after payment completion False by default.
-
#return_url ⇒ String?
Optional URL to redirect after successful subscription creation.
-
#short_link ⇒ Boolean?
If true, returns a shortened payment link.
-
#show_saved_payment_methods ⇒ Boolean?
Display saved payment methods of a returning customer False by default.
-
#tax_id ⇒ String?
Tax ID in case the payment is B2B.
-
#trial_period_days ⇒ Integer?
Optional trial period in days If specified, this value overrides the trial period set in the product’s price Must be between 0 and 10000 days.
Attributes included from Internal::Type::RequestParameters
Method Summary
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from Dodopayments::Internal::Type::BaseModel
Instance Attribute Details
#addons ⇒ Array<Dodopayments::Models::AttachAddon>?
Attach addons to this subscription
38 |
# File 'lib/dodopayments/models/subscription_create_params.rb', line 38 optional :addons, -> { Dodopayments::Internal::Type::ArrayOf[Dodopayments::AttachAddon] }, nil?: true |
#allowed_payment_method_types ⇒ Array<Symbol, Dodopayments::Models::PaymentMethodTypes>?
List of payment methods allowed during checkout.
Customers will never see payment methods that are not in this list. However, adding a method here **does not guarantee** customers will see it. Availability still depends on other factors (e.g., customer location, merchant settings).
49 50 51 |
# File 'lib/dodopayments/models/subscription_create_params.rb', line 49 optional :allowed_payment_method_types, -> { Dodopayments::Internal::Type::ArrayOf[enum: Dodopayments::PaymentMethodTypes] }, nil?: true |
#billing ⇒ Dodopayments::Models::BillingAddress
Billing address information for the subscription
14 |
# File 'lib/dodopayments/models/subscription_create_params.rb', line 14 required :billing, -> { Dodopayments::BillingAddress } |
#billing_currency ⇒ Symbol, ...
Fix the currency in which the end customer is billed. If Dodo Payments cannot support that currency for this transaction, it will not proceed
58 |
# File 'lib/dodopayments/models/subscription_create_params.rb', line 58 optional :billing_currency, enum: -> { Dodopayments::Currency }, nil?: true |
#customer ⇒ Dodopayments::Models::AttachExistingCustomer, Dodopayments::Models::NewCustomer
Customer details for the subscription
20 |
# File 'lib/dodopayments/models/subscription_create_params.rb', line 20 required :customer, union: -> { Dodopayments::CustomerRequest } |
#discount_code ⇒ String?
Discount Code to apply to the subscription
64 |
# File 'lib/dodopayments/models/subscription_create_params.rb', line 64 optional :discount_code, String, nil?: true |
#force_3ds ⇒ Boolean?
Override merchant default 3DS behaviour for this subscription
70 |
# File 'lib/dodopayments/models/subscription_create_params.rb', line 70 optional :force_3ds, Dodopayments::Internal::Type::Boolean, nil?: true |
#metadata ⇒ Hash{Symbol=>String}?
Additional metadata for the subscription Defaults to empty if not specified
76 |
# File 'lib/dodopayments/models/subscription_create_params.rb', line 76 optional :metadata, Dodopayments::Internal::Type::HashOf[String] |
#on_demand ⇒ Dodopayments::Models::OnDemandSubscription?
81 |
# File 'lib/dodopayments/models/subscription_create_params.rb', line 81 optional :on_demand, -> { Dodopayments::OnDemandSubscription }, nil?: true |
#one_time_product_cart ⇒ Array<Dodopayments::Models::SubscriptionCreateParams::OneTimeProductCart>?
List of one time products that will be bundled with the first payment for this subscription
88 89 90 91 92 |
# File 'lib/dodopayments/models/subscription_create_params.rb', line 88 optional :one_time_product_cart, -> { Dodopayments::Internal::Type::ArrayOf[Dodopayments::SubscriptionCreateParams::OneTimeProductCart] }, nil?: true |
#payment_link ⇒ Boolean?
If true, generates a payment link. Defaults to false if not specified.
98 |
# File 'lib/dodopayments/models/subscription_create_params.rb', line 98 optional :payment_link, Dodopayments::Internal::Type::Boolean, nil?: true |
#payment_method_id ⇒ String?
Optional payment method ID to use for this subscription. If provided, customer_id must also be provided (via AttachExistingCustomer). The payment method will be validated for eligibility with the subscription’s currency.
106 |
# File 'lib/dodopayments/models/subscription_create_params.rb', line 106 optional :payment_method_id, String, nil?: true |
#product_id ⇒ String
Unique identifier of the product to subscribe to
26 |
# File 'lib/dodopayments/models/subscription_create_params.rb', line 26 required :product_id, String |
#quantity ⇒ Integer
Number of units to subscribe for. Must be at least 1.
32 |
# File 'lib/dodopayments/models/subscription_create_params.rb', line 32 required :quantity, Integer |
#redirect_immediately ⇒ Boolean?
If true, redirects the customer immediately after payment completion False by default
113 |
# File 'lib/dodopayments/models/subscription_create_params.rb', line 113 optional :redirect_immediately, Dodopayments::Internal::Type::Boolean |
#return_url ⇒ String?
Optional URL to redirect after successful subscription creation
119 |
# File 'lib/dodopayments/models/subscription_create_params.rb', line 119 optional :return_url, String, nil?: true |
#short_link ⇒ Boolean?
If true, returns a shortened payment link. Defaults to false if not specified.
125 |
# File 'lib/dodopayments/models/subscription_create_params.rb', line 125 optional :short_link, Dodopayments::Internal::Type::Boolean, nil?: true |
#show_saved_payment_methods ⇒ Boolean?
Display saved payment methods of a returning customer False by default
131 |
# File 'lib/dodopayments/models/subscription_create_params.rb', line 131 optional :show_saved_payment_methods, Dodopayments::Internal::Type::Boolean |
#tax_id ⇒ String?
Tax ID in case the payment is B2B. If tax id validation fails the payment creation will fail
138 |
# File 'lib/dodopayments/models/subscription_create_params.rb', line 138 optional :tax_id, String, nil?: true |
#trial_period_days ⇒ Integer?
Optional trial period in days If specified, this value overrides the trial period set in the product’s price Must be between 0 and 10000 days
145 |
# File 'lib/dodopayments/models/subscription_create_params.rb', line 145 optional :trial_period_days, Integer, nil?: true |