Class: Dodopayments::Models::SubscriptionListResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Dodopayments::Models::SubscriptionListResponse
- Defined in:
- lib/dodopayments/models/subscription_list_response.rb
Overview
Defined Under Namespace
Classes: Discount
Instance Attribute Summary collapse
-
#billing ⇒ Dodopayments::Models::BillingAddress
Billing address details for payments.
-
#cancel_at_next_billing_date ⇒ Boolean
Indicates if the subscription will cancel at the next billing date.
-
#cancelled_at ⇒ Time?
Cancelled timestamp if the subscription is cancelled.
-
#created_at ⇒ Time
Timestamp when the subscription was created.
-
#currency ⇒ Symbol, Dodopayments::Models::Currency
Currency used for the subscription payments.
-
#customer ⇒ Dodopayments::Models::CustomerLimitedDetails
Customer details associated with the subscription.
-
#discount_cycles_remaining ⇒ Integer?
DEPRECATED: Use discounts[].cycles_remaining instead.
-
#discount_id ⇒ String?
DEPRECATED: Use discounts instead.
-
#discounts ⇒ Array<Dodopayments::Models::SubscriptionListResponse::Discount>
All stacked discounts applied, in order of application.
-
#metadata ⇒ Hash{Symbol=>String}
Additional custom data associated with the subscription.
-
#next_billing_date ⇒ Time
Timestamp of the next scheduled billing.
-
#on_demand ⇒ Boolean
Wether the subscription is on-demand or not.
-
#payment_frequency_count ⇒ Integer
Number of payment frequency intervals.
-
#payment_frequency_interval ⇒ Symbol, Dodopayments::Models::TimeInterval
Time interval for payment frequency (e.g. month, year).
-
#payment_method_id ⇒ String?
Saved payment method id used for recurring charges.
-
#previous_billing_date ⇒ Time
Timestamp of the last payment.
-
#product_id ⇒ String
Identifier of the product associated with this subscription.
-
#product_name ⇒ String?
Name of the product associated with this subscription.
-
#quantity ⇒ Integer
Number of units/items included in the subscription.
-
#recurring_pre_tax_amount ⇒ Integer
Amount charged before tax for each recurring payment in smallest currency unit (e.g. cents).
-
#scheduled_change ⇒ Dodopayments::Models::ScheduledPlanChange?
Scheduled plan change details, if any.
-
#status ⇒ Symbol, Dodopayments::Models::SubscriptionStatus
Current status of the subscription.
-
#subscription_id ⇒ String
Unique identifier for the subscription.
-
#subscription_period_count ⇒ Integer
Number of subscription period intervals.
-
#subscription_period_interval ⇒ Symbol, Dodopayments::Models::TimeInterval
Time interval for the subscription period (e.g. month, year).
-
#tax_id ⇒ String?
Tax identifier provided for this subscription (if applicable).
-
#tax_inclusive ⇒ Boolean
Indicates if the recurring_pre_tax_amount is tax inclusive.
-
#trial_period_days ⇒ Integer
Number of days in the trial period (0 if no trial).
Method Summary
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from Dodopayments::Internal::Type::BaseModel
Instance Attribute Details
#billing ⇒ Dodopayments::Models::BillingAddress
Billing address details for payments
11 |
# File 'lib/dodopayments/models/subscription_list_response.rb', line 11 required :billing, -> { Dodopayments::BillingAddress } |
#cancel_at_next_billing_date ⇒ Boolean
Indicates if the subscription will cancel at the next billing date
17 |
# File 'lib/dodopayments/models/subscription_list_response.rb', line 17 required :cancel_at_next_billing_date, Dodopayments::Internal::Type::Boolean |
#cancelled_at ⇒ Time?
Cancelled timestamp if the subscription is cancelled
140 |
# File 'lib/dodopayments/models/subscription_list_response.rb', line 140 optional :cancelled_at, Time, nil?: true |
#created_at ⇒ Time
Timestamp when the subscription was created
23 |
# File 'lib/dodopayments/models/subscription_list_response.rb', line 23 required :created_at, Time |
#currency ⇒ Symbol, Dodopayments::Models::Currency
Currency used for the subscription payments
29 |
# File 'lib/dodopayments/models/subscription_list_response.rb', line 29 required :currency, enum: -> { Dodopayments::Currency } |
#customer ⇒ Dodopayments::Models::CustomerLimitedDetails
Customer details associated with the subscription
35 |
# File 'lib/dodopayments/models/subscription_list_response.rb', line 35 required :customer, -> { Dodopayments::CustomerLimitedDetails } |
#discount_cycles_remaining ⇒ Integer?
DEPRECATED: Use discounts[].cycles_remaining instead.
146 |
# File 'lib/dodopayments/models/subscription_list_response.rb', line 146 optional :discount_cycles_remaining, Integer, nil?: true |
#discount_id ⇒ String?
DEPRECATED: Use discounts instead.
152 |
# File 'lib/dodopayments/models/subscription_list_response.rb', line 152 optional :discount_id, String, nil?: true |
#discounts ⇒ Array<Dodopayments::Models::SubscriptionListResponse::Discount>
All stacked discounts applied, in order of application
41 42 |
# File 'lib/dodopayments/models/subscription_list_response.rb', line 41 required :discounts, -> { Dodopayments::Internal::Type::ArrayOf[Dodopayments::Models::SubscriptionListResponse::Discount] } |
#metadata ⇒ Hash{Symbol=>String}
Additional custom data associated with the subscription
48 |
# File 'lib/dodopayments/models/subscription_list_response.rb', line 48 required :metadata, Dodopayments::Internal::Type::HashOf[String] |
#next_billing_date ⇒ Time
Timestamp of the next scheduled billing. Indicates the end of current billing period
55 |
# File 'lib/dodopayments/models/subscription_list_response.rb', line 55 required :next_billing_date, Time |
#on_demand ⇒ Boolean
Wether the subscription is on-demand or not
61 |
# File 'lib/dodopayments/models/subscription_list_response.rb', line 61 required :on_demand, Dodopayments::Internal::Type::Boolean |
#payment_frequency_count ⇒ Integer
Number of payment frequency intervals
67 |
# File 'lib/dodopayments/models/subscription_list_response.rb', line 67 required :payment_frequency_count, Integer |
#payment_frequency_interval ⇒ Symbol, Dodopayments::Models::TimeInterval
Time interval for payment frequency (e.g. month, year)
73 |
# File 'lib/dodopayments/models/subscription_list_response.rb', line 73 required :payment_frequency_interval, enum: -> { Dodopayments::TimeInterval } |
#payment_method_id ⇒ String?
Saved payment method id used for recurring charges
158 |
# File 'lib/dodopayments/models/subscription_list_response.rb', line 158 optional :payment_method_id, String, nil?: true |
#previous_billing_date ⇒ Time
Timestamp of the last payment. Indicates the start of current billing period
79 |
# File 'lib/dodopayments/models/subscription_list_response.rb', line 79 required :previous_billing_date, Time |
#product_id ⇒ String
Identifier of the product associated with this subscription
85 |
# File 'lib/dodopayments/models/subscription_list_response.rb', line 85 required :product_id, String |
#product_name ⇒ String?
Name of the product associated with this subscription
164 |
# File 'lib/dodopayments/models/subscription_list_response.rb', line 164 optional :product_name, String, nil?: true |
#quantity ⇒ Integer
Number of units/items included in the subscription
91 |
# File 'lib/dodopayments/models/subscription_list_response.rb', line 91 required :quantity, Integer |
#recurring_pre_tax_amount ⇒ Integer
Amount charged before tax for each recurring payment in smallest currency unit (e.g. cents)
98 |
# File 'lib/dodopayments/models/subscription_list_response.rb', line 98 required :recurring_pre_tax_amount, Integer |
#scheduled_change ⇒ Dodopayments::Models::ScheduledPlanChange?
Scheduled plan change details, if any
170 |
# File 'lib/dodopayments/models/subscription_list_response.rb', line 170 optional :scheduled_change, -> { Dodopayments::ScheduledPlanChange }, nil?: true |
#status ⇒ Symbol, Dodopayments::Models::SubscriptionStatus
Current status of the subscription
104 |
# File 'lib/dodopayments/models/subscription_list_response.rb', line 104 required :status, enum: -> { Dodopayments::SubscriptionStatus } |
#subscription_id ⇒ String
Unique identifier for the subscription
110 |
# File 'lib/dodopayments/models/subscription_list_response.rb', line 110 required :subscription_id, String |
#subscription_period_count ⇒ Integer
Number of subscription period intervals
116 |
# File 'lib/dodopayments/models/subscription_list_response.rb', line 116 required :subscription_period_count, Integer |
#subscription_period_interval ⇒ Symbol, Dodopayments::Models::TimeInterval
Time interval for the subscription period (e.g. month, year)
122 |
# File 'lib/dodopayments/models/subscription_list_response.rb', line 122 required :subscription_period_interval, enum: -> { Dodopayments::TimeInterval } |
#tax_id ⇒ String?
Tax identifier provided for this subscription (if applicable)
176 |
# File 'lib/dodopayments/models/subscription_list_response.rb', line 176 optional :tax_id, String, nil?: true |
#tax_inclusive ⇒ Boolean
Indicates if the recurring_pre_tax_amount is tax inclusive
128 |
# File 'lib/dodopayments/models/subscription_list_response.rb', line 128 required :tax_inclusive, Dodopayments::Internal::Type::Boolean |
#trial_period_days ⇒ Integer
Number of days in the trial period (0 if no trial)
134 |
# File 'lib/dodopayments/models/subscription_list_response.rb', line 134 required :trial_period_days, Integer |