Class: Dodopayments::Models::SubscriptionListResponse::Discount

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/dodopayments/models/subscription_list_response.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(discount_id:, discount_cycles_remaining: nil) ⇒ Object

Lightweight discount info for list endpoints. Array order represents position (no explicit position field).

Parameters:

  • discount_id (String)

    The unique discount ID

  • discount_cycles_remaining (Integer, nil) (defaults to: nil)

    Remaining billing cycles for this discount on this subscription



240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
# File 'lib/dodopayments/models/subscription_list_response.rb', line 240

class Discount < Dodopayments::Internal::Type::BaseModel
  # @!attribute discount_id
  #   The unique discount ID
  #
  #   @return [String]
  required :discount_id, String

  # @!attribute discount_cycles_remaining
  #   Remaining billing cycles for this discount on this subscription
  #
  #   @return [Integer, nil]
  optional :discount_cycles_remaining, Integer, nil?: true

  # @!method initialize(discount_id:, discount_cycles_remaining: nil)
  #   Lightweight discount info for list endpoints. Array order represents position
  #   (no explicit position field).
  #
  #   @param discount_id [String] The unique discount ID
  #
  #   @param discount_cycles_remaining [Integer, nil] Remaining billing cycles for this discount on this subscription
end

Instance Attribute Details

#discount_cycles_remainingInteger?

Remaining billing cycles for this discount on this subscription

Returns:

  • (Integer, nil)


251
# File 'lib/dodopayments/models/subscription_list_response.rb', line 251

optional :discount_cycles_remaining, Integer, nil?: true

#discount_idString

The unique discount ID

Returns:

  • (String)


245
# File 'lib/dodopayments/models/subscription_list_response.rb', line 245

required :discount_id, String