Class: Dodopayments::Models::SubscriptionUpdateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Dodopayments::Models::SubscriptionUpdateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/dodopayments/models/subscription_update_params.rb,
sig/dodopayments/models/subscription_update_params.rbs
Overview
Defined Under Namespace
Modules: CancelReason Classes: CreditEntitlementCart, DisableOnDemand
Constant Summary
Constants included from Internal::Type::RequestParameters
Internal::Type::RequestParameters::Dodopayments
Instance Attribute Summary collapse
- #billing ⇒ Dodopayments::Models::BillingAddress?
-
#cancel_at_next_billing_date ⇒ Boolean?
When set, the subscription will remain active until the end of billing period.
- #cancel_reason ⇒ Symbol, ...
-
#cancellation_comment ⇒ String?
Free-text cancellation comment (only valid when cancelling or scheduling cancellation).
-
#cancellation_feedback ⇒ Symbol, ...
Customer-supplied churn reason (only valid when cancelling or scheduling cancellation).
-
#credit_entitlement_cart ⇒ Array<Dodopayments::Models::SubscriptionUpdateParams::CreditEntitlementCart>?
Update credit entitlement cart settings.
-
#customer_business_name ⇒ String?
Optional business / legal name associated with the tax id.
- #customer_name ⇒ String?
- #disable_on_demand ⇒ Dodopayments::Models::SubscriptionUpdateParams::DisableOnDemand?
-
#metadata ⇒ Hash{Symbol=>String, Float, Boolean}?
Arbitrary key-value metadata.
- #next_billing_date ⇒ Time?
- #status ⇒ Symbol, ...
- #subscription_id ⇒ String
-
#subscription_period_count ⇒ Integer?
New number of
subscription_period_intervalunits the subscription entitlement should span. -
#subscription_period_interval ⇒ Symbol, ...
New interval unit for the subscription period.
- #tax_id ⇒ String?
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Instance Method Summary collapse
- #initialize(credit_entitlement_id:, credits_amount: nil, expires_after_days: nil, low_balance_threshold_percent: nil, max_rollover_count: nil, overage_enabled: nil, overage_limit: nil, rollover_enabled: nil, rollover_percentage: nil, rollover_timeframe_count: nil, rollover_timeframe_interval: nil) ⇒ Object constructor
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(credit_entitlement_id:, credits_amount: nil, expires_after_days: nil, low_balance_threshold_percent: nil, max_rollover_count: nil, overage_enabled: nil, overage_limit: nil, rollover_enabled: nil, rollover_percentage: nil, rollover_timeframe_count: nil, rollover_timeframe_interval: nil) ⇒ Object
|
|
# File 'lib/dodopayments/models/subscription_update_params.rb', line 221
|
Instance Attribute Details
#billing ⇒ Dodopayments::Models::BillingAddress?
18 |
# File 'lib/dodopayments/models/subscription_update_params.rb', line 18 optional :billing, -> { Dodopayments::BillingAddress }, nil?: true |
#cancel_at_next_billing_date ⇒ Boolean?
When set, the subscription will remain active until the end of billing period
24 |
# File 'lib/dodopayments/models/subscription_update_params.rb', line 24 optional :cancel_at_next_billing_date, Dodopayments::Internal::Type::Boolean, nil?: true |
#cancel_reason ⇒ Symbol, ...
29 |
# File 'lib/dodopayments/models/subscription_update_params.rb', line 29 optional :cancel_reason, enum: -> { Dodopayments::SubscriptionUpdateParams::CancelReason }, nil?: true |
#cancellation_comment ⇒ String?
Free-text cancellation comment (only valid when cancelling or scheduling cancellation).
36 |
# File 'lib/dodopayments/models/subscription_update_params.rb', line 36 optional :cancellation_comment, String, nil?: true |
#cancellation_feedback ⇒ Symbol, ...
Customer-supplied churn reason (only valid when cancelling or scheduling cancellation).
43 |
# File 'lib/dodopayments/models/subscription_update_params.rb', line 43 optional :cancellation_feedback, enum: -> { Dodopayments::CancellationFeedback }, nil?: true |
#credit_entitlement_cart ⇒ Array<Dodopayments::Models::SubscriptionUpdateParams::CreditEntitlementCart>?
Update credit entitlement cart settings
49 50 51 52 53 |
# File 'lib/dodopayments/models/subscription_update_params.rb', line 49 optional :credit_entitlement_cart, -> { Dodopayments::Internal::Type::ArrayOf[Dodopayments::SubscriptionUpdateParams::CreditEntitlementCart] }, nil?: true |
#customer_business_name ⇒ String?
Optional business / legal name associated with the tax id. When provided
together with a valid tax id for a B2B subscription, this name is rendered on
the invoice instead of the customer's personal name. Send null to explicitly
clear the business name.
62 |
# File 'lib/dodopayments/models/subscription_update_params.rb', line 62 optional :customer_business_name, String, nil?: true |
#customer_name ⇒ String?
67 |
# File 'lib/dodopayments/models/subscription_update_params.rb', line 67 optional :customer_name, String, nil?: true |
#disable_on_demand ⇒ Dodopayments::Models::SubscriptionUpdateParams::DisableOnDemand?
72 |
# File 'lib/dodopayments/models/subscription_update_params.rb', line 72 optional :disable_on_demand, -> { Dodopayments::SubscriptionUpdateParams::DisableOnDemand }, nil?: true |
#metadata ⇒ Hash{Symbol=>String, Float, Boolean}?
Arbitrary key-value metadata. Values can be string, integer, number, or boolean.
78 79 80 |
# File 'lib/dodopayments/models/subscription_update_params.rb', line 78 optional :metadata, -> { Dodopayments::Internal::Type::HashOf[union: Dodopayments::MetadataItem] }, nil?: true |
#next_billing_date ⇒ Time?
85 |
# File 'lib/dodopayments/models/subscription_update_params.rb', line 85 optional :next_billing_date, Time, nil?: true |
#status ⇒ Symbol, ...
90 |
# File 'lib/dodopayments/models/subscription_update_params.rb', line 90 optional :status, enum: -> { Dodopayments::SubscriptionStatus }, nil?: true |
#subscription_id ⇒ String
13 |
# File 'lib/dodopayments/models/subscription_update_params.rb', line 13 required :subscription_id, String |
#subscription_period_count ⇒ Integer?
New number of subscription_period_interval units the subscription entitlement
should span. Used together with subscription_period_interval to extend the
subscription period. The resulting period must not be shorter than the current
one (this endpoint only extends).
99 |
# File 'lib/dodopayments/models/subscription_update_params.rb', line 99 optional :subscription_period_count, Integer, nil?: true |
#subscription_period_interval ⇒ Symbol, ...
New interval unit for the subscription period. When changing the period, this
may be supplied alongside subscription_period_count; if omitted the existing
interval is retained.
107 |
# File 'lib/dodopayments/models/subscription_update_params.rb', line 107 optional :subscription_period_interval, enum: -> { Dodopayments::TimeInterval }, nil?: true |
#tax_id ⇒ String?
112 |
# File 'lib/dodopayments/models/subscription_update_params.rb', line 112 optional :tax_id, String, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/dodopayments/models/subscription_update_params.rb', line 160
|
Instance Method Details
#to_hash ⇒ {
80 |
# File 'sig/dodopayments/models/subscription_update_params.rbs', line 80
def to_hash: -> {
|