Class: Dodopayments::Models::WebhookPayload::Data::Payout

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/dodopayments/models/webhook_payload.rb,
sig/dodopayments/models/webhook_payload.rbs

Defined Under Namespace

Modules: Status

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(amount:, business_id:, chargebacks:, created_at:, currency:, fee:, payment_method:, payout_id:, refunds:, status:, tax:, updated_at:, name: nil, payout_document_url: nil, remarks: nil, payload_type: :Payout) ⇒ Object

Parameters:

  • amount (Integer)

    The total amount of the payout.

  • business_id (String)

    The unique identifier of the business associated with the payout.

  • chargebacks (Integer)

    The total value of chargebacks associated with the payout.

  • created_at (Time)

    The timestamp when the payout was created, in UTC.

  • currency (Symbol, Dodopayments::Models::Currency)

    The currency of the payout, represented as an ISO 4217 currency code.

  • fee (Integer)

    The fee charged for processing the payout.

  • payment_method (String)

    The payment method used for the payout (e.g., bank transfer, card, etc.).

  • payout_id (String)

    The unique identifier of the payout.

  • refunds (Integer)

    The total value of refunds associated with the payout.

  • status (Symbol, Dodopayments::Models::WebhookPayload::Data::Payout::Status)

    The current status of the payout.

  • tax (Integer)

    The tax applied to the payout.

  • updated_at (Time)

    The timestamp when the payout was last updated, in UTC.

  • name (String, nil) (defaults to: nil)

    The name of the payout recipient or purpose.

  • payout_document_url (String, nil) (defaults to: nil)

    The URL of the document associated with the payout.

  • remarks (String, nil) (defaults to: nil)

    Any additional remarks or notes associated with the payout.

  • payload_type (Symbol, :Payout) (defaults to: :Payout)


# File 'lib/dodopayments/models/webhook_payload.rb', line 233

Instance Attribute Details

#amountInteger

The total amount of the payout.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


133
# File 'lib/dodopayments/models/webhook_payload.rb', line 133

required :amount, Integer

#business_idString

The unique identifier of the business associated with the payout.

Parameters:

  • value (String)

Returns:

  • (String)


139
# File 'lib/dodopayments/models/webhook_payload.rb', line 139

required :business_id, String

#chargebacksInteger

Deprecated.

Use the v3 payout breakup endpoints instead. Will be removed in a future

release.

The total value of chargebacks associated with the payout.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


148
# File 'lib/dodopayments/models/webhook_payload.rb', line 148

required :chargebacks, Integer

#created_atTime

The timestamp when the payout was created, in UTC.

Parameters:

  • value (Time)

Returns:

  • (Time)


154
# File 'lib/dodopayments/models/webhook_payload.rb', line 154

required :created_at, Time

#currencySymbol, Dodopayments::Models::Currency

The currency of the payout, represented as an ISO 4217 currency code.

Parameters:

  • value (Dodopayments::Models::currency)

Returns:



160
# File 'lib/dodopayments/models/webhook_payload.rb', line 160

required :currency, enum: -> { Dodopayments::Currency }

#feeInteger

The fee charged for processing the payout.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


166
# File 'lib/dodopayments/models/webhook_payload.rb', line 166

required :fee, Integer

#nameString?

The name of the payout recipient or purpose.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


219
# File 'lib/dodopayments/models/webhook_payload.rb', line 219

optional :name, String, nil?: true

#payload_typeSymbol, :Payout

Parameters:

  • value (:Payout)

Returns:

  • (Symbol, :Payout)


171
# File 'lib/dodopayments/models/webhook_payload.rb', line 171

required :payload_type, const: :Payout

#payment_methodString

The payment method used for the payout (e.g., bank transfer, card, etc.).

Parameters:

  • value (String)

Returns:

  • (String)


177
# File 'lib/dodopayments/models/webhook_payload.rb', line 177

required :payment_method, String

#payout_document_urlString?

The URL of the document associated with the payout.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


225
# File 'lib/dodopayments/models/webhook_payload.rb', line 225

optional :payout_document_url, String, nil?: true

#payout_idString

The unique identifier of the payout.

Parameters:

  • value (String)

Returns:

  • (String)


183
# File 'lib/dodopayments/models/webhook_payload.rb', line 183

required :payout_id, String

#refundsInteger

Deprecated.

Use the v3 payout breakup endpoints instead. Will be removed in a future

release.

The total value of refunds associated with the payout.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


192
# File 'lib/dodopayments/models/webhook_payload.rb', line 192

required :refunds, Integer

#remarksString?

Any additional remarks or notes associated with the payout.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


231
# File 'lib/dodopayments/models/webhook_payload.rb', line 231

optional :remarks, String, nil?: true

#statusSymbol, Dodopayments::Models::WebhookPayload::Data::Payout::Status

The current status of the payout.

Parameters:

  • value (Dodopayments::Models::WebhookPayload::Data::Payout::status)

Returns:



198
# File 'lib/dodopayments/models/webhook_payload.rb', line 198

required :status, enum: -> { Dodopayments::WebhookPayload::Data::Payout::Status }

#taxInteger

Deprecated.

Use the v3 payout breakup endpoints instead. Will be removed in a future

release.

The tax applied to the payout.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


207
# File 'lib/dodopayments/models/webhook_payload.rb', line 207

required :tax, Integer

#updated_atTime

The timestamp when the payout was last updated, in UTC.

Parameters:

  • value (Time)

Returns:

  • (Time)


213
# File 'lib/dodopayments/models/webhook_payload.rb', line 213

required :updated_at, Time

Instance Method Details

#to_hash{

Returns:

  • ({)


182
# File 'sig/dodopayments/models/webhook_payload.rbs', line 182

def to_hash: -> {